@@ -76,7 +76,7 @@ OC.L10N.register(
     "Nextcloud Group" : "Grup del Nextcloud",
     "Email address" : "Adreça electrònica",
     "Contact" : "Contacte",
-    "Circle" : "Cercle",
+    "Team" : "Equip",
     "Nextcloud App" : "Aplicació del Nextcloud",
     "Member" : "Membre",
     "Moderator" : "Moderació",
@@ -134,6 +134,7 @@ OC.L10N.register(
     "You have no permission to create a new team" : "No teniu permís per a crear un equip nou",
     "%s shared a file with \"%s\"." : "%s ha compartit un fitxer amb «%s».",
     "%s shared a file with you." : "%s ha compartit un fitxer amb vós.",
+    "Open %s" : "Obre %s",
     "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s ha compartit contingut amb vós.\nJa hauríeu d'haver rebut un altre correu electrònic amb un enllaç per a accedir-hi.\n",
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s ha compartit contingut amb vós. Ja hauríeu d'haver rebut un altre correu electrònic amb un enllaç per a accedir-hi.",
     "Password to access content shared with you by %1$s" : "Contrasenya per a accedir al contingut que %1$s ha compartit amb vós",
@@ -141,21 +142,14 @@ OC.L10N.register(
     "This item is already shared with this team" : "Aquest element ja està compartit amb aquest equip",
     "Bring cloud-users closer together." : "Acosteu els usuaris del núvol.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Els equips permeten que les persones creïn els seus propis grups de persones, companys i amics.\nQualsevol altra aplicació pot utilitzar aquests grups de persones per a compartir contingut.",
+    "Try again" : "Torneu-ho a provar",
+    "No teams found" : "No s'ha trobat cap equip",
+    "Loading…" : "S'està carregant…",
     "No files in here" : "No hi ha cap fitxer aquí",
     "No entries found in this folder" : "No s'ha trobat cap entrada en aquesta carpeta",
     "Name" : "Nom",
     "Size" : "Mida",
     "Modified" : "Data de modificació",
-    "Teams' files" : "Fitxers dels equips",
-    "Select team to filter by" : "Seleccioneu l'equip que voleu filtrar",
-    "No teams found" : "No s'ha trobat cap equip",
-    "Please select teams to filter by" : "Seleccioneu els equips que voleu filtrar",
-    "No files found for the selected teams" : "No s'ha trobat cap fitxer per als equips seleccionats",
-    "{author} added team {member} has been added as member to {circle}" : "{author} ha afegit l'equip {member} com a membre de {circle}",
-    "Shared to Circles" : "Compartits en cercles",
-    "You are now a member of the Circle \"%2$s\"" : "Ara sou membre del cercle «%2$s»",
-    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s us ha convidat al cercle «%2$s»",
-    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s ha enviat una sol·licitud per a ser membre del cercle «%2$s»",
-    "Leave the circle" : "Surt del cercle"
+    "Shared to Circles" : "Compartits en cercles"
 },
 "nplurals=2; plural=(n != 1);");
