@@ -14,8 +14,8 @@ OC.L10N.register(
     "{author} made {member} leave {circle}" : "{author} fik {member} til at forlade {circle}",
     "You removed {member} from {circle}" : "Du fjernede {member} fra {circle}",
     "{author} removed {member} from {circle}" : "{author} fjernede {member} fra {circle} ",
-    "You joined {circle}" : "Du har forbundet med {circle}",
-    "{member} joined {circle}" : "{member} sluttede sig til {circle}",
+    "You joined {circle}" : "Du deltager i {circle}",
+    "{member} joined {circle}" : "{member} deltog i {circle}",
     "You accepted the invitation to join {circle}" : "Du accepterede invitationen til at deltage i {circle}",
     "{member} accepted the invitation to join {circle}" : "{member} accepterede invitationen til at deltage i {circle}",
     "You added {member} as member to {circle}" : "Du tilføjede {member} som medlem til {circle}",
@@ -28,8 +28,8 @@ OC.L10N.register(
     "{member}'s request to join {circle} has been accepted by {author}" : "{member}s anmodning om at deltage i {circle} er blevet accepteret af {author}",
     "You left {circle}" : "Du forlod {circle}",
     "{member} left {circle}" : "{member} forlod {circle}",
-    "You declined the invitation to join {circle}" : "Du har afvist en invitation om at forbinde med {circle}",
-    "{member} declined an invitation to join {circle}" : "{member} afviste invitation om at forbinde med {circle}",
+    "You declined the invitation to join {circle}" : "Du har afvist en invitation om at deltage i {circle}",
+    "{member} declined an invitation to join {circle}" : "{member} afviste invitation om at deltage i {circle}",
     "You cancelled your request to join {circle}" : "Du har annulleret din anmodning om at deltage i {circle}",
     "{member} cancelled a request to join {circle}" : "{member} annullerede deres anmodning om at deltage {circle}",
     "You have been removed from {circle} by {author}" : "Du er blevet fjernet fra {circle} af {author}",
@@ -55,14 +55,13 @@ OC.L10N.register(
     "On events happening in a <strong>team</strong> of which you are a member" : "Om begivenheder, der finder sted i et <strong>team</strong>, som du er medlem af ",
     "Any important event in a <strong>team</strong> you are moderating" : "Enhver vigtig begivenhed i et <strong>team</strong>, du modererer",
     "On global events happening in any <strong>team</strong>" : "På globale begivenheder, der sker i ethvert <strong>team</strong>",
-    "Shared to Circles" : "Delt til Cirkler",
     "Single" : "Enkelt",
     "Personal" : "Personlig",
     "System" : "System",
     "Visible" : "Synlig",
     "Open" : "Åbn",
     "Invite" : "Invitere",
-    "Join request" : "Tilmeldingsanmodning",
+    "Join request" : "Deltagelsesanmodning",
     "Friends" : "Venner",
     "Password protected" : "Beskyt med adgangskode",
     "No Owner" : "Ingen ejer",
@@ -71,14 +70,16 @@ OC.L10N.register(
     "Local" : "Lokal",
     "Root" : "Root",
     "Team invite" : "Holdinvitation",
-    "Federated" : "Forbundet",
+    "Federated" : "Fødereret ",
     "Mount point" : "Monteringspunkt",
     "Nextcloud Account" : "Nextcloud-konto",
     "Nextcloud Group" : "Nextcloud gruppe",
     "Email address" : "Email adresse",
     "Contact" : "Kontakt",
-    "Circle" : "Cirkel",
+    "Team" : "Team",
     "Nextcloud App" : "Nextcloud app",
+    "Teams App" : "Teams App",
+    "Admin Command Line" : "Admin Kommandolinje",
     "Member" : "Medlem",
     "Moderator" : "Modeator",
     "Admin" : "Admin",
@@ -111,8 +112,8 @@ OC.L10N.register(
     "Create a new team" : "Opret et nyt team",
     "Files" : "Filer",
     "This feature is not available for personal circles" : "Denne funktion er ikke tilgængelig for personlige cirkler",
-    "The team is not federated" : "Teamet er ikke fødereret",
-    "You cannot join this team" : "Du kan ikke tilslutte dig dette team",
+    "The team is not federated" : "Teamet er ikke fødereret ",
+    "You cannot join this team" : "Du kan ikke deltage i dette team",
     "This member is not a moderator" : "Dette medlem er ikke en moderator",
     "Insufficient privileges" : "Utilstrækkelige rettigheder",
     "This member does not exist" : "Dette medlem eksisterer ikke",
@@ -123,18 +124,21 @@ OC.L10N.register(
     "The account is already a member of this circle" : "Kontoen er allerede medlem af denne cirkel",
     "The account has already been invited into this circle" : "Kontoen er allerede inviteret til denne cirkel",
     "%s (Team owned by %s)" : "%s (Team ejet af %s)",
-    "You are now a member of the Circle \"%2$s\"" : "Du er nu medlem af cirklen \"%2$s\"",
-    "You have been invited by %1$s into the Circle \"%2$s\"" : "Du er blevet inviteret af %1$s ind i cirklen \"%2$s\"",
-    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s sendte en anmodning om at blive medlem af cirklen \"%2$s\"",
+    "You are now a member of the Team \"%2$s\"" : "Du er ikke medlem af teamet \"%2$s\"",
+    "You have been invited by %1$s into the Team \"%2$s\"" : "Du er blevet inviteret af %1$s til teamet \"%2$s\"",
+    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s sendte en anmodning om at blive medlem af team \"%2$s\"",
     "Accept" : "Accepter",
     "Refuse" : "Afvis",
-    "Leave the circle" : "Forlad cirklen",
+    "Leave the team" : "Forlad teamet",
     "%s" : "%s",
     "Personal team" : "Personligt team",
     "%s owned by %s" : "%s ejet af %s",
     "You have no permission to create a new team" : "Du har ikke tilladelse til at oprette et nyt team",
     "%s shared a file with \"%s\"." : "%s delte en fil med \"%s\".",
     "%s shared a file with you." : "%s delte en fil med dig.",
+    "%1$s shared %2$s with %3$s" : "%1$s delte %2$s med %3$s",
+    "%1$s shared %2$s with \"%3$s\"" : "%1$s delte %2$s med \"%3$s\"",
+    "Open %s" : "Åbn %s",
     "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delt indhold med dig.\nDu burde allerede have modtaget en separat e-mail med et link for at få adgang...\n",
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s delt indhold med dig. Du burde allerede have modtaget en e-mail med et link for at få adgang...",
     "Password to access content shared with you by %1$s" : "Adgangskode for at få adgang til indhold, der deles med dig af %1$s",
@@ -142,59 +146,18 @@ OC.L10N.register(
     "This item is already shared with this team" : "Dette element er allerede delt med dette team",
     "Bring cloud-users closer together." : "Bring cloud-brugere tættere på hinanden.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Teams tillader dine brugere at oprette deres egen grupper af brugere/kolleger/venner.\nDisse grupper af brugere kan derefter bruges af enhver anden app til delingsformål.",
+    "Failed to load teams" : "Kunne ikke indlæse teams",
+    "Try again" : "Prøv igen",
+    "No teams found" : "Ingen teams fundet",
+    "Join or create teams to see them here." : "Deltag i eller opret teams for at se dem her.",
+    "Create your first team" : "Opret dit første team",
+    "Loading…" : "Indlæser…",
+    "More teams" : "Flere teams",
     "No files in here" : "Ingen filer herinde",
     "No entries found in this folder" : "Intet fundet i denne mappe",
     "Name" : "Navn",
     "Size" : "Størrelse",
     "Modified" : "Ændret",
-    "Circles" : "Cirkler",
-    "Circles' files" : "Cirklen's filer",
-    "Select circles to filter by" : "Vælg cirkler at filtrere efter",
-    "No circles found" : "Ingen cirkler fundet",
-    "Please select circles to filter by" : "Vælg venligst cirkler at filtrere efter",
-    "No files found for the selected circles" : "Der blev ikke fundet nogen filer for de valgte cirkler",
-    "You created the circle {circle}" : "Du oprettede cirklen {circle}",
-    "{author} created the circle {circle}" : "{author} oprettede cirklen {circle}",
-    "You added circle {member} as member to {circle}" : "Du tilføjede cirkel {member} som medlem i {circle}",
-    "{author} added circle {member} has been added as member to {circle}" : "{author] tilføjede cirkel {member} er blevet tilføjet som medlem i {circle}",
-    "You removed {member} leave {circle}" : "Du fjernede {member} forlad {circle}",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "Om begivenheder, der finder sted i en <strong>Circle</strong>, som du er medlem af ",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "Enhver vigtig begivenhed i en <strong>Circle</strong>, du modererer",
-    "On global events happening in any <strong>Circle</strong>" : "På globale begivenheder, der sker i enhver <strong>Circle</strong>",
-    "Join Request" : "Tilmeldingsanmodning",
-    "Password Protected" : "Adgangskodebeskyttet",
-    "Circle Invite" : "Cirkel invitation",
-    "Email Address" : "Email adresse",
-    "Circle not found" : "Cirklen blev ikke fundet",
-    "Circle not found " : "Cirklen blev ikke fundet",
-    "This account is already a member of the circle" : "Denne konto er allerede medlem af cirklen",
-    "Federated link not found" : "Fødereret link blev ikke fundet",
-    "The circle is not federated" : "Cirklen er ikke fødereret",
-    "You cannot join this circle" : "Du kan ikke forbinde med cirklen",
-    "This member is the owner of the circle" : "Dette medlem ejer cirklen",
-    "%s (Circle owned by %s)" : "%s (cirkel ejet af %s)",
-    "Personal Circle" : "Personlig cirkel",
-    "You need a specify a type of circle" : "Du skal angive en type cirkel",
-    "A circle with that name exists" : "Der findes en cirkel med det navn",
-    "This member is not the owner of the circle" : "Dette medlem ejer ikke cirklen",
-    "This member is not an admin of the circle" : "Dette medlem er ikke administrator af cirklen",
-    "Group contains too many members" : "Gruppen indeholder for mange medlemmer",
-    "This group does not exist" : "Denne gruppe eksisterer ikke",
-    "This group is already linked to the circle" : "Denne gruppe er allerede knyttet til cirklen",
-    "You cannot edit level in a personal circle" : "Du kan ikke redigere niveau i en personlig cirkel",
-    "Group cannot be set as owner of a circle" : "Gruppen kan ikke angives som ejer af en cirkel",
-    "now" : "nu",
-    "This account does not exist" : "Denne konto findes ikke",
-    "Email format is not valid" : "Email format er ugyldigt",
-    "This contact is not available" : "Denne kontakt er ikke tilgængelig ",
-    "You have no permission to create a new circle" : "Du har ikke tilladelse til at oprette en ny cirkel",
-    "This item is already shared with this circle" : "Dette element er allerede delt med denne cirkel",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Cirkler giver dine brugere mulighed for at oprette deres egne grupper af brugere/kolleger/venner.\nDisse grupper af brugere (eller \"cirkler\") kan derefter bruges af enhver anden app til delingsformål.",
-    "Teams' files" : "Teamets filer",
-    "Select team to filter by" : "Vælg team at filtrere efter",
-    "No teams found" : "Ingen teams fundet",
-    "Please select teams to filter by" : "Vælg venligst teams at filtrere efter",
-    "No files found for the selected teams" : "Inge filer funder for det valgte team",
-    "{author} added team {member} has been added as member to {circle}" : "{author} tilføjede team {member} er blevet tilføjet som medlem til {circle}"
+    "Shared to Circles" : "Delt til Cirkler"
 },
 "nplurals=2; plural=(n != 1);");
