@@ -1,9 +1,19 @@
 OC.L10N.register(
     "circles",
     {
+    "Teams" : "Ομάδες",
+    "You created the team {circle}" : "Δημιουργήσατε την ομάδα {circle}",
+    "{author} created the team {circle}" : "Ο/Η {author} δημιούργησε την ομάδα {circle}",
     "You deleted {circle}" : "Διαγράψατε τον {circle}",
     "{author} deleted {circle}" : "{author} διέγραψε {circle}",
+    "You made {member} join {circle}" : "Κάνατε τον/την {member} να γίνει μέλος του {circle}",
+    "{author} made {member} join {circle}" : "Ο/Η {author} έκανε τον/την {member} να γίνει μέλος του {circle}",
+    "You added team {member} as member to {circle}" : "Προσθέσατε την ομάδα {member} ως μέλος στο {circle}",
+    "{author} added team {member} as member to {circle}" : "Ο/Η {author} πρόσθεσε την ομάδα {member} ως μέλος στο {circle}",
+    "You made {member} leave {circle}" : "Κάνατε τον/την {member} να εγκαταλείψει το {circle}",
+    "{author} made {member} leave {circle}" : "Ο/Η {author} έκανε τον/την {member} να εγκαταλείψει το {circle}",
     "You removed {member} from {circle}" : "Απομακρύνατε {member} από {circle}",
+    "{author} removed {member} from {circle}" : "Ο/Η {author} αφαίρεσε τον/την {member} από τον {circle}",
     "You joined {circle}" : "Συμμετέχετε στον {circle}",
     "{member} joined {circle}" : "{member} συμμετέχει {circle}",
     "You accepted the invitation to join {circle}" : "Αποδεχθήκατε την πρόσκληση για να συμμετέχετε σε {circle}",
@@ -21,6 +31,7 @@ OC.L10N.register(
     "You declined the invitation to join {circle}" : "Απορρίψατε την πρόσκληση να συμμετάσχετε στο {circle}",
     "{member} declined an invitation to join {circle}" : " {member} δεν αποδέχτηκε την πρόσκληση για το {circle}",
     "You cancelled your request to join {circle}" : "Ακυρώσατε το αίτημα συμμετοχής στο {circle}",
+    "{member} cancelled a request to join {circle}" : "Ο/Η {member} ακύρωσε ένα αίτημα συμμετοχής στο {circle}",
     "You have been removed from {circle} by {author}" : "Απομακρυνθήκατε από {circle} από {author}",
     "{member} has been removed from {circle} by {author}" : "Ο/η {member} απομακρύνθηκε από {circle} από {author}",
     "You removed {external} from {circle}" : "Καταργήσατε το {external} από {circle}",
@@ -34,19 +45,23 @@ OC.L10N.register(
     "You invited {member} to join {circle}" : "Προσκαλέσατε τον {member} να συμμετέχει στο {circle}",
     "You have been invited to join {circle} by {author}" : "Προσκληθήκατε να συμμετέχετε στο {circle} από τον {author}",
     "{member} has been invited to join {circle} by {author}" : "Ο {member} προσκλήθηκε να συμμετέχει στο {circle} από τον {author}",
-    "You changed {member}'s level in {circle} to %1$s" : "Αλλάξατε {member}'ς επίπεδο στο {circle} σε %1$s",
+    "You changed {member}'s level in {circle} to %1$s" : "Αλλάξατε το επίπεδο του {member} στο {circle} σε %1$s",
     "{author} changed your level in {circle} to %1$s" : "{author} το επίπεδο σας στο {circle} σε %1$s",
-    "{author} changed {member}'s level in {circle} to %1$s" : "{author} άλλαξε {member}'ς επίπεδο στο {circle} σε %1$s ",
+    "{author} changed {member}'s level in {circle} to %1$s" : "Ο {author} άλλαξε το επίπεδο του {member} στο {circle} σε %1$s ",
     "You sent a request to join {circle}" : "Στείλατε αίτημα συμμετοχής στο {circle}",
     "{member} sent a request to join {circle}" : "Ο {member} έστειλε αίτημα συμμετοχής στο {circle}",
     "You are the new owner of {circle}" : "Είστε ο νέος κάτοχος του {circle}",
-    "{member} is the new owner of {circle}" : "{member} είναι ο νέος κάτοχος του {circle}",
+    "{member} is the new owner of {circle}" : "Ο/η {member} είναι ο νέος κάτοχος του {circle}",
+    "On events happening in a <strong>team</strong> of which you are a member" : "Για συμβάντα που συμβαίνουν σε μια <strong>ομάδα</strong> της οποίας είστε μέλος",
+    "Any important event in a <strong>team</strong> you are moderating" : "Οποιοδήποτε σημαντικό συμβάν σε μια <strong>ομάδα</strong> που διαχειρίζεστε",
+    "On global events happening in any <strong>team</strong>" : "Για καθολικά συμβάντα που συμβαίνουν σε οποιαδήποτε <strong>ομάδα</strong>",
     "Single" : "Μονός",
     "Personal" : "Προσωπικός",
     "System" : "Συστήματος",
     "Visible" : "Ορατός",
     "Open" : "Ανοιχτός",
     "Invite" : "Πρόσκληση",
+    "Join request" : "Αίτημα συμμετοχής",
     "Friends" : "Φίλοι",
     "Password protected" : "Προστασία με συνθηματικό",
     "No Owner" : "Χωρίς Κάτοχο",
@@ -54,13 +69,17 @@ OC.L10N.register(
     "Backend" : "Backend",
     "Local" : "Τοπικός",
     "Root" : "Ριζικός",
+    "Team invite" : "Πρόσκληση ομάδας",
     "Federated" : "Federated",
     "Mount point" : "Σημείο προσάρτησης",
     "Nextcloud Account" : "Λογαριασμός Nextcloud",
     "Nextcloud Group" : "Ομάδα Nextcloud",
     "Email address" : "Διεύθυνση αλληλογραφίας",
     "Contact" : "Επαφή",
-    "Nextcloud App" : "Nextcloud App",
+    "Team" : "Ομάδα",
+    "Nextcloud App" : "Εφαρμογή Nextcloud",
+    "Teams App" : "Εφαρμογή Ομάδας",
+    "Admin Command Line" : "Γραμμή Εντολών Διαχειριστή",
     "Member" : "Μέλος",
     "Moderator" : "Συντονιστής",
     "Admin" : "Διαχειριστής",
@@ -83,40 +102,62 @@ OC.L10N.register(
     "%s shared multiple files with \"%s\"." : "%s μοιράστηκε πολλαπλά αρχεία με \"%s\".",
     "%s shared multiple files with you." : "%s διαμοίρασε διάφορα αρχεία με σας.",
     "Boot up" : "Εκκίνηση",
+    "Nextcloud Initialization" : "Προετοιμασία Nextcloud",
+    "Circles App Initialization" : "Προετοιμασία Εφαρμογής Circles",
     "Fresh installation status" : "Κατάσταση νέας εγκατάστασης",
     "Building Local Database" : "Δημιουργία Τοπικής Βάσης Δεδομένων",
     "Testing Basic Circle Creation" : "Δοκιμή Βασικής Δημιουργίας Κύκλου",
     "Adding local users and moderators" : "Προσθήκη τοπικών χρηστών και συντονιστών",
+    "Show all teams" : "Εμφάνιση όλων των ομάδων",
+    "Create a new team" : "Δημιουργία νέας ομάδας",
     "Files" : "Αρχεία",
     "This feature is not available for personal circles" : "Αυτή η επιλογή δεν είναι διαθέσιμη για προσωπικούς κύκλους",
+    "The team is not federated" : "Η ομάδα δεν είναι federated",
+    "You cannot join this team" : "Δεν μπορείτε να συμμετάσχετε σε αυτήν την ομάδα",
     "This member is not a moderator" : "Αυτό το μέλος δεν είναι επιμελητής",
     "Insufficient privileges" : "Μη επαρκή δικαιώματα",
     "This member does not exist" : "Αυτό το μέλος δεν υπάρχει",
+    "This member is the owner of the team" : "Αυτό το μέλος είναι ο ιδιοκτήτης της ομάδας",
     "Level cannot be changed for this type of member" : "Το επίπεδο δεν μπορεί να αλλάξει για αυτόν τον τύπο χρηστών",
     "You are already a member of this circle" : "Είστε ήδη μέλος αυτού του κύκλου",
     "You have been blocked from this circle" : "Έχετε αποκλειστεί από αυτόν τον κύκλο",
     "The account is already a member of this circle" : "Ο λογαριασμός είναι ήδη μέλος του κύκλου",
     "The account has already been invited into this circle" : "Ο λογαριασμός έχει ήδη προσκληθεί για συμμετοχή στον κύκλο",
+    "%s (Team owned by %s)" : "%s (Ομάδα που ανήκει στον %s)",
+    "You are now a member of the Team \"%2$s\"" : "Είστε πλέον μέλος της Ομάδας \"%2$s\"",
+    "You have been invited by %1$s into the Team \"%2$s\"" : "Έχετε προσκληθεί από τον/την %1$s στην Ομάδα \"%2$s\"",
+    "%1$s sent a request to be a member of the Team \"%2$s\"" : "Ο/Η %1$s έστειλε αίτημα για να γίνει μέλος της Ομάδας \"%2$s\"",
     "Accept" : "Αποδοχή",
     "Refuse" : "Απόρριψη",
+    "Leave the team" : "Αποχώρηση από την ομάδα",
     "%s" : "%s",
+    "Personal team" : "Προσωπική ομάδα",
     "%s owned by %s" : "%s ανήκει στον %s",
+    "You have no permission to create a new team" : "Δεν έχετε δικαίωμα να δημιουργήσετε νέα ομάδα",
     "%s shared a file with \"%s\"." : "%s διαμοιράστηκε ένα αρχείο με \"%s\".",
     "%s shared a file with you." : "%s διαμοιράστηκε ένα αρχεία με εσάς.",
+    "%1$s shared %2$s with %3$s" : "Ο/Η %1$s διαμοιράστηκε %2$s με %3$s",
+    "%1$s shared %2$s with \"%3$s\"" : "Ο/Η %1$s διαμοιράστηκε %2$s με \"%3$s\"",
     "Open %s" : "Άνοιγμα %s",
     "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s μοιράστηκε περιεχόμενο με εσάς.\nΘα πρέπει να έχετε ήδη λάβει ένα ξεχωριστό mail με έναν σύνδεσμο με πρόσβαση σε αυτό.\n",
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s μοιράστηκε περιεχόμενο με εσάς. Θα πρέπει να έχετε ήδη λάβει ένα ξεχωριστό mail με έναν σύνδεσμο με πρόσβαση σε αυτό.",
     "Password to access content shared with you by %1$s" : "Συνθηματικό για πρόσβαση στα αρχεία που διαμοιράστηκε μαζί σας ο/η  %1$s",
     "Password to access content" : "Συνθηματικό για πρόσβαση στο περιεχόμενο",
+    "This item is already shared with this team" : "Αυτό το αντικείμενο είναι ήδη διαμοιρασμένο με αυτήν την ομάδα",
     "Bring cloud-users closer together." : "Φέρνει τους χρήστες του cloud πιο κοντά.",
+    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Οι Ομάδες επιτρέπουν στους χρήστες να δημιουργούν τις δικές τους ομάδες ατόμων/συναδέλφων/φίλων.\nΑυτές οι ομάδες ατόμων μπορούν στη συνέχεια να χρησιμοποιηθούν από οποιαδήποτε άλλη εφαρμογή για σκοπούς διαμοιρασμού.",
+    "Failed to load teams" : "Αποτυχία φόρτωσης ομάδων",
     "Try again" : "Δοκιμάστε ξανά",
+    "No teams found" : "Δεν βρέθηκαν ομάδες",
+    "Join or create teams to see them here." : "Γίνετε μέλος ή δημιουργήστε ομάδες για να τις δείτε εδώ.",
+    "Create your first team" : "Δημιουργήστε την πρώτη σας ομάδα",
     "Loading…" : "Γίνεται φόρτωση…",
+    "More teams" : "Περισσότερες ομάδες",
     "No files in here" : "Δεν υπάρχουν αρχεία εδώ",
     "No entries found in this folder" : "Δεν βρέθηκε καταχώρηση σε αυτόν τον φάκελο",
     "Name" : "Όνομα",
     "Size" : "Μέγεθος",
     "Modified" : "Τροποποιήθηκε",
-    "Shared to Circles" : "Κοινόχρηστο στους Κύκλους",
-    "Circle" : "Κύκλος"
+    "Shared to Circles" : "Κοινόχρηστο στους Κύκλους"
 },
 "nplurals=2; plural=(n != 1);");
