@@ -78,6 +78,8 @@ OC.L10N.register(
     "Contact" : "Contacto",
     "Team" : "Equipo",
     "Nextcloud App" : "App Nextcloud",
+    "Teams App" : "App Equipos",
+    "Admin Command Line" : "Línea de Comandos del Administrador",
     "Member" : "Participante",
     "Moderator" : "Moderador",
     "Admin" : "Administrador",
@@ -156,11 +158,6 @@ OC.L10N.register(
     "Name" : "Nombre",
     "Size" : "Tamaño",
     "Modified" : "Modificado",
-    "Teams' files" : "Archivos del equipo",
-    "Select team to filter by" : "Selecciona el equipo por el que filtrar",
-    "Please select teams to filter by" : "Por favor, seleccione los equipos por los que filtrar",
-    "No files found for the selected teams" : "No se encontraron archivos para los equipos seleccionados",
-    "Shared to Circles" : "Compartido con Círculos",
-    "Circle" : "Círculo"
+    "Shared to Circles" : "Compartido con Círculos"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
