@@ -4,28 +4,8 @@ declare(strict_types=1);
 
 
 /**
- * Circles - Bring cloud-users closer together.
- *
- * This file is licensed under the Affero General Public License version 3 or
- * later. See the COPYING file.
- *
- * @author Maxence Lange <maxence@artificial-owl.com>
- * @copyright 2021
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 
@@ -66,7 +46,7 @@ class CirclesQueryHelper {
 	 */
 	public function __construct(
 		CoreRequestBuilder $coreRequestBuilder,
-		FederatedUserService $federatedUserService
+		FederatedUserService $federatedUserService,
 	) {
 		$this->coreRequestBuilder = $coreRequestBuilder;
 		$this->federatedUserService = $federatedUserService;
@@ -95,7 +75,7 @@ class CirclesQueryHelper {
 	public function limitToSession(
 		string $alias,
 		string $field,
-		bool $fullDetails = false
+		bool $fullDetails = false,
 	): ICompositeExpression {
 		$session = $this->federatedUserService->getCurrentUser();
 		if (is_null($session)) {
@@ -133,7 +113,7 @@ class CirclesQueryHelper {
 		string $alias,
 		string $field,
 		IFederatedUser $federatedUser,
-		bool $fullDetails = false
+		bool $fullDetails = false,
 	): ICompositeExpression {
 		$this->queryBuilder->setDefaultSelectAlias($alias);
 		$this->queryBuilder->setOptions(
@@ -186,7 +166,7 @@ class CirclesQueryHelper {
 	 */
 	public function addCircleDetails(
 		string $alias,
-		string $field
+		string $field,
 	): void {
 		$this->queryBuilder->setDefaultSelectAlias($alias);
 		$this->queryBuilder->setOptions(
