@@ -385,120 +385,23 @@ OC.L10N.register(
     "Select all" : "Hautatu dena",
     "Upload too large" : "Igotzekoa handiegia da",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Igotzen saiatzen ari zaren fitxategiek zerbitzari honek onartzen duen gehienezko tamaina gainditzen dute.",
-    "File could not be found" : "Ezin izan da fitxategia aurkitu",
-    "Show list view" : "Erakutsi zerrenda ikuspegia",
-    "Show grid view" : "Erakutsi sareta ikuspegia",
-    "Close" : "Itxi",
-    "Could not create folder \"{dir}\"" : "Ezin izan da \"{dir}\" karpeta sortu",
-    "This will stop your current uploads." : "Honek martxan dauzkazun igoerak geldituko ditu.",
-    "Upload cancelled." : "Igotzea bertan behera utzi da.",
-    "Processing files …" : "Fitxategiak prozesatzen...",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ezin da {filename} igo karpeta bat delako edo 0 byte dituelako",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ez dago leku nahikorik, {size1} igotzen ari zara baina {size2} soilik daude libre",
-    "Target folder \"{dir}\" does not exist any more" : "\"{dir}\" helburuko karpeta ez da existitzen jadanik",
-    "An unknown error has occurred" : "Errore ezezagun bat gertatu da",
-    "File could not be uploaded" : "Fitxategia ezin izan da igo",
-    "Uploading …" : "Igotzen...",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Igotzen … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Ez da onartzen elementu hori igotzea",
-    "Error when assembling chunks, status code {status}" : "Errorea zatiak elkartzean, egoera kodea {status}",
-    "Choose target folder" : "Aukeratu helburuko karpeta",
-    "Set reminder" : "Ezarri gogorarazpena",
-    "Edit locally" : "Editatu lokalean",
-    "Open" : "Ireki",
-    "Could not load info for file \"{file}\"" : "Ezin izan da \"{file}\" fitxategiaren informazioa kargatu",
-    "Please select tag(s) to add to the selection" : "Hautatu etiketa(k) hautapenera gehitzeko",
-    "Apply tag(s) to selection" : "Aplikatu etiketa(k) hautapenari",
-    "Select directory \"{dirName}\"" : "Hautatu \"{dirName}\" direktorioa",
-    "Select file \"{fileName}\"" : "Hautatu \"{fileName}\" fitxategia",
-    "Unable to determine date" : "Ezin izan da data zehaztu",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Direktorio hau ez dago erabilgarri, egiaztatu egunkariak edo jarri administratzailearekin harremanetan",
-    "Could not move \"{file}\", target exists" : "Ezin izan da \"{file}\" lekuz aldatu, helburua existitzen da jadanik",
-    "Could not move \"{file}\"" : "Ezin izan da \"{file}\" lekuz aldatu",
-    "copy" : "kopiatu",
-    "Could not copy \"{file}\", target exists" : "Ezin izan da \"{file}\" kopiatu; helburua existitzen da",
-    "Could not copy \"{file}\"" : "Ezin izan da \"{file}\" kopiatu",
-    "Copied {origin} inside {destination}" : "{origin} kopiatu da {destination} barruan",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} eta beste {nbfiles} fitxategi {destination} barruan kopiatu dira",
-    "{newName} already exists" : "{newName} existitzen da dagoeneko",
-    "Could not create file \"{file}\"" : "Ezin izan da \"{file}\" fitxategia sortu",
-    "Could not create file \"{file}\" because it already exists" : "Ezin izan da \"{file}\" fitxategia sortu, dagoeneko existitzen delako",
-    "Could not create folder \"{dir}\" because it already exists" : "Ezin izan da \"{dir}\" karpeta sortu, dagoeneko existitzen delako",
-    "Could not fetch file details \"{file}\"" : "Ezin izan dira \"{file}\" fitxategiaren xehetasunak eskuratu",
-    "Error deleting file \"{fileName}\"." : "Errorea \"{fileName}\" fitxategia ezabatzerakoan.",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Ez da '{tag}{filter}{endtag}' bilaketarako emaitzarik aurkitu beste karpetetan",
-    "Enter more than two characters to search in other folders" : "Sartu bi karaktere baino gehiago beste karpetetan bilatu ahal izateko",
-    "{dirs} and {files}" : "{dirs} eta {files}",
-    "_including %n hidden_::_including %n hidden_" : ["ezkutuko %n barne","ezkutuko %n barne"],
-    "You do not have permission to upload or create files here" : "Ez duzu hemen fitxategiak igotzeko edo sortzeko baimenik",
-    "_Uploading %n file_::_Uploading %n files_" : ["Fitxategi %n kargatzen","%n fitxategi igotzen"],
-    "New" : "Berria",
-    "New file/folder menu" : "Fitxategi/karpeta berri menua",
-    "Select file range" : "Hautatu fitxategi-barrutia",
-    "{used}%" : "%{used}",
-    "{used} used" : "{used} erabilita",
-    "\"{name}\" is an invalid file name." : "\"{name}\" fitxategi-izen baliogabea da.",
-    "File name cannot be empty." : "Fitxategi-izena ezin da hutsa izan.",
-    "\"/\" is not allowed inside a file name." : "\"/\" ez da onartzen fitxategi-izenen barnean.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" fitxategi-mota ez da onartzen",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} erabiltzailearen biltegia beteta dago, fitxategiak ezin dira jada eguneratu edo sinkronizatu!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "\"{mountPoint}\" taldeko karpeta beteta dago, fitxategiak ezin dira eguneratu edo sinkronizatu!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "\"{mountPoint}\" kanpoko biltegia beteta dago, fitxategiak ezin dira eguneratu edo sinkronizatu!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Zure biltegiratzea beteta dago, fitxategiak ezin dira eguneratu edo sinkronizatu!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner}-(r)en biltegia betetzear dago ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" talde karpeta betetzear dago ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" kanpoko biltegia betetzear dago ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Zure biltegia betetzear dago ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["\"{filter}\" emaitza","\"{filter}\" emaitza"],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Esteka zuzena kopiatu da (fitxategi/karpeta honetara sarbidea dutenentzat bakarrik balio du)",
-    "Path" : "Bidea",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
-    "Favored" : "Mesedetua",
-    "Favor" : "Mesedea",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Kopiatu esteka zuzena (fitxategi/karpeta honetara sarbidea dutenentzat bakarrik balio du)",
-    "Upload file" : "Igo fitxategia",
-    "Not favored" : "Mesedetu gabe",
-    "An error occurred while trying to update the tags" : "Errore bat gertatu da etiketak eguneratzen saiatzean",
+    "%1$s (renamed)" : "%1$s (berrizendatua)",
+    "renamed file" : "fitxategia berrizendatu da",
     "Upload (max. %s)" : "Igo (%s gehienez)",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" ekintza behar bezala exekutatu da",
-    "\"{displayName}\" action failed" : "\"{displayName}\" ekintzak huts egin du",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows-ekin bateragarriak diren fitxategi-izenak gaitu ondoren, lehendik dauden fitxategiak ezin dira gehiago aldatu, baina jabeak baliozko izen berria jar diezaieke.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Fitxategiak automatikoki migratu daitezke ezarpen hau gaitu ondoren. Kontsultatu occ komandoari buruzko dokumentazioa.",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\"-k huts egin du zenbait elementutan",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" multzoko ekintza behar bezala exekutatu da",
-    "Submitting fields…" : "Eremuak bidaltzen…",
-    "Filter filenames…" : "Iragazi fitxategi-izenak...",
+    "\"{displayName}\" action failed" : "\"{displayName}\" ekintzak huts egin du",
+    "Submitting fields …" : "Bidaltzeko eremuak",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" ekintza behar bezala exekutatu da",
+    "Filter file names …" : "Iragazi fitxategien izenak...",
     "WebDAV URL copied to clipboard" : "WebDAV URLa arbelean kopiatu da",
     "Enable the grid view" : "Gaitu sareta ikuspegira",
     "Enable folder tree" : "Gaitu karpeta-zuhaitza",
     "Copy to clipboard" : "Kopiatu arbelera",
     "Use this address to access your Files via WebDAV" : "Erabili helbide hau WebDAV bidez zure fitxategietara sartzeko",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2FA gaitu baduzu, aplikazioaren pasahitz berria sortu eta erabili behar duzu hemen klik eginez.",
-    "Deletion cancelled" : "Ezabatzea bertan behera utzi da",
-    "Moving \"{source}\" to \"{destination}\" …" : "«{source}» «{destination}»(e)ra mugitzen",
-    "Copying \"{source}\" to \"{destination}\" …" : "«{source}» «{destination}»(e)ra mugitzen",
-    "Move cancelled" : "Mugimendua bertan behera utzi da",
-    "Cancelled move or copy of \"{filename}\"." : "\"{filename}\" -ren mugimendua edo kopia bertan behera utzi da.",
-    "Cancelled move or copy operation" : "Mugitze edo kopiatze operazioa utzi da",
-    "Open details" : "Ireki xehetasunak",
-    "Photos and images" : "Argazkiak eta irudiak",
-    "New folder creation cancelled" : "Karpeta berrien sorrera bertan behera utzi da",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["Karpeta {folderCount}","{folderCount} karpeta"],
-    "_{fileCount} file_::_{fileCount} files_" : ["Fitxategi {fileCount}","{fileCount} fitxategi"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["Fitxategi 1 eta karpeta {folderCount}","Fitxategi 1 eta {folderCount} karpeta"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["Fitxategi {fileCount} eta karpeta 1","{fileCount} fitxategi eta karpeta 1"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} fitxategi eta {folderCount} fitxategi",
-    "All folders" : "Karpeta guztiak",
-    "Personal Files" : "Fitxategi pertsonalak",
-    "Text file" : "Testu-fitxategia",
-    "New text file.txt" : "Testu-fitxategi berria.txt",
-    "%1$s (renamed)" : "%1$s (berrizendatua)",
-    "renamed file" : "fitxategia berrizendatu da",
-    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows-ekin bateragarriak diren fitxategi-izenak gaitu ondoren, lehendik dauden fitxategiak ezin dira gehiago aldatu, baina jabeak baliozko izen berria jar diezaieke.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Fitxategiak automatikoki migratu daitezke ezarpen hau gaitu ondoren. Kontsultatu occ komandoari buruzko dokumentazioa.",
-    "Submitting fields …" : "Bidaltzeko eremuak",
-    "Filter file names …" : "Iragazi fitxategien izenak...",
     "Prevent warning dialogs from open or reenable them." : "Ohar-elkarrizketak ez irekitzea edo berriro aktibatzea.",
     "Show a warning dialog when changing a file extension." : "Erakutsi oharra fitxategi baten luzapena aldatzean",
     "Speed up your Files experience with these quick shortcuts." : "Azkartu zure Fitxategi esperientzia lasterbide bizkor hauekin",
@@ -520,6 +423,18 @@ OC.L10N.register(
     "Save as …" : "Gorde honela...",
     "Converting files …" : "Fitxategiak bihurtzen...",
     "Converting file …" : "Fitxategia bihurtzen...",
+    "Deletion cancelled" : "Ezabatzea bertan behera utzi da",
+    "Edit locally" : "Editatu lokalean",
+    "Moving \"{source}\" to \"{destination}\" …" : "«{source}» «{destination}»(e)ra mugitzen",
+    "Copying \"{source}\" to \"{destination}\" …" : "«{source}» «{destination}»(e)ra mugitzen",
+    "Move cancelled" : "Mugimendua bertan behera utzi da",
+    "Cancelled move or copy of \"{filename}\"." : "\"{filename}\" -ren mugimendua edo kopia bertan behera utzi da.",
+    "Cancelled move or copy operation" : "Mugitze edo kopiatze operazioa utzi da",
+    "Open details" : "Ireki xehetasunak",
+    "Photos and images" : "Argazkiak eta irudiak",
+    "New folder creation cancelled" : "Karpeta berrien sorrera bertan behera utzi da",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Direktorio hau ez dago erabilgarri, egiaztatu egunkariak edo jarri administratzailearekin harremanetan",
+    "All folders" : "Karpeta guztiak",
     "Search everywhere …" : "Bilatu nonahi...",
     "Search here …" : "Bilatu hemen...",
     "Preparing …" : "Prestatzen..."
