@@ -51,6 +51,10 @@ OC.L10N.register(
     "You do not have permission to create a file at the specified location" : "Non hai l'autorizzazione per creare un file nella posizione specificata",
     "The file could not be converted." : "Il file non può essere convertito.",
     "Could not get relative path to converted file" : "Impossibile ottenere il percorso relativo al file convertito",
+    "Limit must be a positive integer." : "Il limite deve essere un numero intero positivo.",
+    "The replacement character may only be a single character." : "Il carattere sostitutivo può essere un solo carattere.",
+    "Filename sanitization already started." : "La sanificazione del nome file è già iniziata.",
+    "No filename sanitization in progress." : "Nessuna sanificazione del nome file in corso.",
     "Favorite files" : "File preferiti",
     "No favorites" : "Nessun preferito",
     "More favorites" : "Altri preferiti",
@@ -68,12 +72,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Il trasferimento di proprietà di {path} da {user} è completato.",
     "in %s" : "in %s",
     "Transferred from %1$s on %2$s" : "Trasferito da %1$s su %2$s",
-    "Files compatibility" : "Compatibilità di File",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Consenti di limitare i nomi di file per assicurarsi che i file vengano sincronizzati con tutti i client. In modo predefinito, tutti i nomi di file validi su POSIX (es. Linux o macOS) sono consentiti.",
-    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Dopo aver abilitato i nomi file compatibili con Windows, i file esistenti non potranno più essere modificati, ma potranno essere rinominati con nuovi nomi validi dal rispettivo proprietario.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "È anche possibile migrare i file automaticamente dopo aver abilitato questa impostazione; fare riferimento alla documentazione relativa al comando occ.",
-    "Enforce Windows compatibility" : "Imponi la compatibilità con Windows",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ciò bloccherà i nomi di file non validi sui sistemi Windows, come l'uso di nomi riservati o caratteri speciali. Tuttavia non verrà imposta la compatibilità con le maiuscole/minuscole.",
     "File Management" : "Gestione dei file",
     "Home" : "Home",
     "Target folder does not exist any more" : "La cartella di destinazione non esiste più",
@@ -82,7 +80,7 @@ OC.L10N.register(
     "Current directory path" : "Percorso della cartella corrente",
     "Your have used your space quota and cannot upload files anymore" : "Hai esaurito la tua quota di spazio e non puoi più caricare file",
     "You do not have permission to upload or create files here." : "Non hai l'autorizzazione per caricare o creare file qui.",
-    "Drag and drop files here to upload" : "Trascina i file qui per caricarli",
+    "Drag and drop files here to upload" : "Trascina e rilascia i file qui per caricarli",
     "Favorite" : "Preferito",
     "Back" : "Indietro",
     "Toggle selection for file \"{displayName}\"" : "Attiva/disattiva la selezione per il file \"{displayName}\"",
@@ -115,9 +113,9 @@ OC.L10N.register(
     "Name" : "Nome",
     "File type" : "Tipo di file",
     "Size" : "Dimensione",
-    "\"{displayName}\" failed on some elements" : "\"{displayName}\" non riuscito su alcuni elementi",
-    "\"{displayName}\" batch action executed successfully" : "L'azione batch \"{displayName}\" è stata eseguita correttamente",
-    "\"{displayName}\" action failed" : "L'azione \"{displayName}\" non è riuscita",
+    "{displayName}: failed on some elements" : "{displayName}: non riuscito su alcuni elementi",
+    "{displayName}: done" : "{displayName}: fatto",
+    "{displayName}: failed" : "{displayName}: non riuscito",
     "Actions" : "Azioni",
     "(selected)" : "(selezionato)",
     "List of files and folders." : "Lista di file e cartelle.",
@@ -126,10 +124,10 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Questa lista non è stata mostrata completamente per ragioni di prestazioni. I file verranno mostrati durante la navigazione della lista.",
     "File not found" : "File non trovato",
     "_{count} selected_::_{count} selected_" : ["{count} selezionato","{count} selezionati","{count} selezionati"],
-    "Search globally by filename …" : "Cerca globalmente per nome file…",
-    "Search here by filename …" : "Cerca qui per nome file…",
+    "Search everywhere …" : "Cerca ovunque …",
+    "Search here …" : "Cerca qui …",
     "Search scope options" : "Opzioni nell'ambito di ricerca",
-    "Search globally" : "Cerca globalmente",
+    "Search here" : "Cerca qui",
     "{usedQuotaByte} used" : "{usedQuotaByte} usato",
     "{used} of {quota} used" : "{used} di {quota} utilizzati",
     "{relative}% used" : "{relative}% usato",
@@ -141,8 +139,27 @@ OC.L10N.register(
     "Create new folder" : "Crea una nuova cartella",
     "This name is already in use." : "Questo nome è già utilizzato.",
     "Create" : "Crea",
+    "Files starting with a dot are hidden by default" : "I file che iniziano con un punto sono nascosti per impostazione predefinita",
+    "Failed to start filename sanitization." : "Impossibile avviare la sanificazione del nome file.",
+    "Failed to refresh filename sanitization status." : "Impossibile aggiornare lo stato di sanificazione del nome file.",
+    "Filename sanitization in progress." : "Sanificazione del nome del file in corso.",
+    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Attualmente {processedUsers} di{totalUsers} account sono già stati elaborati.",
+    "Preparing …" : "Preparazione …",
+    "Refresh" : "Aggiorna",
+    "All files have been santized for Windows filename support." : "Tutti i file sono stati abilitati per supportare i nomi file di Windows.",
+    "Some files could not be sanitized, please check your logs." : "Alcuni file non possono essere ripuliti, controlla i tuoi log.",
+    "Sanitization errors" : "Errori di sanificazione",
+    "Not sanitized filenames" : "Nomi di file non sanificati",
+    "Windows filename support has been enabled." : "È stato abilitato il supporto per i nomi file di Windows.",
+    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Sebbene ciò impedisca agli utenti di creare nuovi file con nomi non supportati, i file esistenti non sono ancora stati rinominati e pertanto potrebbero comunque interrompere la sincronizzazione su Windows.",
+    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "È possibile attivare la ridenominazione dei file con nomi non validi; questa operazione verrà eseguita in background e potrebbe richiedere del tempo.",
+    "Please note that this may cause high workload on the sync clients." : "Si prega di notare che ciò potrebbe causare un carico di lavoro elevato sui client di sincronizzazione.",
+    "Limit" : "Limite",
+    "This allows to configure how many users should be processed in one background job run." : "Ciò consente di configurare quanti utenti devono essere elaborati in un'esecuzione di un processo in background.",
+    "Sanitize filenames" : "Sanificare i nomi dei file",
+    "(starting)" : "(iniziando)",
     "Fill template fields" : "Compila i campi del modello",
-    "Submitting fields …" : "Invio dei campi …",
+    "Submitting fields …" : "Invio dei campi …",
     "Submit" : "Invia",
     "Choose a file or folder to transfer" : "Scegli file o cartella da trasferire",
     "Transfer" : "Trasferisci",
@@ -166,6 +183,51 @@ OC.L10N.register(
     "Do not show this dialog again." : "Non visualizzare più questa finestra di dialogo.",
     "Select file or folder to link to" : "Seleziona un file o una cartella da collegare",
     "Choose {file}" : "Scegli {file}",
+    "Clipboard is not available" : "Appunti non disponibili",
+    "WebDAV URL copied" : "URL WebDAV copiato",
+    "Files settings" : "Impostazioni File",
+    "General" : "Generale",
+    "Default view" : "Vista predefinita",
+    "All files" : "Tutti i file",
+    "Personal files" : "File personali",
+    "Sort favorites first" : "Ordina prima i preferiti",
+    "Sort folders before files" : "Ordina cartelle prima dei files",
+    "Folder tree" : "Albero delle cartella",
+    "Appearance" : "Aspetto",
+    "Show hidden files" : "Mostra i file nascosti",
+    "Show file type column" : "Mostra colonna tipo di file",
+    "Show file extensions" : "Mostra estensioni di file",
+    "Crop image previews" : "Ritaglia le anteprime delle immagini",
+    "Additional settings" : "Impostazioni aggiuntive",
+    "WebDAV" : "WebDAV",
+    "WebDAV URL" : "URL WebDAV",
+    "Copy" : "Copia",
+    "How to access files using WebDAV" : "Come accedere ai file tramite WebDAV",
+    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Per il tuo account è abilitata l'autenticazione a due fattori, pertanto devi utilizzare una password dell'app per connetterti a un client WebDAV esterno.",
+    "Warnings" : "Avvertenze",
+    "Warn before changing a file extension" : "Avvisa prima di modificare l'estensione di un file",
+    "Warn before deleting files" : "Avvisa prima di eliminare i file",
+    "Keyboard shortcuts" : "Scorciatoie da tastiera",
+    "File actions" : "Azioni sui file",
+    "Rename" : "Rinomina",
+    "Delete" : "Elimina",
+    "Add or remove favorite" : "Aggiungi o rimuovi preferito",
+    "Manage tags" : "Gestisci etichette",
+    "Selection" : "Selezione",
+    "Select all files" : "Seleziona tutti i file",
+    "Deselect all" : "Deseleziona tutto",
+    "Select or deselect" : "Seleziona o deseleziona",
+    "Select a range" : "Seleziona un intervallo",
+    "Navigation" : "Navigazione",
+    "Go to parent folder" : "Vai alla cartella padre",
+    "Go to file above" : "Vai al file sopra",
+    "Go to file below" : "Vai al file sotto",
+    "Go left in grid" : "Vai a sinistra nella griglia",
+    "Go right in grid" : "Vai a destra nella griglia",
+    "View" : "Visualizza",
+    "Toggle grid view" : "Commuta la vista a griglia",
+    "Open file sidebar" : "Apri la barra laterale del file",
+    "Show those shortcuts" : "Mostra quelle scorciatoie",
     "Share" : "Condividi",
     "Shared by link" : "Condivisi tramite collegamento",
     "Shared" : "Condiviso",
@@ -178,62 +240,12 @@ OC.L10N.register(
     "Error during upload: {message}" : "Errore durante il caricamento: {message}",
     "Error during upload, status code {status}" : "Errore durante il caricamento, codice di stato {status}",
     "Unknown error during upload" : "Errore sconosciuto durante il caricamento",
-    "\"{displayName}\" action executed successfully" : "L'azione \"{displayName}\" è stata eseguita correttamente",
     "Loading current folder" : "Sto caricando la cartella corrente",
     "Retry" : "Riprova",
     "No files in here" : "Qui non c'è alcun file",
     "Upload some content or sync with your devices!" : "Carica dei contenuti o sincronizza con i tuoi dispositivi!",
     "Go back" : "Indietro",
     "Views" : "Viste",
-    "Files settings" : "Impostazioni File",
-    "Your files" : "I tuoi files",
-    "Open in files" : "Apri in file",
-    "File cannot be accessed" : "Il file non possono essere acceduti",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Impossibile trovare il file oppure non disponi dei permessi per visualizzarlo. Chiedi al mittente di condividerlo.",
-    "No search results for “{query}”" : "Nessun risultato di ricerca per “{query}”",
-    "Search for files" : "Cerca file",
-    "Clipboard is not available" : "Appunti non disponibili",
-    "WebDAV URL copied to clipboard" : "L'URL WebDAV è stato copiato negli appunti",
-    "Default view" : "Vista predefinita",
-    "All files" : "Tutti i file",
-    "Personal files" : "File personali",
-    "Sort favorites first" : "Ordina prima i preferiti",
-    "Sort folders before files" : "Ordina cartelle prima dei files",
-    "Show hidden files" : "Mostra i file nascosti",
-    "Show file type column" : "Mostra colonna tipo di file",
-    "Crop image previews" : "Ritaglia le anteprime delle immagini",
-    "Enable folder tree" : "Abilita l'albero delle cartelle",
-    "Additional settings" : "Impostazioni aggiuntive",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "URL WebDAV",
-    "Copy to clipboard" : "Copia negli appunti",
-    "Use this address to access your Files via WebDAV" : "Usa questo indirizzo per accedere ai tuoi file con WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Se hai abilitato il 2FA, devi creare ed usare una nuova password per l'applicazione facendo clic qui.",
-    "Warnings" : "Avvertenze",
-    "Prevent warning dialogs from open or reenable them." : "Impedire l'apertura delle finestre di dialogo di avviso o riattivarle.",
-    "Show a warning dialog when changing a file extension." : "Mostra una finestra di dialogo di avviso quando si modifica l'estensione di un file.",
-    "Keyboard shortcuts" : "Scorciatoie da tastiera",
-    "Speed up your Files experience with these quick shortcuts." : "Velocizza la tua esperienza con i File con queste rapide scorciatoie.",
-    "Open the actions menu for a file" : "Aprire il menu delle azioni per un file",
-    "Rename a file" : "Rinominare un file",
-    "Delete a file" : "Eliminare un file",
-    "Favorite or remove a file from favorites" : "Aggiungere ai Preferiti o rimuovere un file dai preferiti",
-    "Manage tags for a file" : "Gestire i tag per un file",
-    "Selection" : "Selezione",
-    "Select all files" : "Seleziona tutti i file",
-    "Deselect all files" : "Deseleziona tutti i file",
-    "Select or deselect a file" : "Seleziona o deseleziona un file",
-    "Select a range of files" : "Seleziona un intervallo di file",
-    "Navigation" : "Navigazione",
-    "Navigate to the parent folder" : "Passare alla cartella padre",
-    "Navigate to the file above" : "Vai al file sopra",
-    "Navigate to the file below" : "Vai al file qui sotto",
-    "Navigate to the file on the left (in grid mode)" : "Navigare nel file a sinistra (in modalità griglia)",
-    "Navigate to the file on the right (in grid mode)" : "Navigare nel file a destra (in modalità griglia)",
-    "View" : "Visualizza",
-    "Toggle the grid view" : "Attiva la vista a griglia",
-    "Open the sidebar for a file" : "Aprire la barra laterale per un file",
-    "Show those shortcuts" : "Mostra quelle scorciatoie",
     "You" : "Tu",
     "Shared multiple times with different people" : "Condiviso più volte con diverse persone",
     "Unable to change the favorite state of the file" : "Impossibile modificare lo stato preferito del file",
@@ -242,14 +254,26 @@ OC.L10N.register(
     "Remove from favorites" : "Rimuovi dai preferiti",
     "Add to favorites" : "Aggiungi ai preferiti",
     "Tags" : "Etichette",
+    "Your files" : "I tuoi files",
+    "Open in files" : "Apri in file",
+    "File cannot be accessed" : "Il file non possono essere acceduti",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Impossibile trovare il file oppure non disponi dei permessi per visualizzarlo. Chiedi al mittente di condividerlo.",
+    "No search results for “{query}”" : "Nessun risultato di ricerca per “{query}”",
+    "Search for files" : "Cerca file",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Consenti di limitare i nomi di file per assicurarsi che i file vengano sincronizzati con tutti i client. In modo predefinito, tutti i nomi di file validi su POSIX (es. Linux o macOS) sono consentiti.",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Dopo aver abilitato i nomi file compatibili con Windows, i file esistenti non potranno più essere modificati, ma potranno essere rinominati con nuovi nomi validi dal rispettivo proprietario.",
+    "Failed to toggle Windows filename support" : "Impossibile attivare il supporto per i nomi file di Windows",
+    "Files compatibility" : "Compatibilità di File",
+    "Enforce Windows compatibility" : "Imponi la compatibilità con Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ciò bloccherà i nomi di file non validi sui sistemi Windows, come l'uso di nomi riservati o caratteri speciali. Tuttavia non verrà imposta la compatibilità con le maiuscole/minuscole.",
     "Blank" : "Vuoto",
     "Unable to create new file from template" : "Impossibile creare un nuovo file dal modello",
     "Pick a template for {name}" : "Scegli un modello per {name}",
     "Create a new file with the selected template" : "Crea un nuovo file con il modello selezionato",
     "Creating file" : "Creazione del file",
     "Save as {displayName}" : "Savlva come {displayName}",
-    "Save as …" : "Salva come …",
-    "Converting files …" : "Conversione dei file …",
+    "Save as …" : "Salva come …",
+    "Converting files …" : "Conversione dei file …",
     "Failed to convert files: {message}" : "Impossibile convertire i file: {message}",
     "All files failed to be converted" : "Non è stato possibile convertire tutti i file",
     "One file could not be converted: {message}" : "Un file non può essere convertito: {message}",
@@ -257,11 +281,10 @@ OC.L10N.register(
     "_One file successfully converted_::_%n files successfully converted_" : ["Un file convertito correttamente","%nfile convertiti con successo","%n file convertiti con successo"],
     "Files successfully converted" : "File convertiti con successo",
     "Failed to convert files" : "Impossibile convertire i file",
-    "Converting file …" : "Conversione del file …",
+    "Converting file …" : "Conversione del file …",
     "File successfully converted" : "File convertito con successo",
     "Failed to convert file: {message}" : "Impossibile convertire il file: {message}",
     "Failed to convert file" : "Impossibile convertire il file",
-    "Deletion cancelled" : "Eliminazione annullata",
     "Leave this share" : "Abbandona questa condivisione",
     "Leave these shares" : "Abbandona queste condivisioni",
     "Disconnect storage" : "Disconnetti archiviazione",
@@ -272,32 +295,29 @@ OC.L10N.register(
     "Delete files" : "Elimina i file",
     "Delete folder" : "Elimina cartella",
     "Delete folders" : "Elimina la cartella",
-    "Delete" : "Elimina",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Stai per eliminare permanentemente {count} elemento","Stai per eliminare permanentemente {count} elementi","Stai per eliminare permanentemente {count} elementi"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Stai per eliminare {count} elemento","Stai per eliminare {count} elementi","Stai per eliminare {count} elementi"],
     "Confirm deletion" : "Conferma l'eliminazione",
     "Cancel" : "Annulla",
     "Download" : "Scarica",
-    "Moving \"{source}\" to \"{destination}\" …" : "Sposta \"{source}\" in \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Copia \"{source}\" in \"{destination}\" …",
+    "The requested file is not available." : "Il file richiesto non è disponibile.",
+    "The requested files are not available." : "I file richiesti non sono disponibili.",
+    "Moving \"{source}\" to \"{destination}\" …" : "Spostare \"{source}\" in \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copiare \"{source}\" in \"{destination}\" …",
     "Destination is not a folder" : "La destinazione non è una cartella",
     "This file/folder is already in that directory" : "Questo file/cartella è già in quella cartella",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Non puoi spostare un file/cartella in se stesso o in una sottocartella di se stesso",
     "(copy)" : "(copia)",
     "(copy %n)" : "(copia %n)",
-    "Move cancelled" : "Spostamento cancellato",
     "A file or folder with that name already exists in this folder" : "Esiste già un file o una cartella con quel nome in questa cartella",
     "The files are locked" : "I files sono bloccati",
     "The file does not exist anymore" : "Il file non esiste più",
     "Choose destination" : "Scegli la destinazione",
     "Copy to {target}" : "Copia in {target}",
-    "Copy" : "Copia",
     "Move to {target}" : "Sposta in {target}",
     "Move" : "Sposta",
     "Move or copy operation failed" : "Operazione di spostamento o copia fallita",
     "Move or copy" : "Sposta o copia",
-    "Cancelled move or copy of \"{filename}\"." : "Spostamento o copia di \"{filename}\" annullato.",
-    "Cancelled move or copy operation" : "Operazione di spostamento o copia annullata",
     "Open folder {displayName}" : "Apri la cartella {displayName}",
     "Open in Files" : "Apri in File",
     "Open locally" : "Aprire localmente",
@@ -306,8 +326,7 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Il file dovrebbe ora aprirsi sul tuo dispositivo. In caso contrario, controlla di aver installato l'app desktop.",
     "Retry and close" : "Riprova e chiudi",
     "Open online" : "Apri online",
-    "Rename" : "Rinomina",
-    "Open details" : "Apri i dettagli",
+    "Details" : "Dettagli",
     "View in folder" : "Visualizza nella cartella",
     "Today" : "Ogg",
     "Last 7 days" : "Ultimi 7 giorni",
@@ -320,17 +339,17 @@ OC.L10N.register(
     "PDFs" : "PDF",
     "Folders" : "Cartelle",
     "Audio" : "Audio",
-    "Photos and images" : "Foto e immagini",
+    "Images" : "Immagini",
     "Videos" : "Video",
-    "New folder creation cancelled" : "Creazione nuova cartella annullata",
     "Created new folder \"{name}\"" : "Crea una nuova cartella \"{name}\"",
     "Unable to initialize the templates directory" : "Impossibile inizializzare la cartella dei modelli",
     "Create templates folder" : "Crea cartella dei modelli",
     "Templates" : "Modelli",
     "New template folder" : "Nuova cartella dei modelli",
     "In folder" : "Nella cartella",
+    "Search in all files" : "Cerca in tutti i file",
     "Search in folder: {folder}" : "Cerca nella cartella: {folder}",
-    "One of the dropped files could not be processed" : "Impossibile elaborare uno dei file eliminati",
+    "One of the dropped files could not be processed" : "Impossibile elaborare uno dei file depositati",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Il tuo browser non supporta l'API del file system. Le directory non verranno caricate",
     "No files to upload" : "Nessun file da caricare",
     "Unable to create the directory {directory}" : "Impossibile creare la directory {directory}",
@@ -347,7 +366,7 @@ OC.L10N.register(
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Il nome \"{newName}\" è attualmente in uso nella cartella \"{dir}\". Scegli un nome diverso.",
     "Could not rename \"{oldName}\"" : "Impossibile rinominare \"{oldName}\"",
     "This operation is forbidden" : "Questa operazione è vietata",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Questa cartella non è disponibile, controlla i log o contatta l'amministratore",
+    "This folder is unavailable, please try again later or contact the administration" : "Questa cartella non è disponibile, riprova più tardi o contatta l'amministrazione",
     "Storage is temporarily not available" : "L'archiviazione è temporaneamente non disponibile",
     "Unexpected error: {error}" : "Errore imprevisto: {error}",
     "_%n file_::_%n files_" : ["%n file","%n file","%n file"],
@@ -362,7 +381,6 @@ OC.L10N.register(
     "No favorites yet" : "Nessun preferito ancora",
     "Files and folders you mark as favorite will show up here" : "I file e le cartelle che marchi come preferiti saranno mostrati qui",
     "List of your files and folders." : "Lista dei tuoi file e cartelle.",
-    "All folders" : "Tutte le cartelle",
     "List of your files and folders that are not shared." : "Elenco dei file e delle cartelle che non sono condivisi.",
     "No personal files found" : "Nessun file personale trovato",
     "Files that are not shared will show up here." : "I file che non vengono condivisi verranno visualizzati qui.",
@@ -376,98 +394,58 @@ OC.L10N.register(
     "Select all" : "Seleziona tutto",
     "Upload too large" : "Caricamento troppo grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "I file che stai provando a caricare superano la dimensione massima consentita su questo server.",
-    "File could not be found" : "Il file non può essere trovato",
-    "Show list view" : "Mostra la vista elenco",
-    "Show grid view" : "Mostra la visualizzazione griglia",
-    "Close" : "Chiudi",
-    "Could not create folder \"{dir}\"" : "Impossibile creare la cartella \"{dir}\"",
-    "This will stop your current uploads." : "Questo fermerà i caricamenti attuali.",
-    "Upload cancelled." : "Caricamento annullato.",
-    "Processing files …" : "Elaborazione file in corso…",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossibile caricare {filename} poiché è una cartella oppure ha una dimensione di 0 byte",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spazio insufficiente, stai caricando {size1}, ma è rimasto solo {size2}",
-    "Target folder \"{dir}\" does not exist any more" : "La cartella di destinazione \"{dir}\" non esiste più",
-    "An unknown error has occurred" : "Si è verificato un errore sconosciuto",
-    "File could not be uploaded" : "Il file non può essere caricato",
-    "Uploading …" : "Caricamento in corso...",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Caricamento … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} di {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Il caricamento di tale elemento non è supportato",
-    "Error when assembling chunks, status code {status}" : "Errore durante l'assemblaggio dei blocchi, codice di stato {status}",
-    "Choose target folder" : "Scegli la cartella di destinazione",
-    "Set reminder" : "Imposta promemoria",
-    "Edit locally" : "Modifica localmente",
-    "Open" : "Apri",
-    "Could not load info for file \"{file}\"" : "Impossibile caricare le informazioni per il file \"{file}\"",
-    "Details" : "Dettagli",
-    "Please select tag(s) to add to the selection" : "Seleziona un'etichetta(e) da aggiungere alla selezione",
-    "Apply tag(s) to selection" : "Applica etichetta(e) alla selezione",
-    "Select directory \"{dirName}\"" : "Seleziona cartella \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Seleziona file \"{fileName}\"",
-    "Unable to determine date" : "Impossibile determinare la data",
-    "Could not move \"{file}\", target exists" : "Impossibile spostare \"{file}\", la destinazione esiste già",
-    "Could not move \"{file}\"" : "Impossibile spostare \"{file}\"",
-    "copy" : "copia",
-    "Could not copy \"{file}\", target exists" : "Impossibile copiare \"{file}\", la destinazione esiste già",
-    "Could not copy \"{file}\"" : "Impossibile copiare \"{file}\"",
-    "Copied {origin} inside {destination}" : "Copiato {origin} in {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiati {origin} e {nbfiles} altri file in {destination}",
-    "{newName} already exists" : "{newName} esiste già",
-    "Could not create file \"{file}\"" : "Impossibile creare il file \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "Impossibile creare il file \"{file}\" poiché esiste già",
-    "Could not create folder \"{dir}\" because it already exists" : "Impossibile creare la cartella \"{dir}\" poiché esiste già",
-    "Could not fetch file details \"{file}\"" : "Impossibile recuperare i dettagli del file \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Errore durante l'eliminazione del file \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Nessun risultato di ricerca nelle altre cartelle per {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Digita più di due caratteri per cercare in altre cartelle",
-    "{dirs} and {files}" : "{dirs} e {files}",
-    "_including %n hidden_::_including %n hidden_" : ["incluso %n nascosto","inclusi %n nascosti","inclusi %n nascosti"],
-    "You do not have permission to upload or create files here" : "Non disponi dei permessi per caricare o creare file qui",
-    "_Uploading %n file_::_Uploading %n files_" : ["Caricamento di %n file in corso","Caricamento di %n file in corso","Caricamento di %n file in corso"],
-    "New" : "Nuovo",
-    "New file/folder menu" : "Nuovo menu file/cartella",
-    "Select file range" : "Seleziona intervallo di file",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} utilizzati",
-    "\"{name}\" is an invalid file name." : "\"{name}\" non è un nome file valido.",
-    "File name cannot be empty." : "Il nome del file non può essere vuoto.",
-    "\"/\" is not allowed inside a file name." : "\"/\" non è consentito nel nome di un file.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" non è un tipo di file valido",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Lo spazio di archiviazione di {owner} è pieno, i file non possono essere più aggiornati o sincronizzati!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "La cartella di gruppo \"{mountPoint}\" è piena, i file non possono più essere aggiornati o sincronizzati!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "L'archiviazione esterna \"{mountPoint}\" è piena, i file non possono più essere caricati o sincronizzati!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più caricati o sincronizzati!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Lo spazio di archiviazione di {owner} è quasi pieno ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "La cartella di gruppo \"{mountPoint}\" è quasi piena ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "L'archiviazione esterna \"{mountPoint}\" è quasi piena ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Lo spazio di archiviazione è quasi pieno ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["verifica \"{filter}\"","verificano \"{filter}\"","verificano \"{filter}\""],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Il collegamento diretto è stato copiato (funziona solo per gli utenti che hanno accesso a questo file o cartella)",
-    "Path" : "Percorso",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n byte","%n byte"],
-    "Favored" : "Preferito",
-    "Favor" : "Preferiti",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Copia collegamento diretto (funziona solo per utenti che hanno accesso a questo file/cartella)",
-    "Upload file" : "Carica file",
-    "Not favored" : "Non preferito",
-    "An error occurred while trying to update the tags" : "Si è verificato un errore durante il tentativo di aggiornare le etichette",
-    "Upload (max. %s)" : "Carica (massimo %s)",
-    "Submitting fields…" : "Invio dei campi…",
-    "Filter filenames…" : "Filtra nomi di file…",
-    "Enable the grid view" : "Attiva visuale a griglia",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} cartella","{folderCount} cartelle","{folderCount} cartelle"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} file","{fileCount} file","{fileCount} file"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 file e {folderCount} cartella","1 file e {folderCount} cartelle","1 file e {folderCount} cartelle"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} file e 1 cartella","{fileCount} file e 1 cartella","{fileCount} file e 1 cartella"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} file e {folderCount} cartelle",
-    "Personal Files" : "File personali",
-    "Text file" : "File di testo",
-    "New text file.txt" : "Nuovo file di testo.txt",
     "%1$s (renamed)" : "%1$s (rinominato)",
     "renamed file" : "file rinominato",
+    "Upload (max. %s)" : "Carica (massimo %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Dopo aver abilitato i nomi file compatibili con Windows, i file esistenti non potranno più essere modificati, ma potranno essere rinominati con nuovi nomi validi dal rispettivo proprietario.",
-    "Filter file names …" : "Filtra i nomi dei file …"
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "È anche possibile migrare i file automaticamente dopo aver abilitato questa impostazione; fare riferimento alla documentazione relativa al comando occ.",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" non riuscito su alcuni elementi",
+    "\"{displayName}\" batch action executed successfully" : "L'azione batch \"{displayName}\" è stata eseguita correttamente",
+    "\"{displayName}\" action failed" : "L'azione \"{displayName}\" non è riuscita",
+    "Submitting fields …" : "Invio dei campi …",
+    "\"{displayName}\" action executed successfully" : "L'azione \"{displayName}\" è stata eseguita correttamente",
+    "Filter file names …" : "Filtra i nomi dei file …",
+    "WebDAV URL copied to clipboard" : "L'URL WebDAV è stato copiato negli appunti",
+    "Enable the grid view" : "Attiva visuale a griglia",
+    "Enable folder tree" : "Abilita l'albero delle cartelle",
+    "Copy to clipboard" : "Copia negli appunti",
+    "Use this address to access your Files via WebDAV" : "Usa questo indirizzo per accedere ai tuoi file con WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Se hai abilitato il 2FA, devi creare ed usare una nuova password per l'applicazione facendo clic qui.",
+    "Prevent warning dialogs from open or reenable them." : "Impedire l'apertura delle finestre di dialogo di avviso o riattivarle.",
+    "Show a warning dialog when changing a file extension." : "Mostra una finestra di dialogo di avviso quando si modifica l'estensione di un file.",
+    "Speed up your Files experience with these quick shortcuts." : "Velocizza la tua esperienza con i File con queste rapide scorciatoie.",
+    "Open the actions menu for a file" : "Aprire il menu delle azioni per un file",
+    "Rename a file" : "Rinominare un file",
+    "Delete a file" : "Eliminare un file",
+    "Favorite or remove a file from favorites" : "Aggiungere ai Preferiti o rimuovere un file dai preferiti",
+    "Manage tags for a file" : "Gestire i tag per un file",
+    "Deselect all files" : "Deseleziona tutti i file",
+    "Select or deselect a file" : "Seleziona o deseleziona un file",
+    "Select a range of files" : "Seleziona un intervallo di file",
+    "Navigate to the parent folder" : "Passare alla cartella padre",
+    "Navigate to the file above" : "Vai al file sopra",
+    "Navigate to the file below" : "Vai al file qui sotto",
+    "Navigate to the file on the left (in grid mode)" : "Navigare nel file a sinistra (in modalità griglia)",
+    "Navigate to the file on the right (in grid mode)" : "Navigare nel file a destra (in modalità griglia)",
+    "Toggle the grid view" : "Attiva la vista a griglia",
+    "Open the sidebar for a file" : "Aprire la barra laterale per un file",
+    "Save as …" : "Salva come …",
+    "Converting files …" : "Conversione dei file …",
+    "Converting file …" : "Conversione del file …",
+    "Deletion cancelled" : "Eliminazione annullata",
+    "Edit locally" : "Modifica localmente",
+    "Moving \"{source}\" to \"{destination}\" …" : "Sposta \"{source}\" in \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copia \"{source}\" in \"{destination}\" …",
+    "Move cancelled" : "Spostamento cancellato",
+    "Cancelled move or copy of \"{filename}\"." : "Spostamento o copia di \"{filename}\" annullato.",
+    "Cancelled move or copy operation" : "Operazione di spostamento o copia annullata",
+    "Open details" : "Apri i dettagli",
+    "Photos and images" : "Foto e immagini",
+    "New folder creation cancelled" : "Creazione nuova cartella annullata",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Questa cartella non è disponibile, controlla i log o contatta l'amministratore",
+    "All folders" : "Tutte le cartelle",
+    "Search everywhere …" : "Cerca ovunque…",
+    "Search here …" : "Cerca qui…",
+    "Preparing …" : "In preparazione …"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
