@@ -54,7 +54,7 @@ OC.L10N.register(
     "Limit must be a positive integer." : "限制必須為正整數。",
     "The replacement character may only be a single character." : "替代字元僅限單一字元。",
     "Filename sanitization already started." : "檔案名稱消毒流程已開始。",
-    "No filename sanitization inprogress." : "目前未執行檔案名稱的消毒流程。",
+    "No filename sanitization in progress." : "目前未執行檔案名稱的消毒流程。",
     "Favorite files" : "最愛的檔案",
     "No favorites" : "沒有最愛",
     "More favorites" : "更多最愛",
@@ -124,8 +124,6 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "出於性能考慮，此清單未完全呈現。檔案將在您瀏覽清單時呈現。",
     "File not found" : "找不到檔案",
     "_{count} selected_::_{count} selected_" : ["已選擇 {count} 項"],
-    "Search everywhere …" : "搜尋各處 …",
-    "Search here …" : "搜尋此處 …",
     "Search scope options" : "搜尋範圍選項",
     "Search here" : "搜尋此處",
     "{usedQuotaByte} used" : "已使用 {usedQuotaByte} ",
@@ -144,7 +142,6 @@ OC.L10N.register(
     "Failed to refresh filename sanitization status." : "無法刷新檔案名稱的消毒狀態。",
     "Filename sanitization in progress." : "正在進行檔案名稱消毒。",
     "Currently {processedUsers} of {totalUsers} accounts are already processed." : "目前已處理 {processedUsers} 個帳號，共 {totalUsers} 個。",
-    "Preparing …" : "正在準備 …",
     "Refresh" : "刷新",
     "All files have been santized for Windows filename support." : "所有檔案均已消毒以支援 Windows 檔案名稱規範。",
     "Some files could not be sanitized, please check your logs." : "部份檔案無法完成消毒流程，請檢查您的紀錄檔。",
@@ -159,7 +156,6 @@ OC.L10N.register(
     "Sanitize filenames" : "消毒檔案名稱",
     "(starting)" : "（正在開始）",
     "Fill template fields" : "填寫模板欄位",
-    "Submitting fields …" : "正在遞交欄位 …",
     "Submit" : "遞交",
     "Choose a file or folder to transfer" : "選擇要轉移的檔案或資料夾",
     "Transfer" : "轉移",
@@ -183,33 +179,9 @@ OC.L10N.register(
     "Do not show this dialog again." : "不要再次顯示此對話框。",
     "Select file or folder to link to" : "選擇要連結的檔案或資料夾",
     "Choose {file}" : "選擇 {file}",
-    "Share" : "分享",
-    "Shared by link" : "由連結分享",
-    "Shared" : "已分享",
-    "Switch to list view" : "切換到列表檢視",
-    "Switch to grid view" : "切換到網格檢視",
-    "The file could not be found" : "找不到檔案",
-    "Upload was cancelled by user" : "用戶已取消上傳",
-    "Not enough free space" : "空間不足",
-    "Operation is blocked by access control" : "操作已被存取控制封鎖",
-    "Error during upload: {message}" : "上傳時發生錯誤：{message}",
-    "Error during upload, status code {status}" : "上傳期間發生錯誤，狀態代碼 {status}",
-    "Unknown error during upload" : "上傳時發生未知的錯誤",
-    "Loading current folder" : "目前資料夾加載中",
-    "Retry" : "重試",
-    "No files in here" : "沒有任何檔案",
-    "Upload some content or sync with your devices!" : "在您的裝置同步或上傳一些內容！",
-    "Go back" : "返回",
-    "Views" : "視圖",
-    "Files settings" : "檔案設定",
-    "Your files" : "您的檔案",
-    "Open in files" : "在「檔案」應用程式中打開",
-    "File cannot be accessed" : "檔案無法存取",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "找不到該檔案，或是您沒有檢視該檔案的權限。請要求寄件者分享。",
-    "No search results for “{query}”" : "沒有結果符合「{query}」",
-    "Search for files" : "搜尋檔案",
     "Clipboard is not available" : "剪貼板不可用",
     "WebDAV URL copied" : "已複製 WebDAV URL",
+    "Files settings" : "檔案設定",
     "General" : "一般",
     "Default view" : "默認檢視",
     "All files" : "所有檔案",
@@ -252,12 +224,24 @@ OC.L10N.register(
     "Toggle grid view" : "切換網格檢視",
     "Open file sidebar" : "開啟檔案側邊欄",
     "Show those shortcuts" : "顯示這些快捷鍵",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "允許限製檔案名稱以確保檔案可以與所有客戶端同步。默認情況下，允許 POSIX（例如 Linux 或 macOS）上有效的所有檔案名稱。",
-    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "啟用 Windows 兼容檔案名後，現有的檔案無法再被修改，但其擁有者可以將其重新命名為有效的新名稱。",
-    "Failed to toggle Windows filename support" : "切換 Windows 檔案名稱支援失敗",
-    "Files compatibility" : "檔案兼容性",
-    "Enforce Windows compatibility" : "實施 Windows 兼容性",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "這將阻止在 Windows 系統上無效的檔案名，例如使用保留名稱或特殊字元。但這不會強制區分大小寫的兼容性。",
+    "Share" : "分享",
+    "Shared by link" : "由連結分享",
+    "Shared" : "已分享",
+    "Switch to list view" : "切換到列表檢視",
+    "Switch to grid view" : "切換到網格檢視",
+    "The file could not be found" : "找不到檔案",
+    "Upload was cancelled by user" : "用戶已取消上傳",
+    "Not enough free space" : "空間不足",
+    "Operation is blocked by access control" : "操作已被存取控制封鎖",
+    "Error during upload: {message}" : "上傳時發生錯誤：{message}",
+    "Error during upload, status code {status}" : "上傳期間發生錯誤，狀態代碼 {status}",
+    "Unknown error during upload" : "上傳時發生未知的錯誤",
+    "Loading current folder" : "目前資料夾加載中",
+    "Retry" : "重試",
+    "No files in here" : "沒有任何檔案",
+    "Upload some content or sync with your devices!" : "在您的裝置同步或上傳一些內容！",
+    "Go back" : "返回",
+    "Views" : "視圖",
     "You" : "您",
     "Shared multiple times with different people" : "與不同的人多次分享",
     "Unable to change the favorite state of the file" : "無法更改檔案的最愛狀態",
@@ -266,14 +250,24 @@ OC.L10N.register(
     "Remove from favorites" : "從最愛中移除",
     "Add to favorites" : "加到我的最愛",
     "Tags" : "標籤",
+    "Your files" : "您的檔案",
+    "Open in files" : "在「檔案」應用程式中打開",
+    "File cannot be accessed" : "檔案無法存取",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "找不到該檔案，或是您沒有檢視該檔案的權限。請要求寄件者分享。",
+    "No search results for “{query}”" : "沒有結果符合「{query}」",
+    "Search for files" : "搜尋檔案",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "允許限製檔案名稱以確保檔案可以與所有客戶端同步。默認情況下，允許 POSIX（例如 Linux 或 macOS）上有效的所有檔案名稱。",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "啟用 Windows 兼容檔案名後，現有的檔案無法再被修改，但其擁有者可以將其重新命名為有效的新名稱。",
+    "Failed to toggle Windows filename support" : "切換 Windows 檔案名稱支援失敗",
+    "Files compatibility" : "檔案兼容性",
+    "Enforce Windows compatibility" : "實施 Windows 兼容性",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "這將阻止在 Windows 系統上無效的檔案名，例如使用保留名稱或特殊字元。但這不會強制區分大小寫的兼容性。",
     "Blank" : "空白",
     "Unable to create new file from template" : "無法從模板創建新檔案",
     "Pick a template for {name}" : "為 {name} 選擇一個模板",
     "Create a new file with the selected template" : "使用所選模板創建一個新檔案",
     "Creating file" : "創建檔案中",
     "Save as {displayName}" : "保存為 {displayName}",
-    "Save as …" : "另存為 ...",
-    "Converting files …" : "正在轉換檔案 …",
     "Failed to convert files: {message}" : "無法轉換檔案：{message}",
     "All files failed to be converted" : "所有檔案轉換失敗",
     "One file could not be converted: {message}" : "有一個檔案無法轉換：{message}",
@@ -281,7 +275,6 @@ OC.L10N.register(
     "_One file successfully converted_::_%n files successfully converted_" : ["%n 個檔案成功轉換"],
     "Files successfully converted" : "成功轉換檔案",
     "Failed to convert files" : "無法轉換檔案",
-    "Converting file …" : "正在轉換檔案 …",
     "File successfully converted" : "成功轉換檔案",
     "Failed to convert file: {message}" : "無法轉換檔案：{message}",
     "Failed to convert file" : "無法轉換檔案",
@@ -302,8 +295,6 @@ OC.L10N.register(
     "Download" : "下載",
     "The requested file is not available." : "無法取得所要求的檔案。",
     "The requested files are not available." : "無法取得所要求的檔案。",
-    "Moving \"{source}\" to \"{destination}\" …" : "正在移動「{source}」至「{destination}」…",
-    "Copying \"{source}\" to \"{destination}\" …" : "正在複製「{source}」至「{destination}」…",
     "Destination is not a folder" : "目標地不是資料夾",
     "This file/folder is already in that directory" : "此檔案/資料夾已在該目錄中",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "您無法將檔案/資料夾移動到其自身或子資料夾中",
@@ -394,117 +385,23 @@ OC.L10N.register(
     "Select all" : "全選",
     "Upload too large" : "上傳過大",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您試圖上傳的檔案大小超過伺服器的限制",
-    "File could not be found" : "找不到檔案",
-    "Show list view" : "顯示清單視圖",
-    "Show grid view" : "顯示網格視圖",
-    "Close" : "關閉",
-    "Could not create folder \"{dir}\"" : "無法建立資料夾 \"{dir}\"",
-    "This will stop your current uploads." : "這會終止目前任何的上傳。",
-    "Upload cancelled." : "上傳已取消",
-    "Processing files …" : "正在處理檔案…",
-    "…" : "...",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "因為 {filename} 是個目錄或是大小為零，所以無法上傳",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空間不足，你正要上傳 {size1} 可是只剩下 {size2}",
-    "Target folder \"{dir}\" does not exist any more" : "資料夾 \"{dir}\" 不存在",
-    "An unknown error has occurred" : "發生了不詳的錯誤",
-    "File could not be uploaded" : "檔案無法上傳",
-    "Uploading …" : "上傳中...",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "上傳中 ... （{currentNumber}／{total}）",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中的 {loadedSize}（{bitrate}）",
-    "Uploading that item is not supported" : "不支援上傳該項目",
-    "Error when assembling chunks, status code {status}" : "重組檔案片段時出錯，狀態代碼 {status}",
-    "Choose target folder" : "選擇目標資料夾",
-    "Set reminder" : "設定提醒",
-    "Edit locally" : "在近端編輯",
-    "Open" : "開啟",
-    "Could not load info for file \"{file}\"" : "無法讀取 \"{file}\" 的詳細資料",
-    "Please select tag(s) to add to the selection" : "請選擇要添加到所選項目中的標籤",
-    "Apply tag(s) to selection" : "將標籤應用於所選項目",
-    "Select directory \"{dirName}\"" : "選擇目錄「{dirName}」",
-    "Select file \"{fileName}\"" : "選擇檔案「{fileName}」",
-    "Unable to determine date" : "無法確定日期",
-    "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法存取，請檢查伺服器記錄檔或聯絡管理員",
-    "Could not move \"{file}\", target exists" : "無法移動「{file}」，目標已經存在",
-    "Could not move \"{file}\"" : "無法移動 \"{file}\"",
-    "copy" : "複製",
-    "Could not copy \"{file}\", target exists" : "無法複製\"{file}\"，目標已存在",
-    "Could not copy \"{file}\"" : "無法複製\"{file}\"",
-    "Copied {origin} inside {destination}" : "已複製 {origin} 至 {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "已複製 {origin} 和其他 {nbfiles} 個檔案至 {destination}",
-    "{newName} already exists" : "{newName} 已經存在",
-    "Could not create file \"{file}\"" : "無法建立檔案 \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "無法建立檔案「{file}」，因為此檔案已存在",
-    "Could not create folder \"{dir}\" because it already exists" : "無法建立資料夾 \"{dir}\"，因為此資料夾已存在",
-    "Could not fetch file details \"{file}\"" : "不能取得檔案細節\"{file}\"",
-    "Error deleting file \"{fileName}\"." : "刪除 \"{fileName}\" 出錯",
-    "No search results in other folders for {tag}{filter}{endtag}" : "在其它資料夾中沒有找到 {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "輸入兩個字元以上以便在其它資料夾搜尋",
-    "{dirs} and {files}" : "{dirs} 和 {files}",
-    "_including %n hidden_::_including %n hidden_" : ["包括 %n 個隱藏檔"],
-    "You do not have permission to upload or create files here" : "您無權限上傳或建立檔案",
-    "_Uploading %n file_::_Uploading %n files_" : ["正在上傳 %n 個檔案"],
-    "New" : "新",
-    "New file/folder menu" : "新檔案/資料夾選項單",
-    "Select file range" : "選擇多個檔案",
-    "{used}%" : "{used}%",
-    "{used} used" : "已使用 {used}",
-    "\"{name}\" is an invalid file name." : "\"{name}\" 是無效的檔案名稱。",
-    "File name cannot be empty." : "檔名不能為空",
-    "\"/\" is not allowed inside a file name." : "不允許檔名中出現 \"/\"",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" 是不允許的檔案類型",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} 的儲存空間已滿，沒有辦法再更新或是同步檔案！",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "群組資料夾 \"{mountPoint}\" 已滿，已無法再更新或同步檔案！",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "外部儲存空間 \"{mountPoint}\" 已滿，已無法再更新或同步檔案！",
-    "Your storage is full, files cannot be updated or synced anymore!" : "您的儲存空間已滿，沒有辦法再更新或是同步檔案！",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} 的儲存空間將近已滿（{usedSpacePercent}%）。",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "群組資料夾 \"{mountPoint}\" 將近已滿（{usedSpacePercent}%）。",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "外部儲存空間 \"{mountPoint}\" 將近已滿（{usedSpacePercent}%）。",
-    "Your storage is almost full ({usedSpacePercent}%)." : "您的儲存空間將近已滿（{usedSpacePercent}%）。",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["符合「{filter}」"],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "已複製直接連結（僅適用於有權訪問此檔案/資料夾的人仕）",
-    "Path" : "路徑",
-    "_%n byte_::_%n bytes_" : ["%n 位元組"],
-    "Favored" : "已加入最愛",
-    "Favor" : "加入最愛",
-    "Copy direct link (only works for people who have access to this file/folder)" : "複製直接連結（只對能存取的人仕有用）",
-    "Upload file" : "上傳檔案",
-    "Not favored" : "未加入最愛",
-    "An error occurred while trying to update the tags" : "更新標籤時發生錯誤",
+    "%1$s (renamed)" : "%1$s（已重新命名）",
+    "renamed file" : "已重新命名的檔案",
     "Upload (max. %s)" : "上傳（上限 %s）",
-    "\"{displayName}\" action executed successfully" : "成功執行 “{displayName}” 操作",
-    "\"{displayName}\" action failed" : "“{displayName}” 操作失敗",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "啟用 Windows 兼容檔案名後，現有的檔案無法再被修改，但其擁有者可以將其重新命名為有效的新名稱。",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "啟用此設定後，還可以自動遷移檔案，請參考有關 occ 指令的說明書。",
     "\"{displayName}\" failed on some elements" : "“{displayName}” 在某些元素上失敗",
     "\"{displayName}\" batch action executed successfully" : "成功執行 “{displayName}” 批處理操作",
-    "Submitting fields…" : "正在遞交欄位 …",
-    "Filter filenames…" : "過濾檔案名 ...",
+    "\"{displayName}\" action failed" : "“{displayName}” 操作失敗",
+    "Submitting fields …" : "正在遞交欄位 …",
+    "\"{displayName}\" action executed successfully" : "成功執行 “{displayName}” 操作",
+    "Filter file names …" : "過濾檔案名稱 …",
     "WebDAV URL copied to clipboard" : "WebDAV 連結已複製到剪貼板",
     "Enable the grid view" : "啟用網格檢視",
     "Enable folder tree" : "啟用資料夾樹狀結構",
     "Copy to clipboard" : "複製到剪貼板",
     "Use this address to access your Files via WebDAV" : "用這位址使用 WebDAV 存取你的檔案。",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "如果您啟用了 2FA，則必須通過單擊此處創建和使用新的應用程式密碼。",
-    "Deletion cancelled" : "刪除已取消",
-    "Move cancelled" : "移動已取消",
-    "Cancelled move or copy of \"{filename}\"." : "已取消移動或複製 \"{filename}\"。",
-    "Cancelled move or copy operation" : "已取消移動或複製操作",
-    "Open details" : "開啟細節",
-    "Photos and images" : "照片與圖像",
-    "New folder creation cancelled" : "已取消建立新資料夾",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} 個資料夾"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} 個檔案"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 個檔案與 {folderCount} 個資料夾"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} 個檔案與 1 個資料夾"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} 個檔案與 {folderCount} 個資料夾",
-    "All folders" : "所有資料夾",
-    "Personal Files" : "個人檔案",
-    "Text file" : "文字檔",
-    "New text file.txt" : "新文字檔.txt",
-    "%1$s (renamed)" : "%1$s（已重新命名）",
-    "renamed file" : "已重新命名的檔案",
-    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "啟用 Windows 兼容檔案名後，現有的檔案無法再被修改，但其擁有者可以將其重新命名為有效的新名稱。",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "啟用此設定後，還可以自動遷移檔案，請參考有關 occ 指令的說明書。",
-    "Filter file names …" : "過濾檔案名稱 …",
     "Prevent warning dialogs from open or reenable them." : "避免開啟警告對話框或重新啟用它們。",
     "Show a warning dialog when changing a file extension." : "在變更副檔名時顯示警告對話框。",
     "Speed up your Files experience with these quick shortcuts." : "這些快速捷徑可加快您的 Files 體驗。",
@@ -522,6 +419,24 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "前往左側的檔案（在網格模式下）",
     "Navigate to the file on the right (in grid mode)" : "前往右側的檔案（在網格模式下）",
     "Toggle the grid view" : "切換網格檢視",
-    "Open the sidebar for a file" : "開啟檔案側邊欄"
+    "Open the sidebar for a file" : "開啟檔案側邊欄",
+    "Save as …" : "另存為 ...",
+    "Converting files …" : "正在轉換檔案 …",
+    "Converting file …" : "正在轉換檔案 …",
+    "Deletion cancelled" : "刪除已取消",
+    "Edit locally" : "在近端編輯",
+    "Moving \"{source}\" to \"{destination}\" …" : "正在移動「{source}」至「{destination}」…",
+    "Copying \"{source}\" to \"{destination}\" …" : "正在複製「{source}」至「{destination}」…",
+    "Move cancelled" : "移動已取消",
+    "Cancelled move or copy of \"{filename}\"." : "已取消移動或複製 \"{filename}\"。",
+    "Cancelled move or copy operation" : "已取消移動或複製操作",
+    "Open details" : "開啟細節",
+    "Photos and images" : "照片與圖像",
+    "New folder creation cancelled" : "已取消建立新資料夾",
+    "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法存取，請檢查伺服器記錄檔或聯絡管理員",
+    "All folders" : "所有資料夾",
+    "Search everywhere …" : "搜尋各處 …",
+    "Search here …" : "搜尋此處 …",
+    "Preparing …" : "正在準備 …"
 },
 "nplurals=1; plural=0;");
