@@ -32,14 +32,6 @@ OC.L10N.register(
     "Check password against the list of breached passwords from haveibeenpwned.com" : "Проверять пароль по списку слабых паролей из базы сайта haveibeenpwnd.com",
     "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Для проверки пароля создаётся его хеш, после чего первые 5 символов этого хеша передаются в API сайта hasibeenpwned.com. Полученные с сайта хеши паролей сравниваются с хешами паролей сервера Nextcloud.",
     "Account password policies" : "Политика использования паролей для учетных записей",
-    "Share password policies" : "Политика общего доступа к паролям",
-    "Unknown error" : "Неизвестная ошибка",
-    "Minimal length has to be a non negative number" : "Минимальная длина должна быть неотрицательным числом",
-    "History size has to be a non negative number" : "Размер истории должен быть неотрицательным числом",
-    "Expiration days have to be a non negative number" : "Срок действия должен быть неотрицательным числом",
-    "Maximum login attempts have to be a non negative number" : "Максимальное количество попыток входа в систему должно быть неотрицательным числом",
-    "Settings saved" : "Настройки сохранены",
-    "Error while saving settings" : "Ошибка при сохранении параметров",
-    "User password history" : "История паролей пользователей"
+    "Share password policies" : "Политика общего доступа к паролям"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
