@@ -21,6 +21,9 @@ OC.L10N.register(
     "Mark selection as favorite" : "Märgi valitud lemmikuks",
     "Add selection to favorites" : "Lisa valitud lemmikute hulka",
     "Remove selection from favorites" : "Eemalda valitud lemmikute hulgast",
+    "This name is already in use." : "See nimi on juba kasutusel.",
+    "\"{char}\" is not allowed inside a filename." : "„{char}“ pole failinimedes lubatud.",
+    "Invalid filename." : "Vigane failinimi.",
     "Name of the album" : "Albumi nimi",
     "Location of the album" : "Albumi asukoht",
     "Back" : "Tagasi",
@@ -39,8 +42,6 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "Lisa inimesi ja gruppe, kes võivad su albumit muuta",
     "Search people or groups" : "Otsi inimesi või gruppe",
     "No recommendations. Start typing." : "Soovitusi pole. Alusta trükkimist.",
-    "Group" : "Grupp",
-    "Remove {collaboratorLabel} from the collaborators list" : "Eemalda {collaboratorLabel} kaasautorite hulgast",
     "Copy the public link" : "Kopeeri avalik link",
     "Public link copied!" : "Avalik link kopeeritud!",
     "Copy public link" : "Kopeeri avalik link",
@@ -59,9 +60,11 @@ OC.L10N.register(
     "Open the full size \"{name}\" image" : "Ava pilt \"{name}\" täissuuruses",
     "Select image {imageName}" : "Vali pilt {imageName}",
     "Open the \"{name}\" folder" : "Ava kaust \"{name}\"",
-    "Back to {folder}" : "Tagasi kausta {folder}",
     "Go back" : "Mine tagasi",
-    "Share this folder" : "Jaga seda kausta",
+    "Select a custom date range" : "Vali enda määratud ajavahemik",
+    "Select a date range" : "Vali kuupäevavahemik",
+    "Date range" : "Kuupäevade vahemik",
+    "Select filters" : "Vali filtrid",
     "Dates" : "Kuupäevad",
     "Jump to specific date in list" : "Hüppa nimekirjas kindlale kuupäevale",
     "Jump to {date}" : "Hüppa {date} juurde",
@@ -86,9 +89,6 @@ OC.L10N.register(
     "Upload folder" : "Üleslaadimiskaust",
     "Choose the folder where photos and albums are uploaded to." : "Vali kaust, kuhu fotod ja albumid üles laaditakse",
     "_%n photo_::_%n photos_" : ["%n foto","%n fotot"],
-    "Select a date range" : "Vali kuupäevavahemik",
-    "Date range" : "Kuupäevade vahemik",
-    "Select places" : "Vali asukohad",
     "Unselect all" : "Eemalda kogu valik",
     "Add photos to this album" : "Lisa sellesse albumisse fotosid",
     "Manage collaborators for this album" : "Halda selle albumi kaasautoreid",
@@ -119,7 +119,7 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "See võib sõltuvalt fototeegi suurusest natuke aega võtta.",
     "Recognized people will show up here" : "Siin näidatakse tuvastatud inimesi",
     "This folder does not exist" : "Seda kausta pole olemas",
-    "Loading folders …" : "Kaustada laadimine …",
+    "Loading folders…" : "Laadin kaustu…",
     "No photos in here" : "Siin ei ole fotosid",
     "Taken on {date} at {time}" : "Pildistatud {date} {time}",
     "This place does not have any photos or videos yet!" : "Siin kohas pole veel ühtegi fotot ega videot!",
@@ -133,10 +133,10 @@ OC.L10N.register(
     "Photos with tags will show up here" : "Siin näidatakse sildistatud fotosid",
     "Popular tags" : "Populaarsed sildid",
     "All tags" : "Kõik sildid",
+    "Create new album from filters" : "Loo uus album filtrite alusel",
     "One of the source folders does not exist" : "Ühte lähtekaustadest pole olemas",
     "Add to album" : "Lisa albumisse",
     "Delete selection" : "Kustuta valik",
-    "Toggle filter" : "Lülita filter sisse/välja",
     "No photos or videos in here" : "Siin pole fotosid ega videosid",
     "Unassigned faces" : "Määramata näod",
     "Failed to fetch collection." : "Kollektsiooni laadimine ebaõnnestus.",
@@ -151,8 +151,19 @@ OC.L10N.register(
     "Tagged photos" : "Sildistatud fotod",
     "Tagged photo {title}" : "Sildistatud foto {title}",
     "{title}'s face" : "{title} nägu",
+    "Last week" : "Eelmisel nädalal",
+    "Last Month" : "Eelmisel kuul",
+    "Custom…" : "Kohandatud…",
     "{startDate} to {endDate}" : "{startDate} kuni {endDate}",
     "Details" : "Üksikasjad",
+    "Failed to add {fileBaseName} to collection {collectionFileName}" : "„{fileBaseName}“ lisamine „{collectionFileName}“ kogumikku ei õnnestunud",
+    "Failed to delete {fileBaseName}" : "Ei õnnestunud kustutada: „{fileBaseName}“",
+    "Failed to create {collectionFileName}" : "„{collectionFileName}“ loomine ei õnnestunud",
+    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Ei õnnestunud muuta nime: „{currentCollectionFileName}“ → „{newCollectionFileName}“",
+    "Failed to update properties of {collectionFileName} with {properties}" : "„{collectionFileName}“ faili „{properties}“ omaduste muutmine ei õnnestunud",
+    "Failed to delete {collectionFileName}" : "Ei õnnestunud kustutada: „{collectionFileName}“",
+    "Failed to move {fileBaseName} to person {faceName}" : "„{fileBaseName}“ teisaldamine kasutajale „{faceName}“ ei õnnestunud",
+    "Failed to remove {fileBaseName}" : "„{fileBaseName}“ eemaldamine ei õnnestunud",
     "Failed to rename {oldName} to {faceName}" : "Ei õnnestunud muuta nime: „{oldName}“ → „{faceName}“",
     "Failed to delete {faceName}" : "Ei õnnestunud kustutada: „{faceName}“",
     "Failed to delete {fileId}" : "Ei õnnestunud kustutada: „{fileId}“",
@@ -160,7 +171,11 @@ OC.L10N.register(
     "Failed to set favorite state for {fileId}" : "Ei õnnestunud määrata olekut lemmikuna: „{fileId}“",
     "Failed to set favorite state for {fileName}" : "Ei õnnestunud määrata olekut lemmikuna: „{fileName}“",
     "Could not load photos folder" : "Fotode kausta laadimine ei õnnestunud",
-    "One of the source folders does not exists" : "Ühte lähtekaustadest pole olemas",
+    "Group" : "Grupp",
+    "Remove {collaboratorLabel} from the collaborators list" : "Eemalda {collaboratorLabel} kaasautorite hulgast",
+    "Back to {folder}" : "Tagasi kausta {folder}",
+    "Share this folder" : "Jaga seda kausta",
+    "Loading folders …" : "Kaustada laadimine …",
     "Add" : "Lisa"
 },
 "nplurals=2; plural=(n != 1);");
