@@ -3,20 +3,58 @@ OC.L10N.register(
     {
     "Privacy" : "Privadesa",
     "-" : "-",
-    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "El centre de privacitat us mostra a on s'emmagatzemen les vostres dades i qui pot accedir-hi, ja sia perquè vau compartir amb ell/ella o perquè són usuaris administradors.",
-    "Remove external admin" : "Elimina un administrador extern",
+    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "El centre de privadesa us mostra on s'emmagatzemen les vostres dades i qui pot accedir-hi, ja sigui perquè les vau compartir o perquè són usuaris administradors.",
+    "Error loading additional administrator." : "S'ha produït un error en carregar un administrador addicional.",
+    "Error adding new administrator." : "S'ha produït un error en afegir un nou administrador.",
+    "Error deleting new administrator." : "S'ha produït un error en suprimir el nou administrador.",
+    "Administrators" : "Administradors",
+    "The following accounts are designated administrators and may potentially have access to your data through system storage or backups. However, they do not have easy access to your data via the web interface or client applications." : "Els comptes següents són administradors designats i poden tenir accés a les vostres dades mitjançant l'emmagatzematge del sistema o les còpies de seguretat. Tanmateix, no tenen fàcil accés a les vostres dades mitjançant la interfície web o les aplicacions de client.",
+    "Loading administrators …" : "S'estan carregant els administradors …",
+    "Remove external {propertyName} admin" : "Suprimir l'administrador extern {propertyName}",
     "Add external admin" : "Afegeix un administrador extern",
+    "Cancel" : "Cancelar",
+    "Add" : "Afegeix",
     "Name of external admin" : "Nom de l'administrador extern",
-    "This server is using full-disk-encryption." : "Aquest servidor està fent servir xifratge complet de disc.",
+    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "L'emmagatzematge de casa s'encripta mitjançant el {linkopen}xifratge del costat del servidor ↗{linkclose} amb una clau mestra. Significa que els administradors poden accedir als vostres fitxers, però no llegir-ne el contingut.",
+    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Els fitxers en ubicacions d'emmagatzematge extern poden estar xifrats mitjançant {linkopen}xifratge del servidor ↗{linkclose} amb una clau mestra en funció de la configuració.",
+    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "L'emmagatzematge de casa s'encripta mitjançant el {linkopen}xifratge del costat del servidor ↗{linkclose} amb una clau d'usuari individual. Significa que els administradors poden accedir als vostres fitxers, però no llegir-ne el contingut.",
+    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Els fitxers en ubicacions d'emmagatzematge extern poden estar xifrats mitjançant {linkopen}xifratge del servidor ↗{linkclose} amb una clau individual en funció de la configuració.",
+    "Additionally, this server is protected with full-disk-encryption." : "A més, aquest servidor està protegit mitjançant xifratge complet del disc.",
+    "This server is protected with full-disk-encryption." : "Aquest servidor està protegit mitjançant xifratge complet del disc.",
     "Your files are not protected by encryption." : "Els vostres fitxers no estan protegits per xifratge.",
-    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Els vostres fitxers estan xifrats amb {linkopen}xifratge del costat del servidor ↗{linkclose}.",
-    "This server is protected with full-disk-encryption." : "Aquest servidor està protegit amb xifratge complet del disc.",
-    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Els vostres fitxers estan xifrats amb {linkopen}xifratge del costat del servidor ↗{linkclose}. A més, aquest servidor està protegit amb el xifratge complet del disc.",
-    "Your data is located in: " : "Les vostres dades es troben a: ",
-    "The admin hasn't selected the location of the server yet." : "L'administrador encara no ha seleccionat la ubicació del servidor.",
+    "Error saving new state of full-disk-encryption" : "S'ha produït un error en desar l'estat nou de xifratge de disc complet",
+    "Encryption" : "Xifratge",
+    "Edit encryption" : "Edició de xifratge",
+    "Edit" : "Edició",
+    "This server is using full-disk-encryption." : "Aquest servidor utilitza xifratge complet de disc.",
+    "Privacy policy" : "Política de privadesa",
+    "Read the privacy policy ↗" : "Llegeix la política de privadesa ↗",
+    "Error loading information about shares." : "S'ha produït un error en carregar la informació sobre els recursos compartits.",
+    "People you've shared with" : "Persones amb qui has compartit",
+    "Loading people you've shared with …" : "S'està carregant la gent amb qui has compartit …",
+    "You do not have any shares with individual users." : "No teniu cap compartició amb usuaris individuals.",
+    "Who has access to your data?" : "Qui té accés a les vostres dades?",
+    "Error saving new location of the server" : "S'ha produït un error en desar la nova ubicació del servidor",
+    "Where is your data?" : "On són les vostres dades?",
+    "Your data is located in:" : "Les vostres dades es troben a:",
+    "An admin has not selected the location of the server yet." : "L'administrador encara no ha seleccionat la ubicació del servidor.",
     "Change data location" : "Canvia la ubicació de les dades",
+    "Region" : "Regió",
     "Please select a region" : "Seleccioneu una regió",
-    "You don't have any shares with individual users." : "No teniu cap compartició amb usuaris individuals.",
+    "User Data Manifesto 2.0" : "Manifest de dades de l'usuari 2.0",
+    "Defining basic rights for people to control their own data in the internet age." : "Definir els drets bàsics de les persones a controlar les seves pròpies dades en l'era d'Internet.",
+    "Control" : "Control",
+    "over user data access" : "sobre l’accés a les dades dels usuaris",
+    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Les dades pujades de manera explícita i voluntària per part d'un usuari han d'estar sota el control definitiu de l'usuari. Els usuaris han de poder decidir a qui concedeixen accés directe a les seves dades i amb quins permisos i llicències es concedeix l'accés.",
+    "Knowledge" : "Coneixement",
+    "of how the data is stored" : "de com s'emmagatzemen les dades",
+    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Quan es pugen les dades a un proveïdor de serveis específic, els usuaris han de rebre informació sobre el lloc on el proveïdor de serveis específic emmagatzema les dades, durant quant de temps, sota quina jurisdicció opera el proveïdor de serveis específic i quina és la legislació aplicable.",
+    "Freedom" : "Llibertat",
+    "to choose a platform" : "per triar una plataforma",
+    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Els usuaris sempre han de poder extreure les seves dades del servei en qualsevol moment, sense experimentar cap bloqueig per part del proveïdor. Per a garantir això, calen estàndards oberts per a formats i protocols.",
+    "Learn more ↗" : "Més informació ↗",
+    "Your {serverName} account" : "El vostre compte de {serverName}",
+    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Les vostres dades representen qui sou i poden ser objecte d’abús fàcilment. A Nextcloud creiem que teniu dret a decidir què passa amb les vostres dades. Nextcloud protegeix els vostres drets tal com es defineix al Manifest de dades de l'usuari!",
     "Somaliland" : "Somalilàndia",
     "Andorra" : "Andorra",
     "United Arab Emirates" : "Emirats Àrabs Units",
@@ -69,7 +107,7 @@ OC.L10N.register(
     "Colombia" : "Colòmbia",
     "Costa Rica" : "Costa Rica",
     "Cuba" : "Cuba",
-    "Cabo Verde" : "Cabo Verde",
+    "Cabo Verde" : "Cap Verd",
     "Curaçao" : "Curaçao",
     "Christmas Island" : "Illa Christmas",
     "Cyprus" : "Xipre",
@@ -89,7 +127,7 @@ OC.L10N.register(
     "Finland" : "Finlàndia",
     "Fiji" : "Fiji",
     "Falkland Islands" : "Illes Malvines",
-    "Micronesia" : "Micronèsia, Estats Federats de la",
+    "Micronesia" : "Estats Federats de la Micronèsia",
     "Faroe Islands" : "Illes Fèroe",
     "France" : "França",
     "Gabon" : "Gabon",
@@ -111,9 +149,9 @@ OC.L10N.register(
     "Guam" : "Guam",
     "Guinea-Bissau" : "Guinea Bissau",
     "Guyana" : "Guyana",
-    "Honduras" : "Hondures",
     "Hong Kong" : "Hong Kong",
     "Heard Island and McDonald Islands" : "Illes Heard i McDonald",
+    "Honduras" : "Hondures",
     "Croatia" : "Croàcia",
     "Haiti" : "Haití",
     "Hungary" : "Hongria",
@@ -164,7 +202,7 @@ OC.L10N.register(
     "Myanmar" : "Birmània",
     "Mongolia" : "Mongòlia",
     "Macao" : "Macau",
-    "Northern Mariana Islands" : "Illes Marianes del Nord",
+    "Northern Mariana Islands" : "Illes Mariannes del Nord",
     "Mauritania" : "Mauritània",
     "Montserrat" : "Illa de Montserrat",
     "Malta" : "Malta",
@@ -202,7 +240,7 @@ OC.L10N.register(
     "Palau" : "Palau",
     "Paraguay" : "Paraguai",
     "Qatar" : "Qatar",
-    "Réunion" : "Reunió",
+    "Réunion" : "La Reunió",
     "Romania" : "Romania",
     "Serbia" : "Sèrbia",
     "Russia" : "Rússia",
@@ -246,15 +284,15 @@ OC.L10N.register(
     "Tanzania" : "Tanzània",
     "Ukraine" : "Ucraïna",
     "Uganda" : "Uganda",
-    "United States Minor Outlying Islands" : "Illes Perifèriques Menors dels EUA",
+    "United States Minor Outlying Islands" : "Illes d'Ultramar Menors dels Estats Units",
     "United States" : "Estats Units",
     "Uruguay" : "Uruguai",
     "Uzbekistan" : "Uzbekistan",
     "Holy See" : "Santa Seu",
     "Saint Vincent and the Grenadines" : "Saint Vincent i les Grenadines",
     "Venezuela" : "Veneçuela",
-    "Virgin Islands (British)" : "Illes Verges (Britànica)",
-    "Virgin Islands (U.S.)" : "Illes Verges (EUA)",
+    "Virgin Islands (British)" : "Illes Verges Britàniques",
+    "Virgin Islands (U.S.)" : "Illes Verges Nord-americanes",
     "Vietnam" : "Vietnam",
     "Vanuatu" : "Vanuatu",
     "Wallis and Futuna" : "Wallis i Futuna",
@@ -263,27 +301,6 @@ OC.L10N.register(
     "Mayotte" : "Mayotte",
     "South Africa" : "Sud-àfrica",
     "Zambia" : "Zàmbia",
-    "Zimbabwe" : "Zimbabwe",
-    "Your Nextcloud account" : "El vostre compte de Nextcloud",
-    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Les vostres dades representen qui sou i poden ser objecte d’abús fàcilment. A Nextcloud creiem que teniu dret a decidir què passa amb les vostres dades. Nextcloud protegeix els vostres drets tal com es defineix al Manifest de Dades de l'Usuari (User Data Manifesto)!",
-    "User Data Manifesto 2.0" : "Manifest de Dades de l'Usuari 2.0",
-    "Defining basic rights for people to control their own data in the internet age" : "Definició de drets bàsics per a que les persones puguin controlar les seves pròpies dades en l’era d'Internet",
-    "Control" : "Control",
-    "over user data access" : "sobre l’accés a les dades dels usuaris",
-    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Les dades carregades de manera explícita i voluntària per un usuari haurien d'estar sota el control definitiu de l'usuari. Els usuaris haurien de poder decidir a qui concedir accés directe a les seves dades i amb quins permisos i llicències s’hauria de concedir.",
-    "Knowledge" : "Coneixement",
-    "of how the data is stored" : "de com s'emmagatzemen les dades",
-    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Quan es carreguen les dades a un proveïdor de serveis específic, els usuaris haurien de ser informats sobre el lloc on el proveïdor de serveis específic emmagatzema les dades, per quant de temps, sota quina jurisdicció opera el proveïdor de serveis específic i quines lleis s'apliquen.",
-    "Freedom" : "Llibertat",
-    "to choose a platform" : "per triar una plataforma",
-    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Els usuaris sempre han de poder extreure les seves dades del servei en qualsevol moment sense experimentar cap bloqueig per part del proveïdor. Per garantir això, calen estàndards oberts per a formats i protocols.",
-    "Learn more ↗" : "Més informació ↗",
-    "Where is your data?" : "On són les vostres dades?",
-    "Who has access to your data?" : "Qui té accés a les vostres dades?",
-    "Administrators" : "Administradors",
-    "People you shared with" : "Persones amb les quals heu compartit",
-    "Privacy policy" : "Política de privadesa",
-    "Read the privacy policy." : "Llegiu la política de privadesa.",
-    "Encryption" : "Xifratge"
+    "Zimbabwe" : "Zimbabwe"
 },
 "nplurals=2; plural=(n != 1);");
