@@ -1,13 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Prevez",
-    "Local" : "Diabarzh",
-    "Federated" : "Kevredet",
-    "Only synchronize to trusted servers" : "Kempredañ da servijourioù fiziet nemetken",
-    "Synchronize to trusted servers and the global and public address book" : "Kempreda da servijourioù fiziet ha d'al levr chom-lerc'hioù oublik a hollek",
-    "Verify" : "Gwiriañ",
-    "Verifying …" : "O wiriañ...",
     "Unable to change password" : "N'eo ket  bet posupl cheñch ar ger-tremen",
     "Very weak password" : "Ger-tremen skanv kenan",
     "Weak password" : "Ger-tremen skanv",
@@ -100,6 +93,8 @@ OC.L10N.register(
     "Background jobs" : "Labour diadreñv",
     "Unlimited" : "Didermenet",
     "Verifying" : "O gwiriañ",
+    "Verifying …" : "O wiriañ...",
+    "Verify" : "Gwiriañ",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Mankout a ra kolonennoù er roadennoù-diaz dibabapl. Abalamour e kemer amzer ouzhpennañ kolonennoù e taolennoù bras, n'int ket bet lakaet en un doare otomatek. En ul lakaat da dreiñ \"occ db:add-missing-columns\" eo posupl ouzhpennañ ar c'holonennoù a vank gant an dorn pa vo an azgoulenn o treiñ. Ur wech ouzhpennet ar c'holonennoù, goulennoù savet d'an taolennoù a vo buanaet.",
     "Disabled" : "Disaotreañ",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Stumm ar sifrañ kostez ar servijour kozh a zo aotreet. Aliet eo hen disaotreañ.",
@@ -204,8 +199,8 @@ OC.L10N.register(
     "Enter your date of birth" : "Lakaat ho teiziad ganedigezh",
     "You are a member of the following groups:" : "Er strolladoù-mañ emaoc'h",
     "No email address set" : "Chom-lec'h postel ebet lakaet",
-    "Help translate" : "Sikour treiñ",
     "No language set" : "Yezh ebet lakaet",
+    "Help translate" : "Sikour treiñ",
     "Week starts on {firstDayOfWeek}" : "Krog a ra ar sizunn gant {firstDayOfWeek}",
     "Your phone number" : "O niverenn pelgomzer",
     "Change" : "Cheñch",
@@ -242,7 +237,6 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "Ret eo kaout ur c'henstagadur sur evit un dilesa di-ger-tremen.",
     "Add WebAuthn device" : "Ouzhpenn ardivink WebAuthn",
     "Please authorize your WebAuthn device." : "Aotreit o ardivink WebAuthn.",
-    "Adding your device …" : "Ouehpennit ho ardivink ...",
     "Unnamed device" : "Ardivink hep anv",
     "Passwordless Authentication" : "Dilesa hep ger-tremen",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Lakaat o c'hont da implij an dilesa hap ger-tremen en ur heuliañ ar standart FIDO2.",
@@ -267,6 +261,11 @@ OC.L10N.register(
     "Role" : "Roll",
     "Website" : "Lec'hienn web",
     "Locale" : "Diabarzh",
+    "Private" : "Prevez",
+    "Local" : "Diabarzh",
+    "Federated" : "Kevredet",
+    "Only synchronize to trusted servers" : "Kempredañ da servijourioù fiziet nemetken",
+    "Synchronize to trusted servers and the global and public address book" : "Kempreda da servijourioù fiziet ha d'al levr chom-lerc'hioù oublik a hollek",
     "Your apps" : "Ho meziantoù",
     "Active apps" : "Meziantoù lakaet en dro",
     "Disabled apps" : "Meziantoù disaotreet",
@@ -306,11 +305,10 @@ OC.L10N.register(
     "Check out our blog" : "Sellit ouzh hon vlog",
     "Subscribe to our newsletter" : "Koumannantit d'hon kemenadennoù nevesadur",
     "Use a second factor besides your password to increase security for your account." : "Implijour un eil-elfenn d'ho ger-tremen a gwella urentez o c'hont.",
-    "Set default expiration date for shares" : "Lakaat un deizat termen dre ziouer evit ar rannañ",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "N'en deus ket ar meziant ur stumm izelañ evit Nextcloud. Ur fazi a vo en dazont.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ar meziant n'en deus ket ur stumm huela eus Nextcloud merked. Ur fazi vo en dazont.",
-    "You are using <strong>{usage}</strong>" : "Emaoc'h o imlpij <strong>{usage}</strong>",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Ma peus kollet o ardivink pe kuitaet ar strollad, posupl e vefe lemet a pell roadennoù Nextcloud eus tout o ardivinkoù liamet gant {userid}. Ne gerzh nemet ma eo kenstaget an ardivinkoù gant internet.",
+    "Adding your device …" : "Ouehpennit ho ardivink ...",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "N'eo ket ar meziant keverlec'h gant stumm Nextcloud. Ma kendalc'hit e o posupl deoc'h staliañ ar meziant. Taolit evez, ne labouro ket ar meziant evel ma zlefe.",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Pouezus eo evit ar surentez hag ar mont en dro ho azgoulenn e vefe pep tra stummet mat. Evit sikour ac'hanoc'h e vez graet gwiradennoù otomatek. Sellit ouz an diellvadur liammet evit muioc'h a ditouroù.",
     "Checking for system and security issues." : "O gwiriañ ne vefe kuden ebet gant ar sistem hag ar surentez.",
