@@ -56,7 +56,6 @@ OC.L10N.register(
     "Failed to delete tag" : "Impossible de supprimer l'étiquette",
     "Create or edit tags" : "Créer ou modifier les étiquettes",
     "Search for a tag to edit" : "Rechercher une étiquette à modifier",
-    "Collaborative tags …" : "Étiquettes collaboratives…",
     "No tags to select" : "Aucune étiquette à sélectionner",
     "Tag name" : "Nom de l'étiquette",
     "Tag level" : "Niveau de l'étiquette",
@@ -64,7 +63,7 @@ OC.L10N.register(
     "Update" : "Mise à jour",
     "Delete" : "Supprimer",
     "Reset" : "Réinitialiser",
-    "Loading …" : "Chargement…",
+    "Loading …" : "Chargement...",
     "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} sera attribuée et {tag2} sera retirée d'1 fichier.","{tag1} sera attribuée et {tag2} sera retirée de {count} fichiers.","{tag1} sera attribuée et {tag2} sera retirée de {count} fichiers."],
     "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} sera attribuée à 1 fichier.","{tag} sera attribuée à {count} fichiers.","{tag} sera attribuée à {count} fichiers."],
     "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} sera retiré d'1 fichier.","{tag} sera retirée de {count} fichiers.","{tag} sera retirée de {count} fichiers."],
@@ -83,11 +82,10 @@ OC.L10N.register(
     "Choose tags for the selected files" : "Choisir des étiquettes pour les fichiers sélectionnés",
     "Cancel" : "Annuler",
     "Apply" : "Appliquer",
-    "Failed to load tags" : "Impossible de charger les étiquettes",
     "Failed to load selected tags" : "Impossible de charger les étiquettes sélectionnées",
+    "Failed to load tags" : "Impossible de charger les étiquettes",
     "Failed to select tag" : "Impossible de sélectionner l'étiquette",
     "System admin disabled tag creation. You can only use existing ones." : "L'administrateur a désactivé la création d'étiquettes. Vous ne pouvez utiliser que les étiquettes existantes.",
-    "Loading collaborative tags …" : "Chargement des étiquettes collaboratives...",
     "Search or create collaborative tags" : "Rechercher ou créer des étiquettes collaboratives",
     "No tags to select, type to create a new tag" : "Aucune étiquette à sélectionner, entrez une nouvelle étiquette",
     "Unable to update setting" : "Impossible de mettre à jour les paramètres",
@@ -109,9 +107,12 @@ OC.L10N.register(
     "Failed to load tags for file" : "Impossible de charger les étiquettes du fichier",
     "Failed to set tag for file" : "Impossible d'attribuer l'étiquette au fichier",
     "Failed to delete tag for file" : "Impossible de supprimer l'étiquette au fichier",
+    "Collaborative tags …" : "Étiquettes collaboratives…",
+    "Loading …" : "Chargement…",
     "File tags modification canceled" : "Modification des étiquettes du fichier annulée",
     "Select or create tags to apply to all selected files" : "Sélectionnez ou créez des étiquettes à appliquer à tous les fichiers sélectionnés",
     "Select tags to apply to all selected files" : "Sélectionnez les étiquettes à appliquer à tous les fichiers sélectionnés",
-    "Apply changes" : "Appliquer les modifications"
+    "Apply changes" : "Appliquer les modifications",
+    "Loading collaborative tags …" : "Chargement des étiquettes collaboratives..."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
