@@ -91,9 +91,9 @@ OC.L10N.register(
     "Failed to delete tag for file" : "ھۆججەتنىڭ بەلگىسىنى ئۆچۈرەلمىدى",
     "Collaborative tags …" : "ھەمكارلىق خەتكۈچلىرى…",
     "Loading …" : "Loading…",
-    "Loading collaborative tags …" : "ھەمكارلىق خەتكۈچلىرىنى يۈكلەۋاتىدۇ…",
     "File tags modification canceled" : "ھۆججەت خەتكۈچلىرىنى ئۆزگەرتىش ئەمەلدىن قالدۇرۇلدى",
     "Select or create tags to apply to all selected files" : "بارلىق تاللانغان ھۆججەتلەرگە ماس كېلىدىغان بەلگىلەرنى تاللاڭ ياكى قۇرالايسىز",
-    "Apply changes" : "ئۆزگەرتىشلەرنى ئىشلىتىڭ"
+    "Apply changes" : "ئۆزگەرتىشلەرنى ئىشلىتىڭ",
+    "Loading collaborative tags …" : "ھەمكارلىق خەتكۈچلىرىنى يۈكلەۋاتىدۇ…"
 },
 "nplurals=2; plural=(n != 1);");
