@@ -12,6 +12,7 @@ OC.L10N.register(
     "Translate" : "Translate",
     "Reload" : "Yenidən yüklə",
     "you" : "siz",
+    "Copy link" : "linki nüsxələ",
     "guest" : "Qonaq",
     "Saved" : "Saxlanıldı",
     "Save changes" : "Dəyişiklikləri yaddaşa ver",
@@ -24,8 +25,6 @@ OC.L10N.register(
     "Done" : "Edildi",
     "Details" : "Detallar",
     "Choose" : "Seç",
-    "Choose {file}" : "{file} seçin",
-    "Info" : "Info",
-    "Warning" : "Xəbərdarlıq"
+    "Choose {file}" : "{file} seçin"
 },
 "nplurals=2; plural=(n != 1);");
