@@ -10,6 +10,8 @@ OC.L10N.register(
     "Text" : "Texto",
     "Translate" : "Traducir",
     "Guest" : "Invitado",
+    "you" : "tú",
+    "Copy link" : "Copiar liga",
     "Offline" : "Sin conexión",
     "Saved" : "Guardado",
     "Unsaved changes" : "Cambios no guardados",
@@ -27,9 +29,6 @@ OC.L10N.register(
     "Edit" : "Editar",
     "Source code" : "Código fuente",
     "Details" : "Detalles",
-    "Choose" : "Seleccionar",
-    "Info" : "Info",
-    "Success" : "Éxito",
-    "Warning" : "Advertencia"
+    "Choose" : "Seleccionar"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
