@@ -1,20 +1,44 @@
 OC.L10N.register(
     "updatenotification",
     {
-    "{version} is available. Get more information on how to update." : "{version} está disponible. Obtenga más información sobre cómo actualizar.",
     "Channel updated" : "Canal actualizado",
     "Web updater is disabled" : "El actualizador web está desactivado",
+    "App updated" : "Aplicación actualizada",
+    "See what's new" : "Novedades",
+    "{app} updated to version {version}" : "{app} actualizada a la versión {version}",
     "Update notifications" : "Actualizar notificaciones",
     "The update server could not be reached since %d days to check for new updates." : "No se ha podido contactar con el servidor de actualizaciones desde hace %d días para comprobar nuevas actualizaciones.",
     "Please check the Nextcloud and server log files for errors." : "Por favor, revisa los archivos de registro de Nextcloud y del servidor en busca de errores.",
     "Update to {serverAndVersion} is available." : "La actualización a {serverAndVersion} está disponible.",
     "Update for {app} to version %s is available." : "Actualización de {app} a la versión %s está disponible.",
     "Update notification" : "Notificación de actualización",
+    "Displays update notifications for Nextcloud, app updates, and provides the SSO for the updater." : "Muestra las notificaciones de actualización para Nextcloud, actualizaciones de apps y proporciona el SSO para el actualizador.",
+    "Give feedback" : "Dar opinión",
+    "Get started" : "Comenzar",
+    "No changelog available" : "No hay un registro de cambios disponible",
+    "What's new in {app} {version}" : "Novedades en {app} {version}",
+    "A new version is available: <strong>{newVersionString}</strong>" : "La nueva versión está disponible: <strong>{newVersionString}</strong>",
+    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Tenga en cuenta que tras un nuevo lanzamiento, la actualización sólo se mostrará después de la primera versión menor o posterior. Las nuevas versiones se distribuyen a lo largo del tiempo y a veces se omiten versiones cuando se encuentran problemas. Obtenga  más información acerca de las actualizaciones y los canales de lanzamiento en {link}",
+    "Checked on {lastCheckedDate} - Open changelog" : "Comprobado en {lastCheckedDate} - Abrir registro de cambios",
+    "Checking apps for compatible versions" : "Comprobando que las apps tengan actualizaciones compatibles",
+    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Por favor, asegúrate de que tu config.php no tiene configurado <samp>appstoreenabled</samp> como 'false'.",
+    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "No se ha podido conectar a la App Store o no se ha devuelto ninguna actualización. Busque manualmente las actualizaciones o asegúrese de que su servidor tiene acceso a Internet y pueda conectarse a la App Store.",
+    "<strong>All</strong> apps have a compatible version for this {productName} version available." : "<strong>Todas</strong> las apps tienen una versión compatible para la versión de {productName} disponible.",
+    "_<strong>%n</strong> app has no compatible version for this {productName} version available._::_<strong>%n</strong> apps have no compatible version for this {productName} version available._" : ["<strong>%n</strong> app no tiene una versión compatible para la versión de {productName} disponible.","<strong>%n</strong> apps no tienen una versión compatible para la versión de {productName} disponible.","<strong>%n</strong> apps no tienen una versión compatible para la versión de {productName} disponible."],
+    "Enterprise" : "Empresa",
+    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately." : "Para uso empresarial. Siempre provee el último nivel de parches, pero no actualizará a la próxima versión mayor de manera inmediata.",
+    "That update happens once {vendor} has done additional hardening and testing for large-scale and mission-critical deployments." : "Esta actualización sucede una vez que {vendor} ha hecho endurecimiento y pruebas adicionales para despliegues a larga escala y misión crítica.",
+    "This channel is only available to customers and provides the {enterprise} package." : "Este canal está disponible solamente para clientes y provee el paquete {enterprise}.",
+    "Stable" : "Estable",
+    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Es la versión estable más reciente. Es adecuada para uso en producción y siempre se actualizará a la última versión principal.",
+    "Beta" : "Beta",
+    "A pre-release version only for testing new features, not for production environments." : "Es la versión preliminar para poder probar nuevas características, no para entornos de producción.",
     "Update" : "Actualizar",
     "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "La versión que usas yo no está mantenida. Por favor, asegúrate de actualizar a una versión reciente tan pronto como sea posible.",
     "Apps missing compatible version" : "Apps sin versión compatible",
     "View in store" : "Ver en la tienda",
     "Apps with compatible version" : "Apps con versión compatible",
+    "Please note that the web updater is not recommended with more than 100 accounts! Please use the command line updater instead!" : "¡Tenga en cuenta que el actualizador web no se recomienda con más de 100 usuarios! por favor, ¡utilice el actualizador de la línea de comandos!",
     "Open updater" : "Abrir el actualizador",
     "Download now" : "Descargar ahora",
     "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "El actualizador web está desactivado. Por favor, utilice el actualizador de línea de comandos o el mecanismo de actualización apropiado para su método de instalación (p. ej., Docker pull) para actualizar.",
@@ -32,26 +56,11 @@ OC.L10N.register(
     "Only notifications for app updates are available." : "Solo están disponibles las notificaciones para actualizaciones de apps.",
     "The selected update channel makes dedicated notifications for the server obsolete." : "El canal de actualización seleccionado hace obsoletas las notificaciones dedicadas para el servidor.",
     "The selected update channel does not support updates of the server." : "El canal de actualización seleccionado no soporta actualizaciones del servidor",
-    "A new version is available: <strong>{newVersionString}</strong>" : "La nueva versión está disponible: <strong>{newVersionString}</strong>",
-    "Checked on {lastCheckedDate} - Open changelog" : "Comprobado en {lastCheckedDate} - Abrir registro de cambios",
-    "Checking apps for compatible versions" : "Comprobando las versiones comatibles de las apps ",
-    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Por favor, asegúrate de que tu config.php no tiene configurado <samp>appstoreenabled</samp> como 'false'.",
-    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "No se ha podido conectar a la App Store o no se ha devuelto ninguna actualización. Busque manualmente las actualizaciones o asegúrese de que su servidor tiene acceso a Internet y pueda conectarse a la App Store.",
+    "Changelog for app {app}" : "Registro de cambios para la aplicación {app}",
+    "What's new in {app} version {version}" : "Novedades en {app} versión {version}",
+    "{version} is available. Get more information on how to update." : "{version} está disponible. Obtenga más información sobre cómo actualizar.",
     "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Todas</strong> las apps son compatibles con esta versión de Nextcloud.",
-    "Enterprise" : "Empresa",
-    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Para uso empresarial. Proporciona siempre el último nivel de actualización, pero no realiza inmediatamente la actualización a la siguiente versión mayor. La actualización ocurre cuando Nextcloud GmbH ha realizado una revisión dedicada, pruebas para despliegues a gran escala y servicios críticos. Este canal está disponible únicamente para los clientes del paquete Nextcloud Enterprise.",
-    "Stable" : "Estable",
-    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Es la versión estable más reciente. Es adecuada para uso en producción y siempre se actualizará a la última versión principal.",
-    "Beta" : "Beta",
-    "A pre-release version only for testing new features, not for production environments." : "Es la versión preliminar para poder probar nuevas características, no para entornos de producción.",
     "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> app no es compatible con esta versión de Nextcloud.","<strong>%n</strong> apps no son compatibles con la versión de Nextcloud.","<strong>%n</strong> apps no son compatibles con la versión de Nextcloud."],
-    "Update to %1$s is available." : "La actualización a %1$s está disponible.",
-    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Muestra notificaciones de actualizaciones para Nexcloud y provee el SSO para el actualizador.",
-    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "¡Tenga en cuenta que el actualizador web no se recomienda con más de 100 usuarios!. ¡Por favor, utilice el actualizador de línea de comandos en su lugar!",
-    "Please use the command line updater to update." : "Por favor, utilice el actualizador de línea de comandos para actualizar.",
-    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Puede cambiar el canal de actualización a continuación, lo que también afecta a la página de administración de aplicaciones. P. ej., después de cambiar al canal beta, las actualizaciones de aplicaciones beta se ofrecerán en la página de administración de aplicaciones.",
-    "Update channel:" : "Canal de actualización: ",
-    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Tenga en cuenta que tras un nueva lanzamiento, la actualización sólo se mostrará después de la primera versión menor o posterior. Las nuevas versiones se distribuyen entre nuestros usuarios a lo largo del tiempo y a veces se omite una versión cuando se encuentran problemas. Obtenga  más información sobre las actualizaciones y los canales de lanzamiento en {link}",
-    "Checked on {lastCheckedDate}" : "Comprobado el {lastCheckedDate}"
+    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Para uso empresarial. Proporciona siempre el último nivel de actualización, pero no realiza inmediatamente la actualización a la siguiente versión mayor. La actualización ocurre cuando Nextcloud GmbH ha realizado una revisión dedicada, pruebas para despliegues a gran escala y servicios críticos. Este canal está disponible únicamente para los clientes del paquete Nextcloud Enterprise."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
