@@ -37,6 +37,9 @@ use OCP\Util;
  * @package OC\Core
  */
 class Application extends App {
+
+	public const APP_ID = 'core';
+
 	public function __construct() {
 		parent::__construct('core');
 
@@ -237,6 +240,12 @@ class Application extends App {
 				'systag_objecttype',
 				['objecttype']
 			);
+
+			$event->addMissingUniqueIndex(
+				'vcategory',
+				'unique_category_per_user',
+				['uid', 'type', 'category']
+			);
 		});
 
 		$eventDispatcher->addListener(AddMissingPrimaryKeyEvent::class, function (AddMissingPrimaryKeyEvent $event) {
