@@ -18,17 +18,15 @@ OC.L10N.register(
     "Unknown filetype" : "Неизвестен тип файл",
     "An error occurred. Please contact your admin." : "Възникна неизвестна грешка. Свържете с администратора.",
     "Invalid image" : "Невалидно изображение",
-    "No temporary profile picture available, try again" : "Не е налична временна профилна снимка, опитайте отново",
-    "No crop data provided" : "Липсват данни за изрязването",
-    "No valid crop data provided" : "Данни за изрязването са невалидни",
-    "Crop is not square" : "Областта не е квадратна",
     "State token does not match" : "Маркер на състояние не съвпада",
     "Invalid app password" : "Невалидна парола за приложението",
     "Could not complete login" : "Не може да завърши влизането",
     "State token missing" : "Липсва токен/маркер/ на състоянието",
     "Your login token is invalid or has expired" : "Вашият маркер за вход е невалиден или е изтекъл",
+    "Please use original client" : "Моля, използвайте оригиналния клиент.",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Тази общностна версия на Nextcloud не се поддържа и push известия са ограничени.",
     "Login" : "Вписване",
+    "Unsupported email length (>255)" : "Дължината на е-мейлът не се поддържа (>255 символа)",
     "Password reset is disabled" : "Възстановяването на пароли е забранено",
     "Could not reset password because the token is expired" : "Възстановяването на паролата е неуспешно, защото токенът е с изтекла валидност",
     "Could not reset password because the token is invalid" : "Възстановяването на паролата е неуспешно, защото токенът е невалиден",
@@ -38,8 +36,13 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Кликнете върху следния бутон, за да възстановите паролата си. Ако не сте поискали възстановяване на паролата, игнорирайте този имейл.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Кликнете върху следната връзка, за да възстановите паролата си. Ако не сте поискали възстановяване на паролата, игнорирайте този имейл.",
     "Reset your password" : "Възстановяване на вашата парола",
+    "The given provider is not available" : "Доставчикът не е наличен",
+    "Task not found" : "Задачата не е открита",
     "Internal error" : "Вътрешна грешка",
     "Not found" : "Не е намерен",
+    "Node is locked" : "Точката е заключена (Node is locked)",
+    "Bad request" : "Лоша заявка",
+    "Requested task type does not exist" : "Заявената задача не съществува",
     "Image not found" : "Изображението не е открито",
     "No translation provider available" : "Няма наличен доставчик на преводи",
     "Could not detect language" : "Не можа да се установи езика",
@@ -72,16 +75,6 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "Следните приложения са изключени: %s",
     "Already up to date" : "Актуално",
     "Unknown" : "Неизвестен",
-    "Error occurred while checking server setup" : "Възникна грешка при проверката на настройките на сървъра",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "За повече подробности вижте {linkstart}документацията ↗{linkend}.",
-    "unknown text" : "непознат текст",
-    "Hello world!" : "Здравей Свят!",
-    "sunny" : "слънчево",
-    "Hello {name}, the weather is {weather}" : "Здравейте {name}, времето е {weather}",
-    "Hello {name}" : "Здравейте, {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Това са вашите резултати от търсенето<script>сигнал (1)</script></strong>",
-    "new" : "нов",
-    "_download %n file_::_download %n files_" : ["изтегли %n файл","изтегли %n файла"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Актуализирането е в процес, в някой среди - напускането на тази страница може да прекъсне процеса.",
     "Update to {version}" : "Актуализирай до {version}",
     "An error occurred." : "Възникна грешка.",
@@ -98,21 +91,29 @@ OC.L10N.register(
     "Invalid remote URL." : "невалиден отдалечен URL(адрес)",
     "Failed to add the public link to your Nextcloud" : "Неуспешно добавяне на публичната връзка към вашия Nextcloud",
     "Create share" : "Създаване на споделяне",
-    "Direct link copied to clipboard" : "Директният адрес е копиран в клипборда",
     "Please copy the link manually:" : "Моля копирайте адреса ръчно:",
-    "Searching …" : "Търсене ...",
+    "Search in date range" : "Търси във времеви период",
+    "Search in current app" : "Търси в настоящето приложение",
+    "Clear search" : "Изчисти търсенето",
+    "Search everywhere" : "Търси навсякъде",
     "Start typing to search" : "Започнете да пишете, за търсене",
     "Today" : "Днес",
+    "Last 7 days" : "Последните 7 дни",
+    "Last 30 days" : "Последните 30 дни",
     "This year" : "Тази година",
     "Last year" : "Миналата година",
+    "Unified search" : "Глобално търсене",
+    "Search apps, files, tags, messages" : "Търси приложения, файлове, тагове, съобщения",
     "Places" : "Места",
     "Date" : "Дата",
+    "Search people" : "Търси хора",
     "People" : "Хора",
     "Results" : "Резултати",
     "Load more results" : "Зареждане на още резултати",
+    "Search in" : "Търси в",
     "Log in" : "Вписване",
-    "Logging in …" : "Вписване ...",
     "Log in to {productName}" : "Вписване в {productName}",
+    "This account is disabled" : "Профилът е неактивен",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Открихме множество невалидни опити за влизане от вашия IP. Следователно следващото ви влизане се ограничава за 30 секунди.",
     "Account name or email" : "Име на профил или имейл",
     "Account name" : "Име на профил",
@@ -141,20 +142,15 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Документи, електронни таблици и презентации за съвместна работа, създадени в Collabora Online.",
     "Distraction free note taking app." : "Приложение за водене на бележки без разсейване.",
     "Recommended apps" : "Препоръчани приложения",
-    "Loading apps …" : "Зареждане на приложения ...",
     "Could not fetch list of apps from the App Store." : "Списъкът с приложения не можа да се извлече от App Store.",
     "App download or installation failed" : "Изтеглянето или инсталирането на приложението беше неуспешно",
     "Cannot install this app because it is not compatible" : "Това приложение не може да се инсталира, защото е несъвместимо",
     "Cannot install this app" : "Това приложение не може да се инсталира",
     "Skip" : "Пропускане",
-    "Installing apps …" : "Инсталиране на приложения ...",
     "Install recommended apps" : "Инсталиране на препоръчаните приложения ",
     "Settings menu" : "Настройки",
-    "Loading your contacts …" : "Зареждане на контактите ...",
-    "Looking for {term} …" : "Търси се {term} …",
-    "Search contacts" : "Търсене на/в/ контакти",
-    "Reset search" : "Рестартирай търсенето",
-    "Search contacts …" : "Търсене в контактите ...",
+    "Search contacts" : "Търсене в контакти",
+    "Reset search" : "Ново търсене",
     "Could not load your contacts" : "Контактите не могат да бъдат заредени",
     "No contacts found" : "Няма намерени контакти",
     "Show all contacts" : "Показване на всички контакти",
@@ -166,7 +162,6 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Възникна грешка при търсенето на {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Търсенето започва, след като започнете да пишете, а до резултатите можете да стигнете с клавишите със стрелки.",
     "Search for {name} only" : "Търсене само за {name}",
-    "Loading more results …" : "Зарежда още резултати…",
     "Forgot password?" : "Забравена парола?",
     "Back" : "Назад",
     "Login form is disabled." : "Формулярът за вход е деактивиран",
@@ -186,7 +181,6 @@ OC.L10N.register(
     "Database tablespace" : "Tablespace на базата данни",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Моля, посочете номера на порта заедно с името на хоста (напр. Localhost: 5432).",
     "Database host" : "Хост",
-    "Installing …" : "В процес на инсталиране…",
     "Install" : "Инсталиране",
     "Need help?" : "Нуждаете се от помощ?",
     "See the documentation" : "Прегледайте документацията",
@@ -195,7 +189,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Вашият браузър не се поддържа. Моля, преминете към по-нова версия или към версия, която се поддържа.",
     "Continue with this unsupported browser" : "Продължете с този неподдържан браузър",
     "Supported versions" : "Поддържани версии",
-    "Search {types} …" : "Търсене на  {types}  ...",
     "Choose" : "Избор",
     "Copy" : "Копирай",
     "Move" : "Премести",
@@ -212,7 +205,7 @@ OC.L10N.register(
     "(all selected)" : "(всички избрани)",
     "({count} selected)" : "({count} избрани)",
     "Error loading file exists template" : "Грешка при зареждането на шаблона за вече съществуващ файл",
-    "Saving …" : "Записване …",
+    "Saving …" : "Запазване ...",
     "seconds ago" : "преди секунди",
     "Connection to server lost" : "Няма връзка със сървъра",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Проблем при зареждането на страницата, презареждане след %n секунда","Проблем при зареждането на страницата, презареждане след %n секунди"],
@@ -227,17 +220,9 @@ OC.L10N.register(
     "Type to search for existing projects" : "Въведете, за търсене на съществуващи проекти",
     "New in" : "Ново в",
     "View changelog" : "Преглед на списъка с промени",
-    "No action available" : "Няма налични действия",
-    "Error fetching contact actions" : "Грешка при извличането на действия за контакт",
     "Close \"{dialogTitle}\" dialog" : "Затваряне на диалогов прозорец \"{dialogTitle}\"",
-    "Non-existing tag #{tag}" : "Несъществуващ етикет #{tag}",
-    "Restricted" : "Ограничен",
-    "Invisible" : "Невидим",
-    "Delete" : "Изтрий",
-    "Rename" : "Преименувай",
-    "Collaborative tags" : "Съвместни етикети",
-    "No tags found" : "Не са открити етикети",
     "Personal" : "Лични",
+    "Accounts" : "Профили",
     "Admin" : "Админ",
     "Help" : "Помощ",
     "Access forbidden" : "Достъпът е забранен",
@@ -315,24 +300,50 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "В момента се извършва профилактика на %s, може да продължи дълго.",
     "This page will refresh itself when the instance is available again." : "Страницата ще се зареди автоматично, когато е отново на линия.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Свържете се със системния администратор ако това съобщение се задържи твърде дълго или се е появило неочаквано.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Чат, видео разговори, споделяне на екрана, онлайн срещи и уеб конферентни връзки - във вашия браузър и с мобилни приложения.",
-    "You have not added any info yet" : "Все още не сте добавили никаква информация",
-    "{user} has not added any info yet" : "{user} все още не е добавил никаква информация",
-    "Error opening the user status modal, try hard refreshing the page" : "Грешка при отваряне на модалния статус на потребителя, опитайте настоятелно да опресните страницата",
-    "Edit Profile" : "Редактиране на профил",
-    "The headline and about sections will show up here" : "Заглавието и секцията за информация ще се покажат тук",
+    "Error occurred while checking server setup" : "Възникна грешка при проверката на настройките на сървъра",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "За повече подробности вижте {linkstart}документацията ↗{linkend}.",
+    "unknown text" : "непознат текст",
+    "Hello world!" : "Здравей Свят!",
+    "sunny" : "слънчево",
+    "Hello {name}, the weather is {weather}" : "Здравейте {name}, времето е {weather}",
+    "Hello {name}" : "Здравейте, {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Това са вашите резултати от търсенето<script>сигнал (1)</script></strong>",
+    "new" : "нов",
+    "_download %n file_::_download %n files_" : ["изтегли %n файл","изтегли %n файла"],
+    "Direct link copied to clipboard" : "Директният адрес е копиран в клипборда",
+    "Searching …" : "Търсене ...",
+    "Logging in …" : "Вписване ...",
+    "Loading apps …" : "Зареждане на приложения ...",
+    "Installing apps …" : "Инсталиране на приложения ...",
+    "Loading your contacts …" : "Зареждане на контактите ...",
+    "Looking for {term} …" : "Търси се {term} …",
+    "Search contacts …" : "Търсене в контактите ...",
+    "Loading more results …" : "Зарежда още резултати…",
+    "Search {types} …" : "Търсене на  {types}  ...",
+    "Saving …" : "Записване …",
     "Very weak password" : "Много проста парола",
     "Weak password" : "Проста парола",
     "So-so password" : "Не особено добра парола",
     "Good password" : "Добра парола",
     "Strong password" : "Сложна парола",
-    "Profile not found" : "Профилът не е намерен",
-    "The profile does not exist." : "Профилът не съществува.",
+    "No action available" : "Няма налични действия",
+    "Error fetching contact actions" : "Грешка при извличането на действия за контакт",
+    "Non-existing tag #{tag}" : "Несъществуващ етикет #{tag}",
+    "Restricted" : "Ограничен",
+    "Invisible" : "Невидим",
+    "Delete" : "Изтрий",
+    "Rename" : "Преименувай",
+    "Collaborative tags" : "Съвместни етикети",
+    "No tags found" : "Не са открити етикети",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Директория с данни и файлове ви са вероятно са достъпни от Интернет, защото файлът \".htaccess\" не функционира.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Информация, как да настроите сървъра коректно, ще намерите в <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацията</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Създай администраторски профил</strong>",
+    "New admin account name" : "Ново име на администраторския профил",
     "Show password" : "Покажи парола",
     "Toggle password visibility" : "Превключване на видимостта на парола",
     "Configure the database" : "Конфигуриране на базата данни",
-    "Only %s is available." : "Само %s е наличен."
+    "Only %s is available." : "Само %s е наличен.",
+    "Database account" : "Профил за база данни",
+    "Installing …" : "В процес на инсталиране…"
 },
 "nplurals=2; plural=(n != 1);");
