@@ -18,15 +18,12 @@ OC.L10N.register(
     "Unknown filetype" : "Tipus de fitxer desconegut",
     "An error occurred. Please contact your admin." : "S'ha produït un error. Contacteu amb l'administrador.",
     "Invalid image" : "La imatge no és vàlida",
-    "No temporary profile picture available, try again" : "No hi ha cap imatge temporal de perfil disponible; torneu-ho a provar",
-    "No crop data provided" : "No s'han proporcionat dades de retall",
-    "No valid crop data provided" : "Les dades de retall proporcionades no són vàlides",
-    "Crop is not square" : "El retall no és quadrat",
     "State token does not match" : "El testimoni d'estat no coincideix",
     "Invalid app password" : "La contrasenya de l'aplicació no és vàlida",
     "Could not complete login" : "No s'ha pogut completar l'inici de sessió",
     "State token missing" : "Falta el testimoni d'estat",
     "Your login token is invalid or has expired" : "El testimoni d'inici de sessió no és vàlid o ha caducat",
+    "Please use original client" : "Si us plau, utilitzeu el client original",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Aquesta versió de la comunitat del Nextcloud no té suport i les notificacions automàtiques estan limitades.",
     "Login" : "Inici de sessió",
     "Unsupported email length (>255)" : "Longitud de correu electrònic no admesa (>255)",
@@ -43,6 +40,7 @@ OC.L10N.register(
     "Task not found" : "No s'ha trobat la tasca",
     "Internal error" : "Error intern",
     "Not found" : "No s'ha trobat",
+    "Node is locked" : "El node està bloquejat",
     "Bad request" : "Sol·licitud incorrecta",
     "Requested task type does not exist" : "El tipus de tasca sol·licitat no existeix",
     "Necessary language model provider is not available" : "El proveïdor de models de llengua necessari no està disponible",
@@ -51,6 +49,7 @@ OC.L10N.register(
     "No translation provider available" : "No hi ha cap proveïdor de traduccions disponible",
     "Could not detect language" : "No s'ha pogut detectar la llengua",
     "Unable to translate" : "No s'ha pogut traduir",
+    "No valid filters provided" : "No s'han proporcionat filtres vàlids",
     "[%d / %d]: %s" : "[%d/%d]: %s",
     "Repair step:" : "Pas de reparació:",
     "Repair info:" : "Informació de reparació:",
@@ -79,16 +78,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (no compatible)",
     "The following apps have been disabled: %s" : "S'han inhabilitat les aplicacions següents: %s",
     "Already up to date" : "Ja teniu la versió més recent",
+    "Windows Command Script" : "Script d'ordres de Windows",
+    "Electronic book document" : "Document de llibre electrònic",
+    "TrueType Font Collection" : "Col·lecció de fonts TrueType",
+    "Web Open Font Format" : "Format de font oberta per a web",
+    "GPX geographic data" : "Dades geogràfiques GPX",
+    "Gzip archive" : "Arxiu gzip",
+    "Adobe Illustrator document" : "Document d'Adobe Illustrator",
+    "Java source code" : "Codi font de Java",
+    "JavaScript source code" : "Codi font Javascript",
+    "JSON document" : "Document JSON",
+    "Microsoft Access database" : "Fitxer de base de dades Microsoft Access",
+    "Microsoft OneNote document" : "Document de Microsoft OneNote",
+    "Microsoft Word document" : "Document del Microsoft Word",
     "Unknown" : "Desconegut",
+    "PDF document" : "Aquest document PDF potser no es mostra correctament.",
+    "PostScript document" : "Document PostScript",
+    "RSS summary" : "Resum RSS",
+    "Android package" : "Paquet d'Android",
+    "KML geographic data" : "Dades geogràfiques KML",
+    "KML geographic compressed data" : "Dades geogràfiques comprimides en KML",
+    "Lotus Word Pro document" : "Documetn del Lotus Word Pro",
+    "Excel spreadsheet" : "Baixa full de càlcul Excel",
+    "Excel add-in" : "Complement d'Excel",
+    "Excel 2007 binary spreadsheet" : "Full de càlcul binari de l'Excel 2007",
+    "Excel spreadsheet template" : "Plantilla de full de càlcul d'Excel",
+    "Outlook Message" : "Missatge d'Outlook",
+    "PowerPoint presentation" : "Presentació del Microsoft PowerPoint",
+    "PowerPoint add-in" : "Complement del PowerPoint",
+    "PowerPoint presentation template" : "Plantilla de presentació del Microsoft PowerPoint",
+    "Word document" : "Document del MS Word",
+    "ODF formula" : "Fórmula ODF",
+    "ODG drawing" : "Dibuix ODG",
+    "ODG drawing (Flat XML)" : "Dibuix ODG (XML pla)",
+    "ODG template" : "Plantilla ODG",
+    "ODP presentation" : "Presentació de l'ODP",
+    "ODP presentation (Flat XML)" : "Presentació ODP (XML pla)",
+    "ODP template" : "Plantilla ODP",
+    "ODS spreadsheet" : "Full de càlcul ODS",
+    "ODS spreadsheet (Flat XML)" : "Full de càlcul ODS (XML pla)",
+    "ODS template" : "Plantilla ODS",
+    "ODT document" : "Document ODT",
+    "ODT document (Flat XML)" : "Document ODT (XML pla)",
+    "ODT template" : "Plantilla ODT",
+    "PowerPoint 2007 presentation" : "Presentació de PowerPoint 2007",
+    "PowerPoint 2007 show" : "Presentació de PowerPoint 2007",
+    "PowerPoint 2007 presentation template" : "Plantilla de presentació de PowerPoint 2007",
+    "Excel 2007 spreadsheet" : "Full de càlcul de l'Excel 2007",
+    "Excel 2007 spreadsheet template" : "Plantilla de full de càlcul de l'Excel 2007",
+    "Word 2007 document" : "Document de Word 2007",
+    "Word 2007 document template" : "Plantilla de document de Word 2007",
+    "Microsoft Visio document" : "Document de Microsoft Visio",
+    "WordPerfect document" : "Document del WordPerfect",
+    "7-zip archive" : "Arxiu 7-zip",
+    "Blender scene" : "Escena de Blender",
+    "Bzip2 archive" : "Arxiu Bzip2",
+    "Debian package" : "Paquet Debian",
+    "FictionBook document" : "Document de llibre de ficció",
+    "Unknown font" : "No es pot renderitzar el tipus de lletra desconegut:\n%s",
+    "Krita document" : "Document del Krita",
+    "Mobipocket e-book" : "Llibre electrònic Mobipocket",
+    "Windows Installer package" : "Paquet d'instal·lació de Windows",
+    "Perl script" : "Script de Perl",
+    "PHP script" : "Script de PHP",
+    "Tar archive" : "Arxiu tar",
+    "XML document" : "Document XML",
+    "YAML document" : "Document YAML",
+    "Zip archive" : "Arxiu zip",
+    "Zstandard archive" : "Arxiu Zstandard",
+    "AAC audio" : "Àudio AAC",
+    "FLAC audio" : "Àudio FLAC",
+    "MPEG-4 audio" : "Àudio MPEG-4",
+    "MP3 audio" : "Àudio MP3",
+    "Ogg audio" : "Àudio Ogg",
+    "RIFF/WAVe standard Audio" : "Àudio estàndard RIFF/WAVe",
+    "WebM audio" : "Àudio WebM",
+    "MP3 ShoutCast playlist" : "Llista de reproducció MP3 de ShoutCast",
+    "Windows BMP image" : "Imatge BMP del Windows",
+    "Better Portable Graphics image" : "Millor imatge de gràfics portàtils",
+    "EMF image" : "Imatge EMF",
+    "GIF image" : "Imatge GIF",
+    "HEIC image" : "Imatge HEIC",
+    "HEIF image" : "Imatge HEIF",
+    "JPEG-2000 JP2 image" : "Imatge JPEG-2000 JP2",
+    "JPEG image" : "Imatge JPEG",
     "PNG image" : "Imatge PNG",
-    "unknown text" : "text desconegut",
-    "Hello world!" : "Hola a tothom!",
-    "sunny" : "assolellat",
-    "Hello {name}, the weather is {weather}" : "Hola, {name}, el temps és {weather}",
-    "Hello {name}" : "Hola, {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Aquests són els resultats de la cerca<script>alert(1)</script></strong>",
-    "new" : "nou",
-    "_download %n file_::_download %n files_" : ["baixa %n fitxer","baixa %n fitxers"],
+    "SVG image" : "Imatge SVG",
+    "Truevision Targa image" : "Imatge de TrueVision Targa",
+    "TIFF image" : "Imatge TIFF",
+    "WebP image" : "Imatge WebP",
+    "Digital raw image" : "Imatge digital en brut",
+    "Windows Icon" : "Icona de Windows",
+    "Email message" : "Missatge de correu electrònic",
+    "VCS/ICS calendar" : "Calendari VCS/ICS",
+    "CSS stylesheet" : "Full d'estil CSS",
+    "CSV document" : "Document CSV",
+    "HTML document" : "Document HTML",
+    "Markdown document" : "Document de Markdown",
+    "Org-mode file" : "Fitxer en mode org",
+    "Plain text document" : "Document de text pla",
+    "Rich Text document" : "Document de text enriquit",
+    "Electronic business card" : "Targeta de visita electrònica",
+    "C++ source code" : "Codi font de C++",
+    "LDIF address book" : "Llibreta d'adreces LDIF",
+    "NFO document" : "Document NFO",
+    "PHP source" : "Font PHP",
+    "Python script" : "Script de Python",
+    "ReStructuredText document" : "Document de text reestructurat",
+    "3GPP multimedia file" : "Fitxer multimèdia 3GPP",
+    "MPEG video" : "Vídeo MPEG",
+    "DV video" : "Vídeo DV",
+    "MPEG-2 transport stream" : "Flux de transport MPEG-2",
+    "MPEG-4 video" : "Vídeo MPEG-4",
+    "Ogg video" : "Vídeo Ogg",
+    "QuickTime video" : "Vídeo QuickTime",
+    "WebM video" : "Vídeo WebM",
+    "Flash video" : "Vídeo flash",
+    "Matroska video" : "Vídeo de Matroska",
+    "Windows Media video" : "Vídeo de Windows Media",
+    "AVI video" : "Vídeo AVI",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "L'actualització està en curs; si sortiu d'aquesta pàgina, és possible que s'interrompi el procés en alguns entorns.",
     "Update to {version}" : "Actualització a la versió {version}",
     "An error occurred." : "S'ha produït un error.",
@@ -109,6 +217,7 @@ OC.L10N.register(
     "Federated user" : "Usuari federat",
     "user@your-nextcloud.org" : "usuari@el-teu-nextcloud.org",
     "Create share" : "Crea l'element compartit",
+    "Direct link copied" : "Enllaç directe copiat",
     "Please copy the link manually:" : "Copieu l'enllaç manualment:",
     "Custom date range" : "Interval de dates personalitzat",
     "Pick start date" : "Trieu la data d'inici",
@@ -117,14 +226,16 @@ OC.L10N.register(
     "Search in current app" : "Cerca a l'aplicació actual",
     "Clear search" : "Neteja la cerca",
     "Search everywhere" : "Cerca a tot arreu",
-    "Searching …" : "S'està cercant…",
+    "Searching …" : "Cercant …",
     "Start typing to search" : "Escriviu per a cercar",
+    "Minimum search length is {minSearchLength} characters" : "La longitud mínima de cerca és de {minSearchLength} caràcters",
     "No matching results" : "No hi ha resultats coincidents",
     "Today" : "Avui",
     "Last 7 days" : "Últims 7 dies",
     "Last 30 days" : "Últims 30 dies",
     "This year" : "Aquest any",
     "Last year" : "Últim any",
+    "Between {startDate} and {endDate}" : "Entre {startDate} i {endDate}",
     "Unified search" : "Cerca unificada",
     "Search apps, files, tags, messages" : "Cerca aplicacions, fitxers, etiquetes, missatges",
     "Places" : "Llocs",
@@ -132,11 +243,12 @@ OC.L10N.register(
     "Search people" : "Cerca gent",
     "People" : "Persones",
     "Filter in current view" : "Filtra a la vista actual",
+    "Search connected services" : "Cerca serveis connectats",
     "Results" : "Resultats",
     "Load more results" : "Carrega més resultats",
     "Search in" : "Cerca en",
     "Log in" : "Inicia la sessió",
-    "Logging in …" : "S'està iniciant la sessió…",
+    "Logging in …" : "S'està iniciant la sessió …",
     "Log in to {productName}" : "Inici de sessió del {productName}",
     "Wrong login or password." : "Inici de sessió o contrasenya incorrectes.",
     "This account is disabled" : "Aquest compte està inhabilitat",
@@ -145,6 +257,8 @@ OC.L10N.register(
     "Account name" : "Nom de compte",
     "Server side authentication failed!" : "S'ha produït un error en l'autenticació del servidor!",
     "Please contact your administrator." : "Contacteu amb l'administrador.",
+    "Session error" : "Error de sessió",
+    "It appears your session token has expired, please refresh the page and try again." : "Sembla que el vostre testimoni de sessió ha caducat. Si us plau, actualitzeu la pàgina i torneu-ho a intentar.",
     "An internal error occurred." : "S'ha produït un error intern.",
     "Please try again or contact your administrator." : "Torneu-ho a provar o contacteu amb l'administrador.",
     "Password" : "Contrasenya",
@@ -171,21 +285,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documents, fulls de càlcul i presentacions col·laboratius, basats en Collabora Online.",
     "Distraction free note taking app." : "Aplicació per a prendre notes sense distraccions.",
     "Recommended apps" : "Aplicacions recomanades",
-    "Loading apps …" : "S'estan carregant les aplicacions…",
+    "Loading apps …" : "S'estan carregant les aplicacions …",
     "Could not fetch list of apps from the App Store." : "No s'ha pogut obtenir la llista d'aplicacions de la botiga d'aplicacions.",
     "App download or installation failed" : "No s'ha pogut baixar o instal·lar l'aplicació",
     "Cannot install this app because it is not compatible" : "No s'ha pogut instal·lar aquesta aplicació, perquè no és compatible",
     "Cannot install this app" : "No es pot instal·lar aquesta aplicació",
     "Skip" : "Omet",
-    "Installing apps …" : "S'estan instal·lant les aplicacions…",
+    "Installing apps …" : "S'estan instal·lant les aplicacions …",
     "Install recommended apps" : "Instal·la les aplicacions recomanades",
     "Avatar of {displayName}" : "Avatar de {displayName}",
     "Settings menu" : "Menú de paràmetres",
-    "Loading your contacts …" : "S'estan carregant els contactes…",
-    "Looking for {term} …" : "S'està cercant {term}…",
+    "Loading your contacts …" : "S'estan carregant els contactes …",
+    "Looking for {term} …" : "S'està cercant {term} …",
     "Search contacts" : "Cerca de contactes",
     "Reset search" : "Reinicialitza la cerca",
-    "Search contacts …" : "Cerqueu contactes…",
+    "Search contacts …" : "Cerca contactes…",
     "Could not load your contacts" : "No s'han pogut carregar els contactes",
     "No contacts found" : "No s'ha trobat cap contacte",
     "Show all contacts" : "Mostra tots els contactes",
@@ -197,13 +311,18 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "S'ha produït un error mentre en cercar {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "La cerca comença quan escriviu i podeu accedir als resultats amb les tecles de cursor",
     "Search for {name} only" : "Cerca només de {name}",
-    "Loading more results …" : "S'estan carregant més resultats…",
+    "Loading more results …" : "S'estan carregant més resultats …",
     "Forgot password?" : "Heu oblidat la contrasenya?",
     "Back to login form" : "Torna al formulari d'inici de sessió",
     "Back" : "Torna",
     "Login form is disabled." : "El formulari d'inici de sessió està inhabilitat.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "El formulari d'inici de sessió de Nextcloud està desactivat. Utilitzeu una altra opció d'inici de sessió si està disponible o poseu-vos en contacte amb la vostra administració.",
     "More actions" : "Més accions",
+    "User menu" : "Menú d'usuari",
+    "Your guest name: {user}" : "Nom del vostre convidat: {user}",
+    "You are currently not identified." : "Actualment no esteu identificat/da.",
+    "Set public name" : "Estableix el nom públic",
+    "Change public name" : "Canviar el nom públic",
     "Password is too weak" : "La contrasenya és massa feble",
     "Password is weak" : "La contrasenya és feble",
     "Password is average" : "La contrasenya és mitjana",
@@ -222,6 +341,7 @@ OC.L10N.register(
     "Storage & database" : "Emmagatzematge i base de dades",
     "Data folder" : "Carpeta de dades",
     "Database configuration" : "Configuració de la base de dades",
+    "Database type" : "Tipus de base de dades",
     "Only {firstAndOnlyDatabase} is available." : "Només {firstAndOnlyDatabase} està disponible.",
     "Install and activate additional PHP modules to choose other database types." : "Instal·leu i activeu mòduls del PHP addicionals per a seleccionar altres tipus de bases de dades.",
     "For more details check out the documentation." : "Per a conèixer més detalls, consulteu la documentació.",
@@ -229,6 +349,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "Heu triat l'SQLite com a base de dades.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "L'SQLite només s'hauria d'utilitzar per a instàncies mínimes i de desenvolupament. Per a sistemes en producció, us recomanem un rerefons de base de dades diferent.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si utilitzeu clients per a la sincronització de fitxers, no es recomana en absolut l'ús de l'SQLite.",
+    "Database connection" : "Connexió a la base de dades",
     "Database user" : "Usuari de la base de dades",
     "Database password" : "Contrasenya de la base de dades",
     "Database name" : "Nom de la base de dades",
@@ -236,7 +357,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Especifiqueu el número de port, juntament amb el nom del servidor (per exemple, localhost:5432).",
     "Database host" : "Servidor de la base de dades",
     "localhost" : "localhost",
-    "Installing …" : "S'està instal·lant…",
+    "Installing …" : "S'està instal·lant …",
     "Install" : "Instal·la",
     "Need help?" : "Necessiteu ajuda?",
     "See the documentation" : "Consulteu la documentació",
@@ -245,7 +366,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "El vostre navegador no és compatible. Actualitzeu a una versió més recent o compatible.",
     "Continue with this unsupported browser" : "Continua amb aquest navegador no compatible",
     "Supported versions" : "Versions compatibles",
-    "Search {types} …" : "Cerqueu {types}…",
+    "Search {types} …" : "Cerca {types} …",
     "Choose {file}" : "Tria {file}",
     "Choose" : "Tria",
     "Copy to {target}" : "Copia a {target}",
@@ -265,7 +386,7 @@ OC.L10N.register(
     "(all selected)" : "(selecció: tot)",
     "({count} selected)" : "(selecció: {count})",
     "Error loading file exists template" : "S'ha produït un error en carregar la plantilla de fitxer existent",
-    "Saving …" : "S'està desant…",
+    "Saving …" : "S'està desant…",
     "seconds ago" : "fa uns segons",
     "Connection to server lost" : "S'ha perdut la connexió amb el servidor",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Hi ha hagut un problema en carregar la pàgina, es tornarà a carregar d'aquí a %n segon","Hi ha hagut un problema en carregar la pàgina, es tornarà a carregar d'aquí a %n segons"],
@@ -280,23 +401,15 @@ OC.L10N.register(
     "Type to search for existing projects" : "Escriviu per a cercar projectes existents",
     "New in" : "Nou a",
     "View changelog" : "Mostra el registre de canvis",
-    "No action available" : "No hi ha cap acció disponible",
-    "Error fetching contact actions" : "S'ha produït un error en carregar les accions del contacte",
     "Close \"{dialogTitle}\" dialog" : "Tanca el quadre de diàleg «{dialogTitle}»",
     "Email length is at max (255)" : "La longitud del correu electrònic és màxima (255)",
-    "Non-existing tag #{tag}" : "L'etiqueta #{tag} no existeix",
-    "Restricted" : "Restringit",
-    "Invisible" : "Invisible",
-    "Delete" : "Suprimeix",
-    "Rename" : "Canvia el nom",
-    "Collaborative tags" : "Etiquetes col·laboratives",
-    "No tags found" : "No s'ha trobat cap etiqueta",
     "Clipboard not available, please copy manually" : "El porta-retalls no està disponible; copieu-lo manualment",
     "Personal" : "Personal",
     "Accounts" : "Comptes",
     "Admin" : "Administració",
     "Help" : "Ajuda",
     "Access forbidden" : "Accés prohibit",
+    "You are not allowed to access this page." : "No teniu permís per accedir a aquesta pàgina.",
     "Back to %s" : "Torna a %s",
     "Page not found" : "No s'ha trobat la pàgina",
     "The page could not be found on the server or you may not be allowed to view it." : "No s'ha trobat la pàgina en el servidor o és possible que no tingueu permís per a visualitzar-la.",
@@ -377,19 +490,39 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacteu amb l'administrador del sistema si aquest missatge persisteix o si apareix inesperadament.",
     "Error occurred while checking server setup" : "S'ha produït un error en comprovar la configuració del servidor",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Per a conèixer més detalls, consulteu la {linkstart}documentació ↗{linkend}.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Xat, videotrucades, pantalla compartida, reunions en línia i conferències per Internet; en el navegador i amb aplicacions mòbils.",
-    "You have not added any info yet" : "Encara no heu afegit cap informació",
-    "{user} has not added any info yet" : "{user} encara no ha afegit cap informació",
-    "Error opening the user status modal, try hard refreshing the page" : "S'ha produït un error en obrir el quadre de diàleg modal d'estat de l'usuari, proveu d'actualitzar la pàgina",
-    "Edit Profile" : "Edita el perfil",
-    "The headline and about sections will show up here" : "La capçalera i les seccions d'informació es mostraran aquí",
+    "unknown text" : "text desconegut",
+    "Hello world!" : "Hola a tothom!",
+    "sunny" : "assolellat",
+    "Hello {name}, the weather is {weather}" : "Hola, {name}, el temps és {weather}",
+    "Hello {name}" : "Hola, {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Aquests són els resultats de la cerca<script>alert(1)</script></strong>",
+    "new" : "nou",
+    "_download %n file_::_download %n files_" : ["baixa %n fitxer","baixa %n fitxers"],
+    "Direct link copied to clipboard" : "Enllaç directe copiat al porta-retalls",
+    "Searching …" : "S'està cercant…",
+    "Logging in …" : "S'està iniciant la sessió…",
+    "Loading apps …" : "S'estan carregant les aplicacions…",
+    "Installing apps …" : "S'estan instal·lant les aplicacions…",
+    "Loading your contacts …" : "S'estan carregant els contactes…",
+    "Looking for {term} …" : "S'està cercant {term}…",
+    "Search contacts …" : "Cerqueu contactes…",
+    "Loading more results …" : "S'estan carregant més resultats…",
+    "Search {types} …" : "Cerqueu {types}…",
+    "Saving …" : "S'està desant…",
     "Very weak password" : "Contrasenya molt feble",
     "Weak password" : "Contrasenya feble",
     "So-so password" : "Contrasenya justa",
     "Good password" : "Contrasenya bona",
     "Strong password" : "Contrasenya forta",
-    "Profile not found" : "No s'ha trobat el perfil",
-    "The profile does not exist." : "El perfil no existeix.",
+    "No action available" : "No hi ha cap acció disponible",
+    "Error fetching contact actions" : "S'ha produït un error en carregar les accions del contacte",
+    "Non-existing tag #{tag}" : "L'etiqueta #{tag} no existeix",
+    "Restricted" : "Restringit",
+    "Invisible" : "Invisible",
+    "Delete" : "Suprimeix",
+    "Rename" : "Canvia el nom",
+    "Collaborative tags" : "Etiquetes col·laboratives",
+    "No tags found" : "No s'ha trobat cap etiqueta",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "La carpeta de dades i els fitxers probablement són accessibles des d'Internet perquè el fitxer .htaccess no funciona.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Per a obtenir informació sobre com configurar correctament el servidor, consulteu la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentació</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Creació d'un compte d'administrador</strong>",
@@ -400,6 +533,6 @@ OC.L10N.register(
     "Configure the database" : "Configuració de la base de dades",
     "Only %s is available." : "Només hi ha disponible %s.",
     "Database account" : "Compte de base de dades",
-    "Direct link copied to clipboard" : "Enllaç directe copiat al porta-retalls"
+    "Installing …" : "S'està instal·lant…"
 },
 "nplurals=2; plural=(n != 1);");
