@@ -12,21 +12,18 @@ OC.L10N.register(
     "No file was uploaded" : "Ingen fil blev uploadet",
     "Missing a temporary folder" : "Mangler en midlertidig mappe",
     "Could not write file to disk" : "Kunne ikke skrive fil til disk",
-    "A PHP extension stopped the file upload" : "En PHP-udvidelse stoppede filoverførslen",
+    "A PHP extension stopped the file upload" : "En PHP udvidelse stoppede filoverførslen",
     "Invalid file provided" : "Der er angivet en ugyldig fil",
     "No image or file provided" : "Ingen fil eller billede givet",
     "Unknown filetype" : "Ukendt filtype",
     "An error occurred. Please contact your admin." : "Der opstod et problem. Kontakt venligst administratoren.",
     "Invalid image" : "Ugyldigt billede",
-    "No temporary profile picture available, try again" : "Intet midlertidigt profilbillede tilgængeligt, prøv igen",
-    "No crop data provided" : "Ingen beskæringsdata givet",
-    "No valid crop data provided" : "Der er ikke angivet gyldige data om beskæring",
-    "Crop is not square" : "Beskæringen er ikke kvadratisk",
     "State token does not match" : "Forkert tilstandsnøgle",
     "Invalid app password" : "Forkert app kodeord",
     "Could not complete login" : "Kunne ikke gennemføre login",
     "State token missing" : "Tilstands token mangler",
-    "Your login token is invalid or has expired" : "Din login-nøgle er ugyldig eller udløbet",
+    "Your login token is invalid or has expired" : "Din login token er ugyldigt eller udløbet",
+    "Please use original client" : "Anvend venligst original klient",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Denne fællesskabsudgivelse af Nextcloud er ikke understøttet, og push-meddelelser er begrænsede.",
     "Login" : "Login",
     "Unsupported email length (>255)" : "Ikke-understøttet e-maillængde (>255)",
@@ -43,6 +40,7 @@ OC.L10N.register(
     "Task not found" : "Opgaven blev ikke fundet",
     "Internal error" : "Intern fejl",
     "Not found" : "Ikke fundet",
+    "Node is locked" : "Grenen er låst",
     "Bad request" : "Forkert forespørgsel",
     "Requested task type does not exist" : "Den ønskede opgavetype findes ikke",
     "Necessary language model provider is not available" : "Nødvendig sprogmodeludbyder er ikke tilgængelig",
@@ -51,12 +49,13 @@ OC.L10N.register(
     "No translation provider available" : "Ingen tilgængelig oversættelsesudbyder",
     "Could not detect language" : "Kunne ikke finde sprog",
     "Unable to translate" : "Kan ikke oversætte",
+    "No valid filters provided" : "Ingen gyldige filtre leveret",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Reparationstrin:",
     "Repair info:" : "Reparationsinfo:",
     "Repair warning:" : "Reparationsadvarsel:",
     "Repair error:" : "Reparationsfejl:",
-    "Nextcloud Server" : "Nextcloud Server",
+    "Nextcloud Server" : "Nextcloud server",
     "Some of your link shares have been removed" : "Nogle af dine delte links er blevet fjernet",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Pga et sikkerhedshul har vi været nødt til at fjerne nogle af dine delte links. Se linket for mere information.",
     "The account limit of this instance is reached." : "Konto grænsen for denne instans er nået.",
@@ -70,7 +69,7 @@ OC.L10N.register(
     "Updating database schema" : "Opdaterer database skema",
     "Updated database" : "Opdaterede database",
     "Update app \"%s\" from App Store" : "Opdater app \"%s\" fra App Store",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Tjekker om database skemaet for %s kan opdateres (dette kan tage lang tid afhængig af databasens størrelse)",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Tjekker om databaseskemaet for %s kan opdateres (dette kan tage lang tid afhængig af databasens størrelse)",
     "Updated \"%1$s\" to %2$s" : "Opdaterede \"%1$s\" til %2$s",
     "Set log level to debug" : "Sæt logningsniveau til fejlfinding",
     "Reset log level" : "Nulstil logningsniveau",
@@ -79,20 +78,127 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (inkompatibel)",
     "The following apps have been disabled: %s" : "Følgende apps er blevet deaktiveret: %s",
     "Already up to date" : "Allerede opdateret",
+    "Windows Command Script" : "Windows kommandoscript",
+    "Electronic book document" : "Elektronisk bog dokument",
+    "TrueType Font Collection" : "TrueType Font samling",
+    "Web Open Font Format" : "Web Open Font format",
+    "GPX geographic data" : "GPX geografiske data",
+    "Gzip archive" : "Gzip arkiv",
+    "Adobe Illustrator document" : "Adobe Illustrator dokument",
+    "Java source code" : "Java kildekode",
+    "JavaScript source code" : "JavaScript kildekode",
+    "JSON document" : "JSON dokument",
+    "Microsoft Access database" : "Microsoft Access database",
+    "Microsoft OneNote document" : "Microsoft OneNote dokument",
+    "Microsoft Word document" : "Microsoft Word dokument",
     "Unknown" : "Ukendt",
+    "PDF document" : "PDF dokument",
+    "PostScript document" : "PostScript dokument",
+    "RSS summary" : "RSS sammendrag",
+    "Android package" : "Android pakke",
+    "KML geographic data" : "KML geografiske data",
+    "KML geographic compressed data" : "KML geografiske komprimerede data",
+    "Lotus Word Pro document" : "Lotus Word Pro dokumentet",
+    "Excel spreadsheet" : "Excel regneark",
+    "Excel add-in" : "Excel udvidelse",
+    "Excel 2007 binary spreadsheet" : "Excel 2007 binært regneark",
+    "Excel spreadsheet template" : "Excel regnearksskabelon",
+    "Outlook Message" : "Outlook besked",
+    "PowerPoint presentation" : "PowerPoint præsentation",
+    "PowerPoint add-in" : "PowerPoint udvidelse",
+    "PowerPoint presentation template" : "PowerPoint præsentationsskabelon",
+    "Word document" : "Word dokument",
+    "ODF formula" : "ODF formel",
+    "ODG drawing" : "ODG tegning",
+    "ODG drawing (Flat XML)" : "ODG tegning (Flad XML)",
+    "ODG template" : "ODG skabelon",
+    "ODP presentation" : "ODP præsentation",
+    "ODP presentation (Flat XML)" : "ODP præsentation (Flad XML)",
+    "ODP template" : "ODP skabelon",
+    "ODS spreadsheet" : "ODS regneark",
+    "ODS spreadsheet (Flat XML)" : "ODS regneark (Flad XML)",
+    "ODS template" : "ODS skabelon",
+    "ODT document" : "ODT dokument",
+    "ODT document (Flat XML)" : "ODT dokument (Flad XML)",
+    "ODT template" : "ODT skabelon",
+    "PowerPoint 2007 presentation" : "PowerPoint 2007 præsentation",
+    "PowerPoint 2007 show" : "PowerPoint 2007 show",
+    "PowerPoint 2007 presentation template" : "PowerPoint 2007 præsentationsskabelon",
+    "Excel 2007 spreadsheet" : "Excel 2007 regneark",
+    "Excel 2007 spreadsheet template" : "Excel 2007 regnearksskabelon",
+    "Word 2007 document" : "Word 2007 dokument",
+    "Word 2007 document template" : "Word 2007 dokumentskabelon",
+    "Microsoft Visio document" : "Microsoft Visio dokument",
+    "WordPerfect document" : "WordPerfect dokument",
+    "7-zip archive" : "7-zip arkiv",
+    "Blender scene" : "Blender scene",
+    "Bzip2 archive" : "Bzip2 arkiv",
+    "Debian package" : "Debian pakke",
+    "FictionBook document" : "FictionBook dokument",
+    "Unknown font" : "Ukendt font",
+    "Krita document" : "Krita dokument",
+    "Mobipocket e-book" : "Mobipocket e-bog",
+    "Windows Installer package" : "Windows installerbar pakke",
+    "Perl script" : "Perl script",
+    "PHP script" : "PHP script",
+    "Tar archive" : "Tar arkiv",
+    "XML document" : "XML dokument",
+    "YAML document" : "YAML dokument",
+    "Zip archive" : "Zip arkiv",
+    "Zstandard archive" : "Zstandard arkiv",
+    "AAC audio" : "AAC lyd",
+    "FLAC audio" : "FLAC lyd",
+    "MPEG-4 audio" : "MPEG-4 lyd",
+    "MP3 audio" : "MP3 lyd",
+    "Ogg audio" : "Ogg lyd",
+    "RIFF/WAVe standard Audio" : "RIFF/WAVe standard lyd",
+    "WebM audio" : "WebM lyd",
+    "MP3 ShoutCast playlist" : "MP3 ShoutCast spilleliste",
+    "Windows BMP image" : "Windows BMP billede",
+    "Better Portable Graphics image" : "Better Portable Graphics billede",
+    "EMF image" : "EMF billede",
+    "GIF image" : "GIF billede",
+    "HEIC image" : "HEIC billede",
+    "HEIF image" : "HEIF billede",
+    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 billede",
+    "JPEG image" : "JPEG billede",
     "PNG image" : "PNG billede",
-    "Error occurred while checking server setup" : "Der opstod fejl under tjek af serveropsætningen",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "For flere detaljer se {linkstart}dokumentationen ↗{linkend}.",
-    "unknown text" : "ukendt tekst",
-    "Hello world!" : "Hej verden!",
-    "sunny" : "solrigt",
-    "Hello {name}, the weather is {weather}" : "Hej {name}, vejret er {weather}",
-    "Hello {name}" : "Hej {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dine søgeresultater<script>alert(1)</script></strong>",
-    "new" : "ny",
-    "_download %n file_::_download %n files_" : ["hent %n fil","hent %n filer"],
+    "SVG image" : "SVG billede",
+    "Truevision Targa image" : "Truevision Targa billede",
+    "TIFF image" : "TIFF billede",
+    "WebP image" : "WebP billede",
+    "Digital raw image" : "Digital raw billede",
+    "Windows Icon" : "Windows ikon",
+    "Email message" : "E-mail besked",
+    "VCS/ICS calendar" : "VCS/ICS kalender",
+    "CSS stylesheet" : "CSS stylesheet",
+    "CSV document" : "CSV dokument",
+    "HTML document" : "HTML dokument",
+    "Markdown document" : "Markdown dokument",
+    "Org-mode file" : "Org-mode fil",
+    "Plain text document" : "Rå tekst dokument",
+    "Rich Text document" : "Rich tekst dokument",
+    "Electronic business card" : "Elektronisk firmakort",
+    "C++ source code" : "C++ kildekode",
+    "LDIF address book" : "LDIF adressebog",
+    "NFO document" : "NFO dkcument",
+    "PHP source" : "PHP kilde",
+    "Python script" : "Python script",
+    "ReStructuredText document" : "ReStructuredText dokument",
+    "3GPP multimedia file" : "3GPP multimedie fil",
+    "MPEG video" : "MPEG video",
+    "DV video" : "DV video",
+    "MPEG-2 transport stream" : "MPEG-2 transport stream",
+    "MPEG-4 video" : "MPEG-4 video",
+    "Ogg video" : "Ogg video",
+    "QuickTime video" : "QuickTime video",
+    "WebM video" : "WebM video",
+    "Flash video" : "Flash video",
+    "Matroska video" : "Matroska video",
+    "Windows Media video" : "Windows Medie video",
+    "AVI video" : "AVI video",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Opdateringen er i gang. Forlader du denne side kan der ske fejl i processen som ødelægger din Nextcloud installation",
-    "Update to {version}" : "Opdater til {version}",
+    "Update to {version}" : "Opdatér til {version}",
     "An error occurred." : "Der opstod en fejl.",
     "Please reload the page." : "Genindlæs venligst siden.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Opdateringen blev ikke udført korrekt. For mere information <a href=\"{url}\">tjek vores indlæg på forumet</a>, som dækker dette problem.",
@@ -108,9 +214,10 @@ OC.L10N.register(
     "The remote URL must include the user." : "Fjern-URL'en skal omfatte brugeren.",
     "Invalid remote URL." : "Ugyldig fjern webadresse.",
     "Failed to add the public link to your Nextcloud" : "Fejl ved tilføjelse af offentligt link til din Nextcloud",
-    "Federated user" : "Sammenkoblet bruger",
+    "Federated user" : "Fødereret bruger",
     "user@your-nextcloud.org" : "bruger@din-nextcloud.dk",
     "Create share" : "Opret share",
+    "Direct link copied" : "Direkte link kopieret",
     "Please copy the link manually:" : "Kopier venligst linket manuelt:",
     "Custom date range" : " Brugerdefineret datointerval",
     "Pick start date" : "Vælg en startdato",
@@ -119,14 +226,16 @@ OC.L10N.register(
     "Search in current app" : "Søg i nuværende app",
     "Clear search" : "Ryd søgning",
     "Search everywhere" : "Søg overalt",
-    "Searching …" : "Søger …",
+    "Searching …" : "Søger ...",
     "Start typing to search" : "Start med at skrive for at søge",
+    "Minimum search length is {minSearchLength} characters" : "Minimumssøgelængde er {minSearchLength} tegn",
     "No matching results" : "Ingen søgeresultater",
     "Today" : "I dag",
     "Last 7 days" : "Sidste 7 dage",
     "Last 30 days" : "Sidste 30 dage",
     "This year" : "Dette år",
     "Last year" : "Sidste år",
+    "Between {startDate} and {endDate}" : "Mellem {startDate} og {endDate}",
     "Unified search" : "Samlet søgning",
     "Search apps, files, tags, messages" : "Søg i apps, filer, tags, beskeder",
     "Places" : "Steder",
@@ -134,11 +243,12 @@ OC.L10N.register(
     "Search people" : "Søg efter personer",
     "People" : "Personer",
     "Filter in current view" : "Filtrer i den aktuelle visning",
+    "Search connected services" : "Søg efter forbundne services",
     "Results" : "Resultater",
     "Load more results" : "Hent flere resultater",
     "Search in" : "Søg i",
     "Log in" : "Log ind",
-    "Logging in …" : "Logger ind …",
+    "Logging in …" : "Logger på ...",
     "Log in to {productName}" : "Log ind på {productName}",
     "Wrong login or password." : "Forkert brugernavn eller adgangskode.",
     "This account is disabled" : "Denne konto er deaktiveret",
@@ -175,21 +285,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Samarbejdsdokumenter, regneark og præsentationer, bygget på Collabora Online.",
     "Distraction free note taking app." : "App til at tage noter uden distraktion.",
     "Recommended apps" : "Anbefalede apps",
-    "Loading apps …" : "Henter apps ...",
+    "Loading apps …" : "Indlæser apps ...",
     "Could not fetch list of apps from the App Store." : "Kunne ikke hente listen over apps fra App Store.",
     "App download or installation failed" : "App-download eller installation mislykkedes",
     "Cannot install this app because it is not compatible" : "Kan ikke installere denne app, fordi den ikke er kompatibel",
     "Cannot install this app" : "Kan ikke installere denne app",
     "Skip" : "Spring over",
-    "Installing apps …" : "Installerer apps ...",
+    "Installing apps …" : "Installerer apps ...",
     "Install recommended apps" : "Installer anbefalede apps",
     "Avatar of {displayName}" : "Avatar af {displayName}",
     "Settings menu" : "Indstillingsmenu",
-    "Loading your contacts …" : "Henter dine kontakter …",
-    "Looking for {term} …" : "Leder efter {term} …",
+    "Loading your contacts …" : "Indlæser kontakter ...",
+    "Looking for {term} …" : "Leder efter {term} …",
     "Search contacts" : "Søg kontakter",
     "Reset search" : "Nulstil søgning",
-    "Search contacts …" : "Søg efter brugere ...",
+    "Search contacts …" : "Søg efter kontakter ...",
     "Could not load your contacts" : "Kunne ikke indlæse kontakter.",
     "No contacts found" : "Ingen kontakter",
     "Show all contacts" : "Vis alle kontakter",
@@ -201,13 +311,18 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Der opstod en fejl under søgningen efter {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Søgningen starter samtidig med indtastningen og resultatet kan vælges med piletasterne",
     "Search for {name} only" : "Søg kun efter {name}",
-    "Loading more results …" : "Henter flere resultater...",
+    "Loading more results …" : "Indlæser flere resultater ...",
     "Forgot password?" : "Glemt adgangskode?",
     "Back to login form" : "Tilbage til login-formularen",
     "Back" : "Tilbage",
     "Login form is disabled." : "Loginformularen er deaktiveret.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud-loginformularen er deaktiveret. Brug en anden login-mulighed, hvis den er tilgængelig, eller kontakt din administration.",
     "More actions" : "Flere handlinger",
+    "User menu" : "Brugermenu",
+    "Your guest name: {user}" : "Dit gæstenavn: {user}",
+    "You are currently not identified." : "Du er aktuelt ikke identificeret.",
+    "Set public name" : "Angiv offentligt navn",
+    "Change public name" : "Skift offentligt navn",
     "Password is too weak" : "Adgangskoden er for svag",
     "Password is weak" : "Adgangskoden er svag",
     "Password is average" : "Adgangskoden er middel",
@@ -240,7 +355,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Angiv et portnummer sammen med hostnavnet (f.eks. localhost:5432).",
     "Database host" : "Databasehost",
     "localhost" : "localhost",
-    "Installing …" : "Installerer...",
+    "Installing …" : "Installerer ...",
     "Install" : "Installer",
     "Need help?" : "Brug for hjælp?",
     "See the documentation" : "Se dokumentationen",
@@ -249,11 +364,11 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Din browser understøttes ikke. Opdater venligst til en nyere version, eller vælg en anden der supporteres. ",
     "Continue with this unsupported browser" : "Fortsæt med denne ikke supporterede browser",
     "Supported versions" : "Supporterede versioner",
-    "Search {types} …" : "Søg {types} …",
+    "Search {types} …" : "Søg {types} …",
     "Choose {file}" : "Vælg {file}",
     "Choose" : "Vælg",
-    "Copy to {target}" : "Kopier til {target}",
-    "Copy" : "Kopier",
+    "Copy to {target}" : "Kopiér til {target}",
+    "Copy" : "Kopiér",
     "Move to {target}" : "Flyt til {target}",
     "Move" : "Flyt",
     "OK" : "Ok",
@@ -269,7 +384,7 @@ OC.L10N.register(
     "(all selected)" : "(alle valgt)",
     "({count} selected)" : "({count} valgt)",
     "Error loading file exists template" : "Fejl ved indlæsning af 'fil eksisterer' skabelon",
-    "Saving …" : "Gemmer…",
+    "Saving …" : "Gemmer …",
     "seconds ago" : "få sekunder siden",
     "Connection to server lost" : "Forbindelsen til serveren er tabt",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Der opstod et problem med at hente siden, prøver igen om %n sekund","Der opstod et problem med at hente siden, prøver igen om %n sekunder"],
@@ -284,23 +399,15 @@ OC.L10N.register(
     "Type to search for existing projects" : "Skriv for at søge efter eksisterende projekter",
     "New in" : "Ny i",
     "View changelog" : "Se ændringslog",
-    "No action available" : "Ingen funktion tilgængelig",
-    "Error fetching contact actions" : "Kunne ikke hente kontakt funktioner",
     "Close \"{dialogTitle}\" dialog" : "Luk dialogboksen \"{dialogTitle}\".",
     "Email length is at max (255)" : "E-maillængde er på maks. (255)",
-    "Non-existing tag #{tag}" : "Ikke-eksisterende mærke #{tag}",
-    "Restricted" : "Begrænset",
-    "Invisible" : "Usynlig",
-    "Delete" : "Slet",
-    "Rename" : "Omdøb",
-    "Collaborative tags" : "Collaborative tags",
-    "No tags found" : "Ingen tags fundet",
     "Clipboard not available, please copy manually" : "Udklipsholderen er ikke tilgængeligt, kopier venligst manuelt",
     "Personal" : "Personligt",
     "Accounts" : "Konti",
     "Admin" : "Admin",
     "Help" : "Hjælp",
     "Access forbidden" : "Adgang forbudt",
+    "You are not allowed to access this page." : "Du har ikke tilladelse til at tilgå denne side.",
     "Back to %s" : "Tilbage til %s",
     "Page not found" : "Siden blev ikke fundet",
     "The page could not be found on the server or you may not be allowed to view it." : "Siden kunne ikke findes på serveren, eller du har muligvis ikke tilladelse til at se den.",
@@ -379,19 +486,41 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Denne %s-instans befinder sig i vedligeholdelsestilstand for øjeblikket, hvilket kan tage et stykke tid.",
     "This page will refresh itself when the instance is available again." : "Denne side vil genopfriske sig selv, når instancen er tilgængelig igen.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontakt systemadministratoren, hvis denne meddelelse fortsætter eller optrådte uventet.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chat, video kald, skærmdeling, online møder og web konferencer - i din browser og med mobil apps.",
-    "You have not added any info yet" : "Du har ikke tilføjet nogen information endnu",
-    "{user} has not added any info yet" : "{user} har ikke tilføjet nogen oplysninger endnu",
-    "Error opening the user status modal, try hard refreshing the page" : "Fejl ved åbning af brugerstatusmodal. Prøv at opdatere siden",
-    "Edit Profile" : "Rediger profil",
-    "The headline and about sections will show up here" : "Overskriften og om sektionerne vises her",
+    "Error occurred while checking server setup" : "Der opstod fejl under tjek af serveropsætningen",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "For flere detaljer se {linkstart}dokumentationen ↗{linkend}.",
+    "unknown text" : "ukendt tekst",
+    "Hello world!" : "Hej verden!",
+    "sunny" : "solrigt",
+    "Hello {name}, the weather is {weather}" : "Hej {name}, vejret er {weather}",
+    "Hello {name}" : "Hej {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dine søgeresultater<script>alert(1)</script></strong>",
+    "new" : "ny",
+    "_download %n file_::_download %n files_" : ["hent %n fil","hent %n filer"],
+    "Direct link copied to clipboard" : "Direkte link kopieret til udklipsholder",
+    "Searching …" : "Søger …",
+    "Logging in …" : "Logger ind …",
+    "Loading apps …" : "Henter apps ...",
+    "Installing apps …" : "Installerer apps ...",
+    "Loading your contacts …" : "Henter dine kontakter …",
+    "Looking for {term} …" : "Leder efter {term} …",
+    "Search contacts …" : "Søg efter brugere ...",
+    "Loading more results …" : "Henter flere resultater...",
+    "Search {types} …" : "Søg {types} …",
+    "Saving …" : "Gemmer…",
     "Very weak password" : "Meget svagt kodeord",
     "Weak password" : "Svagt kodeord",
     "So-so password" : "Jævnt kodeord",
     "Good password" : "Godt kodeord",
     "Strong password" : "Stærkt kodeord",
-    "Profile not found" : "Profil ikke fundet",
-    "The profile does not exist." : "Profilen eksisterer ikke.",
+    "No action available" : "Ingen funktion tilgængelig",
+    "Error fetching contact actions" : "Kunne ikke hente kontakt funktioner",
+    "Non-existing tag #{tag}" : "Ikke-eksisterende mærke #{tag}",
+    "Restricted" : "Begrænset",
+    "Invisible" : "Usynlig",
+    "Delete" : "Slet",
+    "Rename" : "Omdøb",
+    "Collaborative tags" : "Collaborative tags",
+    "No tags found" : "Ingen tags fundet",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Din data mappe og filer er sandsynligvis tilgængelige fra internettet fordi .htaccess filen ikke virker.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information om, hvordan du konfigurerer din server korrekt se <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentationen</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Opret en administrator konto</strong>",
@@ -402,6 +531,6 @@ OC.L10N.register(
     "Configure the database" : "Konfigurer databasen",
     "Only %s is available." : "Kun %s er tilgængelig.",
     "Database account" : "Database konto",
-    "Direct link copied to clipboard" : "Direkte link kopieret til udklipsholder"
+    "Installing …" : "Installerer..."
 },
 "nplurals=2; plural=(n != 1);");
