@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "უცნობი ფაილის ტიპი",
     "An error occurred. Please contact your admin." : "მოხდა შეცდომა. გთხოვთ, დაუკავშირდეთ თქვენს ადმინისტრატორს.",
     "Invalid image" : "არასწორი სურათი",
-    "No temporary profile picture available, try again" : "No temporary profile picture available, try again",
-    "No crop data provided" : "No crop data provided",
-    "No valid crop data provided" : "No valid crop data provided",
-    "Crop is not square" : "Crop is not square",
     "State token does not match" : "State token does not match",
     "Invalid app password" : "Invalid app password",
     "Could not complete login" : "Could not complete login",
@@ -29,6 +25,7 @@ OC.L10N.register(
     "Your login token is invalid or has expired" : "Your login token is invalid or has expired",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "This community release of Nextcloud is unsupported and push notifications are limited.",
     "Login" : "Login",
+    "Unsupported email length (>255)" : "იმეილი ძალიან გრძელია (>255)",
     "Password reset is disabled" : "Password reset is disabled",
     "Could not reset password because the token is expired" : "Could not reset password because the token is expired",
     "Could not reset password because the token is invalid" : "Could not reset password because the token is invalid",
@@ -38,6 +35,7 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Click the following button to reset your password. If you have not requested the password reset, then ignore this email.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Click the following link to reset your password. If you have not requested the password reset, then ignore this email.",
     "Reset your password" : "Reset your password",
+    "The given provider is not available" : "მოცემული პროვაიდერი მიუწვდომელია",
     "Task not found" : "Task not found",
     "Internal error" : "Internal error",
     "Not found" : "Not found",
@@ -48,16 +46,16 @@ OC.L10N.register(
     "No translation provider available" : "No translation provider available",
     "Could not detect language" : "Could not detect language",
     "Unable to translate" : "Unable to translate",
-    "Nextcloud Server" : "Nextcloud Server",
-    "Some of your link shares have been removed" : "Some of your link shares have been removed",
-    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Due to a security bug we had to remove some of your link shares. Please see the link for more information.",
-    "Learn more ↗" : "Learn more ↗",
-    "Preparing update" : "Preparing update",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Repair step:",
     "Repair info:" : "Repair info:",
     "Repair warning:" : "Repair warning:",
     "Repair error:" : "Repair error:",
+    "Nextcloud Server" : "Nextcloud Server",
+    "Some of your link shares have been removed" : "Some of your link shares have been removed",
+    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Due to a security bug we had to remove some of your link shares. Please see the link for more information.",
+    "Learn more ↗" : "Learn more ↗",
+    "Preparing update" : "Preparing update",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Please use the command line updater because updating via browser is disabled in your config.php.",
     "Turned on maintenance mode" : "Turned on maintenance mode",
     "Turned off maintenance mode" : "Turned off maintenance mode",
@@ -74,16 +72,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (incompatible)",
     "The following apps have been disabled: %s" : "The following apps have been disabled: %s",
     "Already up to date" : "Already up to date",
-    "Error occurred while checking server setup" : "Error occurred while checking server setup",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "For more details see the {linkstart}documentation ↗{linkend}.",
-    "unknown text" : "unknown text",
-    "Hello world!" : "Hello world!",
-    "sunny" : "sunny",
-    "Hello {name}, the weather is {weather}" : "Hello {name}, the weather is {weather}",
-    "Hello {name}" : "Hello {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>These are your search results<script>alert(1)</script></strong>",
-    "new" : "new",
-    "_download %n file_::_download %n files_" : ["download %n file","download %n files"],
+    "Unknown" : "Unknown",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "The update is in progress, leaving this page might interrupt the process in some environments.",
     "Update to {version}" : "Update to {version}",
     "An error occurred." : "An error occurred.",
@@ -98,104 +87,125 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count} notification","{count} notifications"],
     "No" : "No",
     "Yes" : "Yes",
-    "Create share" : "Create share",
     "Failed to add the public link to your Nextcloud" : "Failed to add the public link to your Nextcloud",
+    "Create share" : "Create share",
+    "Please copy the link manually:" : "გთხოვთ, ლინკი ხელით ჩასვათ:",
     "Custom date range" : "Custom date range",
     "Pick start date" : "Pick start date",
     "Pick end date" : "Pick end date",
     "Search in date range" : "Search in date range",
-    "Unified search" : "Unified search",
-    "Search apps, files, tags, messages" : "Search apps, files, tags, messages",
-    "Date" : "Date",
+    "Clear search" : "წაშალე ძიების ისტორია",
+    "Search everywhere" : "მოძებნე ყველგან",
+    "Start typing to search" : "Start typing to search",
+    "No matching results" : "No matching results",
     "Today" : "Today",
     "Last 7 days" : "Last 7 days",
     "Last 30 days" : "Last 30 days",
     "This year" : "This year",
     "Last year" : "Last year",
+    "Unified search" : "Unified search",
+    "Search apps, files, tags, messages" : "Search apps, files, tags, messages",
+    "Places" : "ადგილები",
+    "Date" : "Date",
     "Search people" : "Search people",
     "People" : "People",
     "Filter in current view" : "Filter in current view",
+    "Results" : "შედეგი",
     "Load more results" : "Load more results",
     "Search in" : "Search in",
-    "Searching …" : "Searching …",
-    "Start typing to search" : "Start typing to search",
-    "No matching results" : "No matching results",
-    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}",
     "Log in" : "Log in",
-    "Logging in …" : "Logging in …",
+    "Log in to {productName}" : "Log in to {productName}",
+    "Wrong login or password." : "არასწორი მომხმარებელი ან პაროლი.",
+    "This account is disabled" : "ექაუნთი გათიშულია",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds.",
+    "Account name or email" : "Account name or email",
+    "Account name" : "ექაუნთის სახელი",
     "Server side authentication failed!" : "Server side authentication failed!",
     "Please contact your administrator." : "Please contact your administrator.",
-    "Temporary error" : "Temporary error",
-    "Please try again." : "Please try again.",
+    "Session error" : "სესიის შეცდომა",
     "An internal error occurred." : "An internal error occurred.",
     "Please try again or contact your administrator." : "Please try again or contact your administrator.",
     "Password" : "პაროლი",
-    "Log in to {productName}" : "Log in to {productName}",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds.",
-    "Account name or email" : "Account name or email",
     "Log in with a device" : "Log in with a device",
+    "Login or email" : "მომხმარებელის სახელი ან იმეილი",
     "Your account is not setup for passwordless login." : "Your account is not setup for passwordless login.",
-    "Browser not supported" : "Browser not supported",
-    "Passwordless authentication is not supported in your browser." : "Passwordless authentication is not supported in your browser.",
     "Your connection is not secure" : "Your connection is not secure",
     "Passwordless authentication is only available over a secure connection." : "Passwordless authentication is only available over a secure connection.",
+    "Browser not supported" : "Browser not supported",
+    "Passwordless authentication is not supported in your browser." : "Passwordless authentication is not supported in your browser.",
     "Reset password" : "Reset password",
+    "Back to login" : "Back to login",
     "Couldn't send reset email. Please contact your administrator." : "Couldn't send reset email. Please contact your administrator.",
     "Password cannot be changed. Please contact your administrator." : "Password cannot be changed. Please contact your administrator.",
-    "Back to login" : "Back to login",
     "New password" : "New password",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?",
     "I know what I'm doing" : "I know what I'm doing",
     "Resetting password" : "Resetting password",
+    "Schedule work & meetings, synced with all your devices." : "Schedule work & meetings, synced with all your devices.",
+    "Keep your colleagues and friends in one place without leaking their private info." : "Keep your colleagues and friends in one place without leaking their private info.",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Simple email app nicely integrated with Files, Contacts and Calendar.",
+    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collaborative documents, spreadsheets and presentations, built on Collabora Online.",
+    "Distraction free note taking app." : "Distraction free note taking app.",
     "Recommended apps" : "Recommended apps",
-    "Loading apps …" : "Loading apps …",
     "Could not fetch list of apps from the App Store." : "Could not fetch list of apps from the App Store.",
     "App download or installation failed" : "App download or installation failed",
     "Cannot install this app because it is not compatible" : "Cannot install this app because it is not compatible",
     "Cannot install this app" : "Cannot install this app",
     "Skip" : "Skip",
-    "Installing apps …" : "Installing apps …",
     "Install recommended apps" : "Install recommended apps",
-    "Schedule work & meetings, synced with all your devices." : "Schedule work & meetings, synced with all your devices.",
-    "Keep your colleagues and friends in one place without leaking their private info." : "Keep your colleagues and friends in one place without leaking their private info.",
-    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Simple email app nicely integrated with Files, Contacts and Calendar.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps.",
-    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collaborative documents, spreadsheets and presentations, built on Collabora Online.",
-    "Distraction free note taking app." : "Distraction free note taking app.",
-    "Settings menu" : "Settings menu",
     "Avatar of {displayName}" : "Avatar of {displayName}",
+    "Settings menu" : "Settings menu",
     "Search contacts" : "Search contacts",
     "Reset search" : "Reset search",
-    "Search contacts …" : "Search contacts …",
     "Could not load your contacts" : "Could not load your contacts",
     "No contacts found" : "No contacts found",
     "Show all contacts" : "Show all contacts",
     "Install the Contacts app" : "Install the Contacts app",
-    "Loading your contacts …" : "Loading your contacts …",
-    "Looking for {term} …" : "Looking for {term} …",
-    "Search starts once you start typing and results may be reached with the arrow keys" : "Search starts once you start typing and results may be reached with the arrow keys",
-    "Search for {name} only" : "Search for {name} only",
-    "Loading more results …" : "Loading more results …",
     "Search" : "Search",
     "No results for {query}" : "No results for {query}",
     "Press Enter to start searching" : "Press Enter to start searching",
-    "An error occurred while searching for {type}" : "An error occurred while searching for {type}",
-    "Forgot password?" : "Forgot password?",
+    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Please enter {minSearchLength} character or more to search","გთხოვთ, შეიყვანოთ {minSearchLength} ან მეტი ასო ძიებისთვის"],
+    "An error occurred while searching for {type}" : "შეცდომა დაფიქსირდა {type}-ის ძიებისას",
+    "Search starts once you start typing and results may be reached with the arrow keys" : "Search starts once you start typing and results may be reached with the arrow keys",
+    "Search for {name} only" : "მოძებნე მარტო {name} ",
+    "Forgot password?" : "დაგავიწყდათ პაროლი?",
     "Back to login form" : "Back to login form",
-    "Back" : "Back",
+    "Back" : "უკან",
     "Login form is disabled." : "Login form is disabled.",
-    "Edit Profile" : "Edit Profile",
-    "The headline and about sections will show up here" : "The headline and about sections will show up here",
-    "You have not added any info yet" : "You have not added any info yet",
-    "{user} has not added any info yet" : "{user} has not added any info yet",
-    "Error opening the user status modal, try hard refreshing the page" : "Error opening the user status modal, try hard refreshing the page",
     "More actions" : "More actions",
+    "Password is too weak" : "პაროლი ძალიან სუსტია",
+    "Password is weak" : "პაროლი სუსტია",
+    "Password is average" : "პაროლი დამაკმაყოფილებელია",
+    "Password is strong" : "პაროლი ძლიერია",
+    "Password is very strong" : "პაროლი ძალიან ძლიერია",
+    "Password is extremely strong" : "პაროლი ძალზე ძლიერია",
+    "Unknown password strength" : "პაროლის სიძლიერე უცნობია",
+    "Security warning" : "Security warning",
+    "Create administration account" : "შექმენი ადმინისტრატორის ექაუნთი",
+    "Administration account name" : "ადმინისტრატორის ექაუნთის სახელი",
+    "Administration account password" : "ადმინისტრატორის ექაუნთის პაროლი",
+    "Storage & database" : "Storage & database",
+    "Data folder" : "Data folder",
+    "Install and activate additional PHP modules to choose other database types." : "Install and activate additional PHP modules to choose other database types.",
+    "For more details check out the documentation." : "For more details check out the documentation.",
+    "Performance warning" : "Performance warning",
+    "You chose SQLite as database." : "You chose SQLite as database.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite should only be used for minimal and development instances. For production we recommend a different database backend.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "If you use clients for file syncing, the use of SQLite is highly discouraged.",
+    "Database user" : "Database user",
+    "Database password" : "Database password",
+    "Database name" : "Database name",
+    "Database tablespace" : "Database tablespace",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
+    "Database host" : "Database host",
+    "Install" : "Install",
+    "Need help?" : "Need help?",
+    "See the documentation" : "See the documentation",
+    "{name} version {version} and above" : "{name} version {version} and above",
     "This browser is not supported" : "This browser is not supported",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Your browser is not supported. Please upgrade to a newer version or a supported one.",
     "Continue with this unsupported browser" : "Continue with this unsupported browser",
     "Supported versions" : "Supported versions",
-    "{name} version {version} and above" : "{name} version {version} and above",
-    "Search {types} …" : "Search {types} …",
     "Choose {file}" : "Choose {file}",
     "Choose" : "Choose",
     "Copy to {target}" : "Copy to {target}",
@@ -215,7 +225,7 @@ OC.L10N.register(
     "(all selected)" : "(all selected)",
     "({count} selected)" : "({count} selected)",
     "Error loading file exists template" : "Error loading file exists template",
-    "Saving …" : "Saving …",
+    "Saving …" : "Saving …",
     "seconds ago" : "seconds ago",
     "Connection to server lost" : "Connection to server lost",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem loading page, reloading in %n second","Problem loading page, reloading in %n seconds"],
@@ -230,35 +240,18 @@ OC.L10N.register(
     "Type to search for existing projects" : "Type to search for existing projects",
     "New in" : "New in",
     "View changelog" : "View changelog",
-    "Very weak password" : "Very weak password",
-    "Weak password" : "Weak password",
-    "So-so password" : "So-so password",
-    "Good password" : "Good password",
-    "Strong password" : "Strong password",
-    "No action available" : "No action available",
-    "Error fetching contact actions" : "Error fetching contact actions",
     "Close \"{dialogTitle}\" dialog" : "Close \"{dialogTitle}\" dialog",
-    "Non-existing tag #{tag}" : "Non-existing tag #{tag}",
-    "Restricted" : "Restricted",
-    "Invisible" : "Invisible",
-    "Delete" : "Delete",
-    "Rename" : "Rename",
-    "Collaborative tags" : "Collaborative tags",
-    "No tags found" : "No tags found",
     "Personal" : "Personal",
     "Accounts" : "Accounts",
     "Admin" : "Admin",
     "Help" : "Help",
     "Access forbidden" : "Access forbidden",
-    "Profile not found" : "Profile not found",
-    "The profile does not exist." : "The profile does not exist.",
     "Back to %s" : "Back to %s",
     "Page not found" : "Page not found",
     "The page could not be found on the server or you may not be allowed to view it." : "The page could not be found on the server or you may not be allowed to view it.",
     "Too many requests" : "Too many requests",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "There were too many requests from your network. Retry later or contact your administrator if this is an error.",
     "Error" : "Error",
-    "Previous" : "Previous",
     "Internal Server Error" : "Internal Server Error",
     "The server was unable to complete your request." : "The server was unable to complete your request.",
     "If this happens again, please send the technical details below to the server administrator." : "If this happens again, please send the technical details below to the server administrator.",
@@ -272,31 +265,6 @@ OC.L10N.register(
     "File: %s" : "File: %s",
     "Line: %s" : "Line: %s",
     "Trace" : "Trace",
-    "Security warning" : "Security warning",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Your data directory and files are probably accessible from the internet because the .htaccess file does not work.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
-    "Create an <strong>admin account</strong>" : "Create an <strong>admin account</strong>",
-    "Show password" : "Show password",
-    "Toggle password visibility" : "Toggle password visibility",
-    "Storage & database" : "Storage & database",
-    "Data folder" : "Data folder",
-    "Configure the database" : "Configure the database",
-    "Only %s is available." : "Only %s is available.",
-    "Install and activate additional PHP modules to choose other database types." : "Install and activate additional PHP modules to choose other database types.",
-    "For more details check out the documentation." : "For more details check out the documentation.",
-    "Database password" : "Database password",
-    "Database name" : "Database name",
-    "Database tablespace" : "Database tablespace",
-    "Database host" : "Database host",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
-    "Performance warning" : "Performance warning",
-    "You chose SQLite as database." : "You chose SQLite as database.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite should only be used for minimal and development instances. For production we recommend a different database backend.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "If you use clients for file syncing, the use of SQLite is highly discouraged.",
-    "Install" : "Install",
-    "Installing …" : "Installing …",
-    "Need help?" : "Need help?",
-    "See the documentation" : "See the documentation",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Could not remove CAN_INSTALL from the config folder. Please remove this file manually.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page.",
@@ -316,6 +284,7 @@ OC.L10N.register(
     "Account connected" : "Account connected",
     "Your client should now be connected!" : "Your client should now be connected!",
     "You can close this window." : "You can close this window.",
+    "Previous" : "Previous",
     "This share is password-protected" : "This share is password-protected",
     "The password is wrong or expired. Please try again or request a new one." : "The password is wrong or expired. Please try again or request a new one.",
     "Please type in your email address to request a temporary password" : "Please type in your email address to request a temporary password",
@@ -353,35 +322,46 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "This %s instance is currently in maintenance mode, which may take a while.",
     "This page will refresh itself when the instance is available again." : "This page will refresh itself when the instance is available again.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contact your system administrator if this message persists or appeared unexpectedly.",
-    "The user limit of this instance is reached." : "The user limit of this instance is reached.",
-    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies.",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken.",
-    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}.",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update.",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}.",
-    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}.",
-    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly.",
-    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly.",
-    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}.",
-    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}.",
-    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!",
-    "Currently open" : "Currently open",
-    "Wrong username or password." : "Wrong username or password.",
-    "User disabled" : "User disabled",
-    "Username or email" : "Username or email",
-    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help.",
-    "Apps and Settings" : "Apps and Settings",
-    "Error loading message template: {error}" : "Error loading message template: {error}",
-    "Users" : "Users",
-    "Username" : "Username",
-    "Database user" : "Database user",
-    "This action requires you to confirm your password" : "This action requires you to confirm your password",
-    "Confirm your password" : "Confirm your password",
-    "Confirm" : "Confirm",
-    "App token" : "App token",
-    "Alternative log in using app token" : "Alternative log in using app token",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Please use the command line updater because you have a big instance with more than 50 users."
+    "Error occurred while checking server setup" : "Error occurred while checking server setup",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "For more details see the {linkstart}documentation ↗{linkend}.",
+    "unknown text" : "unknown text",
+    "Hello world!" : "Hello world!",
+    "sunny" : "sunny",
+    "Hello {name}, the weather is {weather}" : "Hello {name}, the weather is {weather}",
+    "Hello {name}" : "Hello {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>These are your search results<script>alert(1)</script></strong>",
+    "new" : "new",
+    "_download %n file_::_download %n files_" : ["download %n file","download %n files"],
+    "Searching …" : "Searching …",
+    "Logging in …" : "Logging in …",
+    "Loading apps …" : "Loading apps …",
+    "Installing apps …" : "Installing apps …",
+    "Loading your contacts …" : "Loading your contacts …",
+    "Looking for {term} …" : "Looking for {term} …",
+    "Search contacts …" : "Search contacts …",
+    "Loading more results …" : "შედეგი იტვირთება …",
+    "Search {types} …" : "Search {types} …",
+    "Saving …" : "Saving …",
+    "Very weak password" : "Very weak password",
+    "Weak password" : "Weak password",
+    "So-so password" : "So-so password",
+    "Good password" : "Good password",
+    "Strong password" : "Strong password",
+    "No action available" : "No action available",
+    "Error fetching contact actions" : "Error fetching contact actions",
+    "Non-existing tag #{tag}" : "Non-existing tag #{tag}",
+    "Restricted" : "Restricted",
+    "Invisible" : "Invisible",
+    "Delete" : "Delete",
+    "Rename" : "Rename",
+    "Collaborative tags" : "Collaborative tags",
+    "No tags found" : "No tags found",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Your data directory and files are probably accessible from the internet because the .htaccess file does not work.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
+    "Show password" : "Show password",
+    "Toggle password visibility" : "Toggle password visibility",
+    "Configure the database" : "Configure the database",
+    "Only %s is available." : "Only %s is available.",
+    "Installing …" : "Installing …"
 },
 "nplurals=2; plural=(n!=1);");
