@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Tipo de arquivo desconhecido",
     "An error occurred. Please contact your admin." : "Ocorreu um erro. Entre em contato com o administrador.",
     "Invalid image" : "Imagem inválida",
-    "No temporary profile picture available, try again" : "Nenhuma imagem temporária disponível no perfil, tente novamente",
-    "No crop data provided" : "Nenhum dado recortado fornecido",
-    "No valid crop data provided" : "Nenhum dado recortado válido",
-    "Crop is not square" : "Recorte não é quadrado",
     "State token does not match" : "O estado do token não coincide",
     "Invalid app password" : "Senha do aplicativo inválida",
     "Could not complete login" : "Não foi possível concluir o login",
@@ -44,7 +40,7 @@ OC.L10N.register(
     "Task not found" : "Tarefa não encontrada",
     "Internal error" : "Erro interno",
     "Not found" : "Não encontrado",
-    "Node is locked" : "O nó está bloqueado",
+    "Node is locked" : "O nó está trancado",
     "Bad request" : "Requisição inválida",
     "Requested task type does not exist" : "O tipo de tarefa solicitado não existe",
     "Necessary language model provider is not available" : "O provedor de modelo de linguagem necessário não está disponível",
@@ -53,6 +49,7 @@ OC.L10N.register(
     "No translation provider available" : "Nenhum provedor de tradução disponível",
     "Could not detect language" : "Não foi possível detectar o idioma",
     "Unable to translate" : "Incapaz de traduzir",
+    "No valid filters provided" : "Não foram fornecidos filtros válidos",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Etapa do reparo:",
     "Repair info:" : "Informação do reparo:",
@@ -200,14 +197,6 @@ OC.L10N.register(
     "Matroska video" : "Vídeo Matroska",
     "Windows Media video" : "Vídeo Windows Media",
     "AVI video" : "Vídeo AVI",
-    "unknown text" : "texto desconhecido",
-    "Hello world!" : "Olá mundo!",
-    "sunny" : "ensolarado",
-    "Hello {name}, the weather is {weather}" : "Olá {name}, o clima está {weather}",
-    "Hello {name}" : "Olá {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estes são os resultados de sua pesquisa<script>alert(1)</script></strong>",
-    "new" : "novo",
-    "_download %n file_::_download %n files_" : ["baixar %n arquivo","baixar %n de arquivos","baixar %n arquivos"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "A atualização está em andamento. Em alguns ambientes, se sair desta página o processo poderá ser interrompido.",
     "Update to {version}" : "Atualizar para {version}",
     "An error occurred." : "Ocorreu um erro.",
@@ -237,8 +226,9 @@ OC.L10N.register(
     "Search in current app" : "Pesquisar no aplicativo atual",
     "Clear search" : "Limpar pesquisa",
     "Search everywhere" : "Pesquisar em qualquer lugar",
-    "Searching …" : "Pesquisando …",
+    "Searching …" : "Pesquisando …",
     "Start typing to search" : "Comece a digitar para pesquisar",
+    "Minimum search length is {minSearchLength} characters" : "O comprimento mínimo da pesquisa é de {minSearchLength} caracteres.",
     "No matching results" : "Nenhum resultado encontrado",
     "Today" : "Hoje",
     "Last 7 days" : "Últimos 7 dias",
@@ -258,7 +248,7 @@ OC.L10N.register(
     "Load more results" : "Carregar mais resultados",
     "Search in" : "Pesquisar em",
     "Log in" : "Entrar",
-    "Logging in …" : "Entrando …",
+    "Logging in …" : "Fazendo login …",
     "Log in to {productName}" : "Faça login em {productName}",
     "Wrong login or password." : "Login ou senha incorretos.",
     "This account is disabled" : "Esta conta está desativada",
@@ -295,21 +285,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos, planilhas e apresentações colaborativos, criados no Collabora Online.",
     "Distraction free note taking app." : "Aplicativo de notas sem distrações.",
     "Recommended apps" : "Aplicativos recomendados",
-    "Loading apps …" : "Carregando aplicativos...",
+    "Loading apps …" : "Carregando aplicativos …",
     "Could not fetch list of apps from the App Store." : "Não foi possível buscar a lista de aplicativos da Loje de Aplicativos.",
     "App download or installation failed" : "O download ou a instalação do aplicativo falhou",
     "Cannot install this app because it is not compatible" : "Não foi possível instalar este aplicativo pois não é compatível.",
     "Cannot install this app" : "Não foi possível instalar este aplicativo.",
     "Skip" : "Pular",
-    "Installing apps …" : "Instalando aplicativos...",
+    "Installing apps …" : "Instalando aplicativos …",
     "Install recommended apps" : "Instalar aplicativos recomendados",
     "Avatar of {displayName}" : "Avatar de {displayName}",
     "Settings menu" : "Menu de configurações",
-    "Loading your contacts …" : "Carregando seus contatos...",
-    "Looking for {term} …" : "Procurando por {term}…",
+    "Loading your contacts …" : "Carregando seus contatos …",
+    "Looking for {term} …" : "Pesquisando {term} …",
     "Search contacts" : "Pesquisar contatos",
     "Reset search" : "Redefinir pesquisa",
-    "Search contacts …" : "Pesquisar contatos …",
+    "Search contacts …" : "Pesquisar contatos …",
     "Could not load your contacts" : "Não foi possível carregar seus contatos",
     "No contacts found" : "Nenhum contato encontrado",
     "Show all contacts" : "Mostrar todos os contatos",
@@ -321,7 +311,7 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Ocorreu um erro ao pesquisar por {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "A pesquisa iniciará assim que você começar a digitar e você pode navegar nos resultados com as teclas de seta",
     "Search for {name} only" : "Pesquisar somente por {name}",
-    "Loading more results …" : "Carregando mais resultados…",
+    "Loading more results …" : "Carregando mais resultados …",
     "Forgot password?" : "Esqueceu a senha?",
     "Back to login form" : "Voltar ao formulário de login",
     "Back" : "Voltar",
@@ -351,6 +341,7 @@ OC.L10N.register(
     "Storage & database" : "Armazenamento & banco de dados",
     "Data folder" : "Pasta de dados",
     "Database configuration" : "Configuração do banco de dados",
+    "Database type" : "Tipo de banco de dados",
     "Only {firstAndOnlyDatabase} is available." : "Somente {firstAndOnlyDatabase} está disponível.",
     "Install and activate additional PHP modules to choose other database types." : "Instale e ative os módulos adicionais do PHP para escolher outros tipos de banco de dados.",
     "For more details check out the documentation." : "Para mais informações consulte a documentação.",
@@ -358,6 +349,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "Você escolheu o SQLite como banco de dados.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "O SQLite deve ser usado apenas para instâncias mínimas e de desenvolvimento. Para produção, recomendamos um banco de dados diferente.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se você usa clientes para sincronização de arquivos, o SQLite é altamente desencorajado.",
+    "Database connection" : "Conexão com o banco de dados",
     "Database user" : "Usuário do banco de dados",
     "Database password" : "Senha do banco de dados",
     "Database name" : "Nome do banco de dados",
@@ -365,7 +357,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor, especifique o nome do host e a porta (p. ex., localhost:5432).",
     "Database host" : "Host do banco de dados",
     "localhost" : "localhost",
-    "Installing …" : "Instalando …",
+    "Installing …" : "Instalando …",
     "Install" : "Instalar",
     "Need help?" : "Precisa de ajuda?",
     "See the documentation" : "Veja a documentação",
@@ -374,7 +366,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Seu navegador não é compatível. Por favor, atualize para uma versão mais recente ou compatível.",
     "Continue with this unsupported browser" : "Continuar com este navegador não compatível",
     "Supported versions" : "Versões compatíveis",
-    "Search {types} …" : "Pesquisar {types}…",
+    "Search {types} …" : "Pesquisar{types} …",
     "Choose {file}" : "Escolher {file}",
     "Choose" : "Escolher",
     "Copy to {target}" : "Copiar para {target}",
@@ -394,7 +386,7 @@ OC.L10N.register(
     "(all selected)" : "(todos selecionados)",
     "({count} selected)" : "({count} selecionados)",
     "Error loading file exists template" : "Erro carregando arquivo. Já existe o modelo",
-    "Saving …" : "Salvando...",
+    "Saving …" : "Salvando …",
     "seconds ago" : "segundos atrás",
     "Connection to server lost" : "Conexão perdida com o servidor",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema no carregamento da página, recarregando em %n segundo","Problema no carregamento da página, recarregando em %n de segundos","Problema no carregamento da página, recarregando em %n segundos"],
@@ -409,17 +401,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Digite para pesquisar projetos existentes",
     "New in" : "Novo em",
     "View changelog" : "Ver alterações",
-    "No action available" : "Nenhuma ação disponível",
-    "Error fetching contact actions" : "Erro ao obter as ações de contato",
     "Close \"{dialogTitle}\" dialog" : "Fechar a caixa de diálogo \"{dialogTitle}\"",
     "Email length is at max (255)" : "O comprimento do e-mail é no máximo (255)",
-    "Non-existing tag #{tag}" : "Etiqueta inexistente #{tag}",
-    "Restricted" : "Restrita",
-    "Invisible" : "Invisível",
-    "Delete" : "Excluir",
-    "Rename" : "Renomear",
-    "Collaborative tags" : "Etiquetas colaborativas",
-    "No tags found" : "Nenhuma etiqueta encontrada",
     "Clipboard not available, please copy manually" : "A área de transferência não está disponível, por favor, copie manualmente",
     "Personal" : "Pessoal",
     "Accounts" : "Contas",
@@ -507,19 +490,39 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Entre em contato com o administrador do sistema se esta mensagem persistir ou aparecer inesperadamente.",
     "Error occurred while checking server setup" : "Erro ao verificar a configuração do servidor",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Para obter mais detalhes, consulte a {linkstart}documentação ↗{linkend}.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Bate-papo, vídeo chamadas, compartilhamento de tela, reuniões on-line e conferência na web - no seu navegador e com aplicativos móveis.",
-    "You have not added any info yet" : "Você ainda não adicionou nenhuma informação",
-    "{user} has not added any info yet" : "{user} ainda não adicionou nenhuma informação",
-    "Error opening the user status modal, try hard refreshing the page" : "Erro ao abrir o modal de status do usuário, tente forçar uma atualização da página sem cache",
-    "Edit Profile" : "Editar Perfil ",
-    "The headline and about sections will show up here" : "As seções de título e sobre serão exibidas aqui",
+    "unknown text" : "texto desconhecido",
+    "Hello world!" : "Olá mundo!",
+    "sunny" : "ensolarado",
+    "Hello {name}, the weather is {weather}" : "Olá {name}, o clima está {weather}",
+    "Hello {name}" : "Olá {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estes são os resultados de sua pesquisa<script>alert(1)</script></strong>",
+    "new" : "novo",
+    "_download %n file_::_download %n files_" : ["baixar %n arquivo","baixar %n de arquivos","baixar %n arquivos"],
+    "Direct link copied to clipboard" : "Link direto copiado para a área de transferência",
+    "Searching …" : "Pesquisando …",
+    "Logging in …" : "Entrando …",
+    "Loading apps …" : "Carregando aplicativos...",
+    "Installing apps …" : "Instalando aplicativos...",
+    "Loading your contacts …" : "Carregando seus contatos...",
+    "Looking for {term} …" : "Procurando por {term}…",
+    "Search contacts …" : "Pesquisar contatos …",
+    "Loading more results …" : "Carregando mais resultados…",
+    "Search {types} …" : "Pesquisar {types}…",
+    "Saving …" : "Salvando...",
     "Very weak password" : "Senha muito fraca",
     "Weak password" : "Senha fraca",
     "So-so password" : "Senha mais ou menos",
     "Good password" : "Senha boa",
     "Strong password" : "Senha forte",
-    "Profile not found" : "Perfil não encontrado",
-    "The profile does not exist." : "O perfil não existe. ",
+    "No action available" : "Nenhuma ação disponível",
+    "Error fetching contact actions" : "Erro ao obter as ações de contato",
+    "Non-existing tag #{tag}" : "Etiqueta inexistente #{tag}",
+    "Restricted" : "Restrita",
+    "Invisible" : "Invisível",
+    "Delete" : "Excluir",
+    "Rename" : "Renomear",
+    "Collaborative tags" : "Etiquetas colaborativas",
+    "No tags found" : "Nenhuma etiqueta encontrada",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Seu diretório de dados e arquivos provavelmente estão acessíveis pela internet, porque o .htaccess não funciona.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para mais informações de como configurar apropriadamente seu servidor, consulte nossa <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentação</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Criar uma conta de administrador</strong>",
@@ -530,6 +533,6 @@ OC.L10N.register(
     "Configure the database" : "Configurar o banco de dados",
     "Only %s is available." : "Somente %s está disponível.",
     "Database account" : "Conta de banco de dados",
-    "Direct link copied to clipboard" : "Link direto copiado para a área de transferência"
+    "Installing …" : "Instalando …"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
