@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Неизвестный тип файла",
     "An error occurred. Please contact your admin." : "Произошла ошибка. Свяжитесь со своим администратором.",
     "Invalid image" : "Недопустимое изображение",
-    "No temporary profile picture available, try again" : "Временная картинка профиля недоступна, повторите попытку",
-    "No crop data provided" : "Не указана информация о кадрировании",
-    "No valid crop data provided" : "Не указаны корректные данные о кадрировании",
-    "Crop is not square" : "Кадр не является квадратом",
     "State token does not match" : "Токен состояния не совпадает",
     "Invalid app password" : "Неверный пароль приложения",
     "Could not complete login" : "Не удалось завершить вход в систему",
@@ -200,16 +196,6 @@ OC.L10N.register(
     "Matroska video" : "Видеофайл в формате Matroska",
     "Windows Media video" : "Видеофайл в формате Windows Media",
     "AVI video" : "Видеофайл в формате AVI",
-    "Error occurred while checking server setup" : "Произошла ошибка при проверке настроек сервера",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "За дополнительными сведениями обратитесь к {linkstart}документации ↗{linkend}.",
-    "unknown text" : "неизвестный текст",
-    "Hello world!" : "Привет мир!",
-    "sunny" : "солнечно",
-    "Hello {name}, the weather is {weather}" : "Здравствуйте, {name}! Погода сейчас  {weather}",
-    "Hello {name}" : "Здравствуйте, {name}!",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Эти результаты поиска<script>alert(1)</script></strong>",
-    "new" : "новый",
-    "_download %n file_::_download %n files_" : ["скачать %n файл","скачать %n файла","скачать %n файлов","скачать %n файла"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Выполняется обновление. Не уходите с этой страницы, т.к. в некоторых случаях может прервать процесс.",
     "Update to {version}" : "Обновление до версии {version}",
     "An error occurred." : "Произошла ошибка.",
@@ -230,7 +216,7 @@ OC.L10N.register(
     "Federated user" : "Федеративный пользователь",
     "user@your-nextcloud.org" : "пользователь@ваш-nextcloud.org",
     "Create share" : "Создать общий ресурс",
-    "Direct link copied to clipboard" : "Прямая ссылка, скопированная в буфер обмена",
+    "Direct link copied" : "Прямая ссылка скопирована",
     "Please copy the link manually:" : "Выполните копирование ссылки вручную:",
     "Custom date range" : "Настраиваемый диапазон дат",
     "Pick start date" : "Выберите дату начала",
@@ -239,7 +225,6 @@ OC.L10N.register(
     "Search in current app" : "Поиск в текущем приложении",
     "Clear search" : "Очистить поиск",
     "Search everywhere" : "Искать везде",
-    "Searching …" : "Поиск…",
     "Start typing to search" : "Начните вводить символы для поиска",
     "No matching results" : "Нет совпадающих результатов",
     "Today" : "Сегодня",
@@ -247,6 +232,7 @@ OC.L10N.register(
     "Last 30 days" : "Последние 30 дней",
     "This year" : "Этот год",
     "Last year" : "Прошлый год",
+    "Between {startDate} and {endDate}" : "Между {startDate} и {endDate}",
     "Unified search" : "Объединённый поиск",
     "Search apps, files, tags, messages" : "Поиск приложений, файлов, тегов, сообщений",
     "Places" : "Места",
@@ -254,11 +240,11 @@ OC.L10N.register(
     "Search people" : "Поиск людей",
     "People" : "Люди",
     "Filter in current view" : "Фильтр в текущем виде",
+    "Search connected services" : "Поиск подключенных сервисов",
     "Results" : "Результаты",
     "Load more results" : "Загрузить дополнительные результаты",
     "Search in" : "Искать в",
     "Log in" : "Войти",
-    "Logging in …" : "Вход в систему…",
     "Log in to {productName}" : "Вход в {productName}",
     "Wrong login or password." : "Неверное имя пользователя или пароль.",
     "This account is disabled" : "Эта учётная запись отключена",
@@ -295,21 +281,16 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Совместная работа с документами, таблицами и презентациями, основанная на Collabora Online.",
     "Distraction free note taking app." : "Простые приложение для ведения заметок.",
     "Recommended apps" : "Рекомендованные приложения",
-    "Loading apps …" : "Получение списка приложений…",
     "Could not fetch list of apps from the App Store." : "Не удалось получить список приложений.",
     "App download or installation failed" : "Не удалось скачать или установить приложение",
     "Cannot install this app because it is not compatible" : "Приложение не может быть установлено, так как оно несовместимо",
     "Cannot install this app" : "Это приложение не может быть установлено",
     "Skip" : "Пропустить",
-    "Installing apps …" : "Установка приложений…",
     "Install recommended apps" : "Установить рекомендуемые приложения",
     "Avatar of {displayName}" : "Изображение профиля {displayName}",
     "Settings menu" : "Меню настроек",
-    "Loading your contacts …" : "Загрузка контактов…",
-    "Looking for {term} …" : "Поиск {term}…",
     "Search contacts" : "Поиск контактов",
     "Reset search" : "Очистить поиск",
-    "Search contacts …" : "Поиск контакта…",
     "Could not load your contacts" : "Ошибка получения контактов",
     "No contacts found" : "Контактов не найдено",
     "Show all contacts" : "Показать все контакты",
@@ -321,13 +302,17 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Произошла ошибка при поиске {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Поиск начнётся при наборе текста. Для перехода к результатам поиска используйте клавиши со стрелками.",
     "Search for {name} only" : "Искать только для «{name}»",
-    "Loading more results …" : "Загрузка дополнительных результатов…",
     "Forgot password?" : "Забыли пароль?",
     "Back to login form" : "Вернуться к форме входа",
     "Back" : "Назад",
     "Login form is disabled." : "Форма входа отключена.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Диалог входа отключен. Используйте другой способ входа или свяжитесь с администратором.",
     "More actions" : "Больше действий",
+    "User menu" : "Меню пользователя",
+    "Your guest name: {user}" : "Ваше гостевое имя: {user}",
+    "You are currently not identified." : "В данный момент вы не идентифицированы.",
+    "Set public name" : "Задать публичное имя",
+    "Change public name" : "Изменить публичное имя",
     "Password is too weak" : "Пароль слишком слабый",
     "Password is weak" : "Пароль слабый",
     "Password is average" : "Пароль средний",
@@ -360,7 +345,6 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Пожалуйста укажите номер порта вместе с именем хоста (напр. localhost:5432)",
     "Database host" : "Хост базы данных",
     "localhost" : "локальный хост",
-    "Installing …" : "Установка ...",
     "Install" : "Установить",
     "Need help?" : "Требуется помощь?",
     "See the documentation" : "Посмотреть документацию",
@@ -369,7 +353,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Используемый браузер не поддерживается. Обновитесь до более новой версии или используйте другой браузер.",
     "Continue with this unsupported browser" : "Продолжить с использованием неподдерживаемого браузера",
     "Supported versions" : "Поддерживаемые версии",
-    "Search {types} …" : "Поиск {types}…",
     "Choose {file}" : "Выбран «{file}»",
     "Choose" : "Выбрать",
     "Copy to {target}" : "Скопировать в {target}",
@@ -389,7 +372,7 @@ OC.L10N.register(
     "(all selected)" : "(все выбранные)",
     "({count} selected)" : "(выбрано: {count})",
     "Error loading file exists template" : "Ошибка при загрузке шаблона существующего файла",
-    "Saving …" : "Сохранение…",
+    "Saving …" : "Сохранение…",
     "seconds ago" : "только что",
     "Connection to server lost" : "Потеряно подключение к серверу",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Возникла проблема при загрузке страницы, повторная попытка через %n секунду","Возникла проблема при загрузке страницы, повторная попытка через %n секунды","Возникла проблема при загрузке страницы, повторная попытка через %n секунд","Возникла проблема при загрузке страницы, повторная попытка через %n секунд"],
@@ -404,17 +387,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Нажмите, чтобы найти существующий проект",
     "New in" : "Новые возможности",
     "View changelog" : "Просмотреть изменения",
-    "No action available" : "Нет доступных действий",
-    "Error fetching contact actions" : "Ошибка получения действий контакта",
     "Close \"{dialogTitle}\" dialog" : "Закрыть «{dialogTitle}»",
     "Email length is at max (255)" : "Максимальная длина адреса эл. почты (255 символов)",
-    "Non-existing tag #{tag}" : "Несуществующая метка #{tag}",
-    "Restricted" : "Ограниченный",
-    "Invisible" : "Невидимый",
-    "Delete" : "Удалить",
-    "Rename" : "Переименовать",
-    "Collaborative tags" : "Совместные теги",
-    "No tags found" : "Метки не найдены",
     "Clipboard not available, please copy manually" : "Буфер обмена недоступен, пожалуйста, скопируйте вручную",
     "Personal" : "Личное",
     "Accounts" : "Учётные записи",
@@ -500,19 +474,41 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Этот сервер %s находится в режиме технического обслуживания, которое может занять некоторое время.",
     "This page will refresh itself when the instance is available again." : "Эта страница обновится автоматически когда сервер снова станет доступен.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Обратитесь к вашему системному администратору если это сообщение не исчезает или появляется неожиданно.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Текстовые сообщения, видеозвонки, демонстрация содержимого экрана, онлайн общение и веб-конференции на ПК и мобильных устройствах. ",
-    "You have not added any info yet" : "Вы ещё не добавили никакой информации",
-    "{user} has not added any info yet" : "Пользователь {user} ещё не добавил(а) никакой информации",
-    "Error opening the user status modal, try hard refreshing the page" : "Произошла ошибка при открытии модального окна пользователя, попробуйте обновить страницу",
-    "Edit Profile" : "Редактирование профиля",
-    "The headline and about sections will show up here" : "Разделы \"Заголовок\" и \"О вас\" будут отображаться здесь",
+    "Error occurred while checking server setup" : "Произошла ошибка при проверке настроек сервера",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "За дополнительными сведениями обратитесь к {linkstart}документации ↗{linkend}.",
+    "unknown text" : "неизвестный текст",
+    "Hello world!" : "Привет мир!",
+    "sunny" : "солнечно",
+    "Hello {name}, the weather is {weather}" : "Здравствуйте, {name}! Погода сейчас  {weather}",
+    "Hello {name}" : "Здравствуйте, {name}!",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Эти результаты поиска<script>alert(1)</script></strong>",
+    "new" : "новый",
+    "_download %n file_::_download %n files_" : ["скачать %n файл","скачать %n файла","скачать %n файлов","скачать %n файла"],
+    "Direct link copied to clipboard" : "Прямая ссылка, скопированная в буфер обмена",
+    "Searching …" : "Поиск…",
+    "Logging in …" : "Вход в систему…",
+    "Loading apps …" : "Получение списка приложений…",
+    "Installing apps …" : "Установка приложений…",
+    "Loading your contacts …" : "Загрузка контактов…",
+    "Looking for {term} …" : "Поиск {term}…",
+    "Search contacts …" : "Поиск контакта…",
+    "Loading more results …" : "Загрузка дополнительных результатов…",
+    "Search {types} …" : "Поиск {types}…",
+    "Saving …" : "Сохранение…",
     "Very weak password" : "Очень слабый пароль",
     "Weak password" : "Слабый пароль",
     "So-so password" : "Так себе пароль",
     "Good password" : "Хороший пароль",
     "Strong password" : "Надёжный пароль",
-    "Profile not found" : "Профиль не найден",
-    "The profile does not exist." : "Профиль не существует",
+    "No action available" : "Нет доступных действий",
+    "Error fetching contact actions" : "Ошибка получения действий контакта",
+    "Non-existing tag #{tag}" : "Несуществующая метка #{tag}",
+    "Restricted" : "Ограниченный",
+    "Invisible" : "Невидимый",
+    "Delete" : "Удалить",
+    "Rename" : "Переименовать",
+    "Collaborative tags" : "Совместные теги",
+    "No tags found" : "Метки не найдены",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Правила файла .htaccess не выполняются. Возможно, каталог данных и файлы свободно доступны из интернета.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Сведения о правильной настройке сервера можно найти в <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документации</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Создайте учетную запись администратора</strong>",
@@ -522,6 +518,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Переключить видимость пароля",
     "Configure the database" : "Настройка базы данных",
     "Only %s is available." : "Доступен только %s.",
-    "Database account" : "Учётная запись базы данных"
+    "Database account" : "Учётная запись базы данных",
+    "Installing …" : "Установка ..."
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
