@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Neznámy typ súboru",
     "An error occurred. Please contact your admin." : "Vyskytla sa chyba.\nProsím, kontaktujte svojho správcu.\n\t",
     "Invalid image" : "Chybný obrázok",
-    "No temporary profile picture available, try again" : "Dočasný profilový obrázok nie je k dispozícii, skúste to znovu",
-    "No crop data provided" : "Dáta pre orezanie neboli zadané",
-    "No valid crop data provided" : "Neplatné dáta pre orezanie neboli zadané",
-    "Crop is not square" : "Orezanie nie je štvorcové",
     "State token does not match" : "Príznak stavu nesúhlasí",
     "Invalid app password" : "Neplatné heslo aplikácie",
     "Could not complete login" : "Nie je možné dokončiť prihlásenie",
@@ -156,16 +152,6 @@ OC.L10N.register(
     "WebM audio" : "WebM audio",
     "MP3 ShoutCast playlist" : "MP3 ShoutCast playlist",
     "Windows BMP image" : "Obrázok Windows BMP",
-    "Error occurred while checking server setup" : "Počas kontroly nastavenia serveru sa stala chyba",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Viac podrobností nájdete v {linkstart}dokumentácii ↗{linkend}.",
-    "unknown text" : "neznámy text",
-    "Hello world!" : "Ahoj svet!",
-    "sunny" : "slnečno",
-    "Hello {name}, the weather is {weather}" : "Dobrý deň {name}, počasie je {weather}",
-    "Hello {name}" : "Vitaj {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Toto sú výsledky vášho vyhľadávania <script>alert(1)</script></strong>",
-    "new" : "nový",
-    "_download %n file_::_download %n files_" : ["stiahnuť %n súbor","stiahnuť %n súbory","stiahnuť %n súborov","stiahnuť %n súborov"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Aktualizácie prebieha. V niektorých prostrediach môže opustenie tejto stránky spôsobiť prerušenie aktualizácie.",
     "Update to {version}" : "Aktualizuj na {version}",
     "An error occurred." : "Vyskytla sa chyba.",
@@ -186,7 +172,6 @@ OC.L10N.register(
     "Federated user" : "Združený užívateľ",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "Vytvoriť zdieľanie",
-    "Direct link copied to clipboard" : "Priamy odkaz bol skopírovný do schránky",
     "Please copy the link manually:" : "Prosím skopírujte odkaz manuálne:",
     "Custom date range" : "Vlastné rozpätie dátumov",
     "Pick start date" : "Vyberte dátum začiatku",
@@ -195,7 +180,6 @@ OC.L10N.register(
     "Search in current app" : "Hľadať v aktuálnej aplikácii",
     "Clear search" : "Vymazať hľadanie",
     "Search everywhere" : "Hľadať všade",
-    "Searching …" : "Hľadá sa…",
     "Start typing to search" : "Začnite písať pre vyhľadanie",
     "No matching results" : "Žiadne zhodujúce výsledky",
     "Today" : "Dnes",
@@ -214,7 +198,6 @@ OC.L10N.register(
     "Load more results" : "Načítať viac výsledkov",
     "Search in" : "Hľadať v",
     "Log in" : "Prihlásiť sa",
-    "Logging in …" : "Prihlasujem ...",
     "Log in to {productName}" : "Prihlásiť sa do {productName}u",
     "Wrong login or password." : "Nesprávne meno alebo heslo.",
     "This account is disabled" : "Tento účet je deaktivovaný",
@@ -251,21 +234,16 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Kolaboratívne dokumenty, tabuľky a prezentácie postavené na Collabora Online.",
     "Distraction free note taking app." : "Aplikácia pre písanie poznámok bez rozptyľovania.",
     "Recommended apps" : "Odporúčané apky",
-    "Loading apps …" : "Načítavanie apiek...",
     "Could not fetch list of apps from the App Store." : "Nepodarilo sa načítať zoznam apiek z Obchodu s aplikáciami.",
     "App download or installation failed" : "Nepodarilo sa prevziať alebo nainštalovať apku",
     "Cannot install this app because it is not compatible" : "Táto apka sa nedá nainštalovať, pretože nie je kompatibilná",
     "Cannot install this app" : "Táto aplikácia sa nedá nainštalovať",
     "Skip" : "Preskočiť",
-    "Installing apps …" : "Inštalácia apiek...",
     "Install recommended apps" : "Nainštalovať odporúčané apky",
     "Avatar of {displayName}" : "Avatar užívateľa {displayName}",
     "Settings menu" : "Menu nastavení",
-    "Loading your contacts …" : "Načítavam vaše kontakty...",
-    "Looking for {term} …" : "Hľadá sa výraz {term}...",
     "Search contacts" : "Prehľadať kontakty",
     "Reset search" : "Vynuluj vyhľadávanie",
-    "Search contacts …" : "Prehľadať kontakty...",
     "Could not load your contacts" : "Nie je možné načítať Vaše kontakty",
     "No contacts found" : "Kontakty nenájdené",
     "Show all contacts" : "Zobraziť všetky kontakty",
@@ -277,7 +255,6 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Počas hľadania {type} sa vyskytla chyba",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Hľadanie sa začína, keď začnete písať a výsledky môžete dosiahnuť pomocou šípiek.",
     "Search for {name} only" : "Hľadať iba {name}",
-    "Loading more results …" : "Načítava sa viac výsledkov …",
     "Forgot password?" : "Zabudli ste heslo?",
     "Back to login form" : "Späť na prihlásenie",
     "Back" : "Späť",
@@ -316,7 +293,6 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zadajte číslo portu spolu s názvom hostiteľa (napr. localhost:5432).",
     "Database host" : "Server databázy",
     "localhost" : "localhost",
-    "Installing …" : "Inštalujem ...",
     "Install" : "Inštalovať",
     "Need help?" : "Potrebujete pomoc?",
     "See the documentation" : "Pozri dokumentáciu",
@@ -325,7 +301,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Váš prehliadač nie je podporovaný. Inovujte na novšiu alebo podporovanú verziu.",
     "Continue with this unsupported browser" : "Pokračovať s nepodporovaným prehliadačom",
     "Supported versions" : "Podporované verzie",
-    "Search {types} …" : "Vyhľadať {types}",
     "Choose {file}" : "Vyberte {file}",
     "Choose" : "Vybrať",
     "Copy to {target}" : "Kopírovať do {target}",
@@ -345,7 +320,7 @@ OC.L10N.register(
     "(all selected)" : "(všetko vybrané)",
     "({count} selected)" : "({count} vybraných)",
     "Error loading file exists template" : "Chyba pri nahrávaní šablóny existencie súboru",
-    "Saving …" : "Ukladá sa...",
+    "Saving …" : "Ukladanie …",
     "seconds ago" : "pred sekundami",
     "Connection to server lost" : "Stratené spojenie so serverom",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Nepodarilo sa načítať stránku, opätovný pokus o %n sekundu","Nepodarilo sa načítať stránku, opätovný pokus o %n sekundy","Nepodarilo sa načítať stránku, opätovný pokus o %n sekúnd","Nepodarilo sa načítať stránku, opätovný pokus o %n sekúnd"],
@@ -360,17 +335,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Hľadajte v existujúcich projektoch",
     "New in" : "Nové v",
     "View changelog" : "Zobraziť súhrn zmien",
-    "No action available" : "NIe sú dostupné žiadne akcie",
-    "Error fetching contact actions" : "Chyba počas získavania akcií kontaktu",
     "Close \"{dialogTitle}\" dialog" : "Zatvoriť okno \"{dialogTitle}\"",
     "Email length is at max (255)" : "E-mailová správa má maximálnu veľkosť (255)",
-    "Non-existing tag #{tag}" : "Neexistujúci štítok #{tag}",
-    "Restricted" : "Obmedzené",
-    "Invisible" : "Neviditeľný",
-    "Delete" : "Zmazať",
-    "Rename" : "Premenovať",
-    "Collaborative tags" : "Štítky pre spoluprácu",
-    "No tags found" : "Štítky sa nenašli",
     "Clipboard not available, please copy manually" : "Schránka nie je k dispozícii, prosím skopírujte ručne",
     "Personal" : "Osobné",
     "Accounts" : "Účty",
@@ -455,19 +421,41 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Táto %s inštancia je v súčasnej dobe v režime údržby. Počkajte prosím.",
     "This page will refresh itself when the instance is available again." : "Táto stránka sa obnoví sama hneď ako bude inštancia znovu dostupná.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktujte prosím správcu systému, ak sa táto správa objavuje opakovane alebo neočakávane.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Četovanie, videohovory, zdieľanie obrazovky, online stretnutia a webové konferencie - vo vašom prehliadači a pomocou mobilných aplikácií.",
-    "You have not added any info yet" : "Zatiaľ ste nepridali žiadne informácie",
-    "{user} has not added any info yet" : "{user} zatiaľ nepridal žiadne informácie",
-    "Error opening the user status modal, try hard refreshing the page" : "Chyba pri otváraní modálneho okna stavu používateľa, skúste stránku obnoviť",
-    "Edit Profile" : "Upraviť rofil",
-    "The headline and about sections will show up here" : "Tu sa zobrazí titul a sekcia Informácie",
+    "Error occurred while checking server setup" : "Počas kontroly nastavenia serveru sa stala chyba",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Viac podrobností nájdete v {linkstart}dokumentácii ↗{linkend}.",
+    "unknown text" : "neznámy text",
+    "Hello world!" : "Ahoj svet!",
+    "sunny" : "slnečno",
+    "Hello {name}, the weather is {weather}" : "Dobrý deň {name}, počasie je {weather}",
+    "Hello {name}" : "Vitaj {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Toto sú výsledky vášho vyhľadávania <script>alert(1)</script></strong>",
+    "new" : "nový",
+    "_download %n file_::_download %n files_" : ["stiahnuť %n súbor","stiahnuť %n súbory","stiahnuť %n súborov","stiahnuť %n súborov"],
+    "Direct link copied to clipboard" : "Priamy odkaz bol skopírovný do schránky",
+    "Searching …" : "Hľadá sa…",
+    "Logging in …" : "Prihlasujem ...",
+    "Loading apps …" : "Načítavanie apiek...",
+    "Installing apps …" : "Inštalácia apiek...",
+    "Loading your contacts …" : "Načítavam vaše kontakty...",
+    "Looking for {term} …" : "Hľadá sa výraz {term}...",
+    "Search contacts …" : "Prehľadať kontakty...",
+    "Loading more results …" : "Načítava sa viac výsledkov …",
+    "Search {types} …" : "Vyhľadať {types}",
+    "Saving …" : "Ukladá sa...",
     "Very weak password" : "Veľmi slabé heslo",
     "Weak password" : "Slabé heslo",
     "So-so password" : "Priemerné heslo",
     "Good password" : "Dobré heslo",
     "Strong password" : "Silné heslo",
-    "Profile not found" : "Profil nenájdený",
-    "The profile does not exist." : "Profil neexistuje.",
+    "No action available" : "NIe sú dostupné žiadne akcie",
+    "Error fetching contact actions" : "Chyba počas získavania akcií kontaktu",
+    "Non-existing tag #{tag}" : "Neexistujúci štítok #{tag}",
+    "Restricted" : "Obmedzené",
+    "Invisible" : "Neviditeľný",
+    "Delete" : "Zmazať",
+    "Rename" : "Premenovať",
+    "Collaborative tags" : "Štítky pre spoluprácu",
+    "No tags found" : "Štítky sa nenašli",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš priečinok s dátami a súbormi je dostupný z internetu, lebo súbor .htaccess nefunguje.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pre podrobnosti ako správne nakonfigurovať server si pozrite prosím <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentáciu</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Vytvoriť účet administrátora</strong>",
@@ -477,6 +465,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Prepnúť viditeľnosť hesla",
     "Configure the database" : "Nastaviť databázu",
     "Only %s is available." : "Je dostupný len %s.",
-    "Database account" : "Databázový účet"
+    "Database account" : "Databázový účet",
+    "Installing …" : "Inštalujem ..."
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
