@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Dosya türü bilinmiyor",
     "An error occurred. Please contact your admin." : "Bir sorun çıktı. Lütfen yöneticiniz ile görüşün.",
     "Invalid image" : "Görsel geçersiz",
-    "No temporary profile picture available, try again" : "Kullanılabilecek geçici bir profil görseli bulunamadı. Yeniden deneyin",
-    "No crop data provided" : "Kırpma verileri belirtilmemiş",
-    "No valid crop data provided" : "Geçerli bir kırpma verisi belirtilmemiş",
-    "Crop is not square" : "Kırpma kare şeklinde değil",
     "State token does not match" : "Durum kodu eşleşmiyor",
     "Invalid app password" : "Uygulama parolası geçersiz",
     "Could not complete login" : "Oturum açılamadı",
@@ -44,6 +40,7 @@ OC.L10N.register(
     "Task not found" : "Görev bulunamadı",
     "Internal error" : "İçeride bir sorun çıktı",
     "Not found" : "Bulunamadı",
+    "Node is locked" : "Düğüm kilitlenmiş",
     "Bad request" : "İstek hatalı",
     "Requested task type does not exist" : "İstenilen görev türü bulunamadı",
     "Necessary language model provider is not available" : "Gerekli dil modeli sağlayıcısı kullanılamıyor",
@@ -52,6 +49,7 @@ OC.L10N.register(
     "No translation provider available" : "Kullanılabilecek bir çeviri hizmeti sağlayıcı yok",
     "Could not detect language" : "Dil algılanamadı",
     "Unable to translate" : "Çevrilemedi",
+    "No valid filters provided" : "Geçerli bir süzgeç belirtilmemiş",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Onarım adımı:",
     "Repair info:" : "Onarım bilgileri:",
@@ -64,34 +62,141 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Hesap sayısı sınırını artırmak için destek uygulamasına abonelik kodunuzu yazın. Bu ayrıca size Nextcloud Enterprise sürümünün sunduğu ve kurumsal operasyonlar için önemle önerilen tüm ek faydaları sağlar.",
     "Learn more ↗" : "Ayrıntılı bilgi alın ↗",
     "Preparing update" : "Güncelleme hazırlanıyor",
-    "Please use the command line updater because updating via browser is disabled in your config.php." : "Tarayıcı üzerinden güncelleme config.php dosyasında devre dışı bırakılmış olduğundan, komut satırı güncelleyicisini kullanın.",
+    "Please use the command line updater because updating via browser is disabled in your config.php." : "Tarayıcı üzerinden güncelleme özelliği config.php dosyasından kapatılmış olduğundan, komut satırı güncelleyicisini kullanın.",
     "Turned on maintenance mode" : "Bakım kipi açıldı",
     "Turned off maintenance mode" : "Bakım kipi kapatıldı",
     "Maintenance mode is kept active" : "Bakım kipi kullanımda tutuldu",
-    "Updating database schema" : "Veritabanı şeması güncelleniyor",
-    "Updated database" : "Veritabanı güncellendi",
+    "Updating database schema" : "Veri tabanı şeması güncelleniyor",
+    "Updated database" : "Veri tabanı güncellendi",
     "Update app \"%s\" from App Store" : "Uygulama mağazasından \"%s\" uygulamasını güncelle",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "%s için veritabanı şeması güncellemesi denetleniyor (veri tabanının büyüklüğüne bağlı olarak uzun sürebilir)",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "%s için veri tabanı şeması güncellemesi denetleniyor (veri tabanının büyüklüğüne bağlı olarak uzun sürebilir)",
     "Updated \"%1$s\" to %2$s" : "\"%1$s\", %2$s sürümüne güncellendi",
     "Set log level to debug" : "Günlük kaydı düzeyi hata ayıklama olarak ayarlanıyor",
     "Reset log level" : "Günlük kaydı düzeyi sıfırlanıyor",
     "Starting code integrity check" : "Kod bütünlüğü sınaması başlatılıyor",
     "Finished code integrity check" : "Kod bütünlüğü sınaması tamamlandı",
     "%s (incompatible)" : "%s (uyumsuz)",
-    "The following apps have been disabled: %s" : "Şu uygulamalar devre dışı bırakıldı: %s",
+    "The following apps have been disabled: %s" : "Şu uygulamalar kullanımdan kaldırıldı: %s",
     "Already up to date" : "Zaten güncel",
+    "Windows Command Script" : "Windows komut satırı betiği",
+    "Electronic book document" : "Elektronik kitap belgesi",
+    "TrueType Font Collection" : "TrueType yazı tipi derlemesi",
+    "Web Open Font Format" : "Web Open yazı tipi biçimi",
+    "GPX geographic data" : "GPX coğrafi verileri",
+    "Gzip archive" : "Gzip arşivi",
+    "Adobe Illustrator document" : "Adobe Illustrator belgesi",
+    "Java source code" : "Java kaynak kodu",
+    "JavaScript source code" : "JavaScript kaynak kodu",
+    "JSON document" : "JSON belgesi",
+    "Microsoft Access database" : "Microsoft Access veri tabanı",
+    "Microsoft OneNote document" : "Microsoft OneNote belgesi",
+    "Microsoft Word document" : "Microsoft Word belgesi",
     "Unknown" : "Bilinmiyor",
-    "PNG image" : "PNG Görseli",
-    "Error occurred while checking server setup" : "Sunucu ayarları denetlenirken sorun çıktı",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Ayrıntılı bilgi almak için {linkstart}belgeler ↗{linkend} bölümüne bakabilirsiniz.",
-    "unknown text" : "bilinmeyen metin",
-    "Hello world!" : "Merhaba dünya!",
-    "sunny" : "güneşli",
-    "Hello {name}, the weather is {weather}" : "Merhaba {name}, hava durumu {weather}",
-    "Hello {name}" : "Merhaba {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Arama sonuçlarınız<script>alert(1)</script></strong>",
-    "new" : "yeni",
-    "_download %n file_::_download %n files_" : ["%n dosya indiriliyor","%n dosya indiriliyor"],
+    "PDF document" : "PDF belgesi",
+    "PostScript document" : "PostScript belgesi",
+    "RSS summary" : "RSS özeti",
+    "Android package" : "Android paketi",
+    "KML geographic data" : "KML coğrafi verileri",
+    "KML geographic compressed data" : "KML sıkıştırılmış coğrafi verileri",
+    "Lotus Word Pro document" : "Lotus Word Pro belgesi",
+    "Excel spreadsheet" : "Excel çalışma sayfası",
+    "Excel add-in" : "Excel eklentisi",
+    "Excel 2007 binary spreadsheet" : "Excel 2007 binary çalışma sayfası",
+    "Excel spreadsheet template" : "Excel çalışma sayfası kalıbı",
+    "Outlook Message" : "Outlook iletisi",
+    "PowerPoint presentation" : "PowerPoint sunumu",
+    "PowerPoint add-in" : "PowerPoint eklentisi",
+    "PowerPoint presentation template" : "PowerPoint sunumu kalıbı",
+    "Word document" : "Word belgesi",
+    "ODF formula" : "ODF formülü",
+    "ODG drawing" : "ODG çizimi",
+    "ODG drawing (Flat XML)" : "ODG çizimi (Düz XML)",
+    "ODG template" : "ODG kalıbı",
+    "ODP presentation" : "ODP sunumu",
+    "ODP presentation (Flat XML)" : "ODP sunumu (Düz XML)",
+    "ODP template" : "ODP kalıbı",
+    "ODS spreadsheet" : "ODS çalışma sayfası",
+    "ODS spreadsheet (Flat XML)" : "ODS çalışma sayfası (Düz XML)",
+    "ODS template" : "ODS kalıbı",
+    "ODT document" : "ODT belgesi",
+    "ODT document (Flat XML)" : "ODT belgesi (Düz XML)",
+    "ODT template" : "ODT kalıbı",
+    "PowerPoint 2007 presentation" : "PowerPoint 2007 sunumu",
+    "PowerPoint 2007 show" : "PowerPoint 2007 gösterisi",
+    "PowerPoint 2007 presentation template" : "PowerPoint 2007 sunumu kalıbı",
+    "Excel 2007 spreadsheet" : "Excel 2007 çalışma sayfası",
+    "Excel 2007 spreadsheet template" : "Excel 2007 çalışma sayfası kalıbı",
+    "Word 2007 document" : "Word 2007 belgesi",
+    "Word 2007 document template" : "Word 2007 belgesi kalıbı",
+    "Microsoft Visio document" : "Microsoft Visio belgesi",
+    "WordPerfect document" : "WordPerfect belgesi",
+    "7-zip archive" : "7-zip arşivi",
+    "Blender scene" : "Blender manzarası",
+    "Bzip2 archive" : "Bzip2 arşivi",
+    "Debian package" : "Debian paketi",
+    "FictionBook document" : "FictionBook belgesi",
+    "Unknown font" : "Yazı tipi bilinmiyor",
+    "Krita document" : "Krita belgesi",
+    "Mobipocket e-book" : "Mobipocket e-kitabı",
+    "Windows Installer package" : "Windows kurulum paketi",
+    "Perl script" : "Perl betiği",
+    "PHP script" : "PHP betiği",
+    "Tar archive" : "Tar arşivi",
+    "XML document" : "XML belgesi",
+    "YAML document" : "YAML belgesi",
+    "Zip archive" : "Zip arşivi",
+    "Zstandard archive" : "Zstandard arşivi",
+    "AAC audio" : "AAC ses dosyası",
+    "FLAC audio" : "FLAC ses dosyası",
+    "MPEG-4 audio" : "MPEG-4 ses dosyası",
+    "MP3 audio" : "MP3 ses dosyası",
+    "Ogg audio" : "Ogg ses dosyası",
+    "RIFF/WAVe standard Audio" : "RIFF/WAVe standart ses dosyası",
+    "WebM audio" : "WebM ses dosyası",
+    "MP3 ShoutCast playlist" : "MP3 ShoutCast oynatma listesi",
+    "Windows BMP image" : "Windows BMP görseli",
+    "Better Portable Graphics image" : "Better Portable Graphics görseli",
+    "EMF image" : "EMF görseli",
+    "GIF image" : "GIF görseli",
+    "HEIC image" : "HEIC görseli",
+    "HEIF image" : "HEIF görseli",
+    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 görseli",
+    "JPEG image" : "JPEG görseli",
+    "PNG image" : "PNG görseli",
+    "SVG image" : "SVG görseli",
+    "Truevision Targa image" : "Truevision Targa görseli",
+    "TIFF image" : "TIFF görseli",
+    "WebP image" : "WebP görseli",
+    "Digital raw image" : "Dijital ham görseli",
+    "Windows Icon" : "Windows simgesi",
+    "Email message" : "E-posta iletisi",
+    "VCS/ICS calendar" : "VCS/ICS takvimi",
+    "CSS stylesheet" : "CSS biçem sayfası",
+    "CSV document" : "CSV belgesi",
+    "HTML document" : "HTML belgesi",
+    "Markdown document" : "Markdown belgesi",
+    "Org-mode file" : "Org-mode dosyası",
+    "Plain text document" : "Düz yazı belgesi",
+    "Rich Text document" : "Zengin yazı belgesi",
+    "Electronic business card" : "Elektronik kartvizit",
+    "C++ source code" : "C++ kaynak kodu",
+    "LDIF address book" : "LDIF adres defteri",
+    "NFO document" : "NFO belgesi",
+    "PHP source" : "PHP kaynak kodu",
+    "Python script" : "Python betiği",
+    "ReStructuredText document" : "ReStructuredText belgesi",
+    "3GPP multimedia file" : "3GPP çoklu ortam dosyası",
+    "MPEG video" : "MPEG görüntü dosyası",
+    "DV video" : "DV görüntü dosyası",
+    "MPEG-2 transport stream" : "MPEG-2 aktarım akışı",
+    "MPEG-4 video" : "MPEG-4 görüntü dosyası",
+    "Ogg video" : "Ogg görüntü dosyası",
+    "QuickTime video" : "QuickTime görüntü dosyası",
+    "WebM video" : "WebM görüntü dosyası",
+    "Flash video" : "Flash görüntü dosyası",
+    "Matroska video" : "Matroska görüntü dosyası",
+    "Windows Media video" : "Windows Media görüntü dosyası",
+    "AVI video" : "AVI görüntü dosyası",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Güncelleniyor. Bu sayfadan ayrılırsanız bazı işlemler yarım kalabilir.",
     "Update to {version}" : "{version} sürümüne güncelleniyor",
     "An error occurred." : "Bir sorun çıktı.",
@@ -112,7 +217,7 @@ OC.L10N.register(
     "Federated user" : "Birleşik kullanıcı",
     "user@your-nextcloud.org" : "kullanici@nextcloud-kopyaniz.org",
     "Create share" : "Paylaşım ekle",
-    "Direct link copied to clipboard" : "Doğrudan bağlantı panoya kopyalandı",
+    "Direct link copied" : "Doğrudan bağlantı kopyalandı",
     "Please copy the link manually:" : "Lütfen bağlantıyı el ile kopyalayın:",
     "Custom date range" : "Özel tarih aralığı",
     "Pick start date" : "Başlangıç tarihini seçin",
@@ -121,14 +226,16 @@ OC.L10N.register(
     "Search in current app" : "Geçerli uygulamada ara",
     "Clear search" : "Aramayı temizle",
     "Search everywhere" : "Her yerde ara",
-    "Searching …" : "Aranıyor…",
+    "Searching …" : "Aranıyor…",
     "Start typing to search" : "Aramak için yazmaya başlayın",
+    "Minimum search length is {minSearchLength} characters" : "En az {minSearchLength} karakter ile arama yapılabilir ",
     "No matching results" : "Aramaya uyan bir sonuç bulunamadı",
     "Today" : "Bugün",
     "Last 7 days" : "Önceki 7 gün",
     "Last 30 days" : "Önceki 30 gün",
     "This year" : "Bu yıl",
     "Last year" : "Önceki yıl",
+    "Between {startDate} and {endDate}" : "{startDate} ile {endDate} arasında",
     "Unified search" : "Birleşik arama",
     "Search apps, files, tags, messages" : "Uygulama, dosya, etiket, ileti ara",
     "Places" : "Yerler",
@@ -136,14 +243,15 @@ OC.L10N.register(
     "Search people" : "Kişi ara",
     "People" : "Kişiler",
     "Filter in current view" : "Geçerli görünümü süz",
+    "Search connected services" : "Bağlı aygıtları ara",
     "Results" : "Sonuçlar",
     "Load more results" : "Diğer sonuçları yükle",
     "Search in" : "Şurada aransın",
     "Log in" : "Oturum aç",
-    "Logging in …" : "Oturum açılıyor …",
+    "Logging in …" : "Oturum açılıyor…",
     "Log in to {productName}" : "{productName} oturumu aç",
     "Wrong login or password." : "Hatalı kullanıcı adı ya da parolası.",
-    "This account is disabled" : "Bu hesap devre dışı bırakılmış",
+    "This account is disabled" : "Bu hesap kullanımdan kaldırılmış",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "IP adresinizden yapılan birden çok geçersiz oturum açma girişimi algılandı. Bu nedenle oturum açmanız 30 saniye süreyle engellendi.",
     "Account name or email" : "Hesap adı ya da e-posta adresi",
     "Account name" : "Hesap adı",
@@ -173,25 +281,25 @@ OC.L10N.register(
     "Schedule work & meetings, synced with all your devices." : "İşlerinizi ve toplantılarınızı planlayın ve tüm aygıtlarınızla eşitleyin.",
     "Keep your colleagues and friends in one place without leaking their private info." : "İş arkadaşlarınızın ve tanıdıklarınızın kayıtlarını kişisel bilgilerini sızdırmadan tek bir yerde tutun.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Dosyalar, Kişiler ve Takvim uygulamaları ile bir arada çalışan basit bir e-posta uygulaması.",
-    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Sohbet, görüntülü çağrı, ekran paylaşımı, çevrim içi toplantılar ve internet görüşmeleri - masaüstü ve mobil için uygulamalar.",
+    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Sohbet, görüntülü çağrı, ekran paylaşımı, çevrim içi toplantılar ve internet görüşmeleri. Bilgisayar ve mobil aygıtlar için uygulamalar.",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collabora Online üzerinde hazırlanmış iş birlikli çalışma belgeleri, hesap tabloları ve sunumlar.",
     "Distraction free note taking app." : "Dikkatinizi dağıtmayan not alma uygulaması.",
     "Recommended apps" : "Önerilen uygulamalar",
-    "Loading apps …" : "Uygulamalar yükleniyor …",
+    "Loading apps …" : "Uygulamalar yükleniyor…",
     "Could not fetch list of apps from the App Store." : "Uygulama mağazasından uygulama listesi alınamadı.",
     "App download or installation failed" : "Uygulama indirilemedi ya da kurulamadı",
     "Cannot install this app because it is not compatible" : "Bu uygulama uyumlu olmadığından kurulamadı",
     "Cannot install this app" : "Bu uygulama kurulamadı",
     "Skip" : "Atla",
-    "Installing apps …" : "Uygulamalar kuruluyor …",
+    "Installing apps …" : "Uygulamalar kuruluyor…",
     "Install recommended apps" : "Önerilen uygulamaları kur",
     "Avatar of {displayName}" : "{displayName} avatarı",
     "Settings menu" : "Ayarlar menüsü",
-    "Loading your contacts …" : "Kişileriniz yükleniyor …",
-    "Looking for {term} …" : "{term} ifadesi aranıyor …",
+    "Loading your contacts …" : "Kişileriniz yükleniyor…",
+    "Looking for {term} …" : "{term} ifadesi aranıyor…",
     "Search contacts" : "Kişi arama",
     "Reset search" : "Aramayı sıfırla",
-    "Search contacts …" : "Kişi arama …",
+    "Search contacts …" : "Kişi arama…",
     "Could not load your contacts" : "Kişileriniz yüklenemedi",
     "No contacts found" : "Herhangi bir kişi bulunamadı",
     "Show all contacts" : "Tüm kişileri görüntüle",
@@ -203,13 +311,18 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "{type} aranırken bir sorun çıktı",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Arama, yazmaya başladığınızda başlar ve sonuçlara ok tuşları ile erişilebilir",
     "Search for {name} only" : "Yalnızca {name} için ara",
-    "Loading more results …" : "Diğer sonuçlar yükleniyor…",
+    "Loading more results …" : "Diğer sonuçlar yükleniyor…",
     "Forgot password?" : "Parolamı unuttum",
     "Back to login form" : "Oturum açma formuna dön",
     "Back" : "Geri",
-    "Login form is disabled." : "Oturum açma formu devre dışı bırakılmış.",
-    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud oturum açma formu devre dışı bırakılmış. Varsa başka bir oturum açma seçeneğini kullanın ya da yöneticiniz ile görüşün.",
+    "Login form is disabled." : "Oturum açma formu kullanımdan kaldırılmış.",
+    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud oturum açma formu kullanımdan kaldırılmış. Varsa başka bir oturum açma seçeneğini kullanın ya da yöneticiniz ile görüşün.",
     "More actions" : "Diğer işlemler",
+    "User menu" : "Kullanıcı menüsü",
+    "Your guest name: {user}" : "Konuk adınız: {user}",
+    "You are currently not identified." : "Şu anda tanımlanmamışsınız.",
+    "Set public name" : "Herkese açık adı ayarla",
+    "Change public name" : "Herkese açık adı değiştir",
     "Password is too weak" : "Parola çok kolay",
     "Password is weak" : "Parola kolay",
     "Password is average" : "Parola orta zorlukta",
@@ -225,24 +338,26 @@ OC.L10N.register(
     "Create administration account" : "Yönetici hesabı oluştur",
     "Administration account name" : "Yönetici hesabı kullanıcı adı",
     "Administration account password" : "Yönetici hesabı parolası",
-    "Storage & database" : "Depolama ve veritabanı",
+    "Storage & database" : "Depolama alanı ve veri tabanı",
     "Data folder" : "Veri klasörü",
-    "Database configuration" : "Veritabanı yapılandırması",
+    "Database configuration" : "Veri tabanı yapılandırması",
+    "Database type" : "Veri tabanı türü",
     "Only {firstAndOnlyDatabase} is available." : "Yalnızca {firstAndOnlyDatabase} kullanılabilir.",
-    "Install and activate additional PHP modules to choose other database types." : "Diğer veritabanı türlerini seçebilmek için ek PHP modüllerini kurun ve etkinleştirin.",
+    "Install and activate additional PHP modules to choose other database types." : "Diğer veri tabanı türlerini seçebilmek için ek PHP modüllerini kurun ve etkinleştirin.",
     "For more details check out the documentation." : "Ayrıntılı bilgi almak için belgelere bakabilirsiniz.",
     "Performance warning" : "Başarım uyarısı",
-    "You chose SQLite as database." : "Veritabanı olarak SQLite seçtiniz.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite yalnızca küçük ve geliştirme ortamları için seçilmelidir. Üretim ortamları için farklı bir veritabanı kullanmanız önerilir.",
+    "You chose SQLite as database." : "Veri tabanı olarak SQLite seçtiniz.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite yalnızca küçük ve geliştirme ortamları için seçilmelidir. Üretim ortamları için farklı bir veri tabanı kullanmanız önerilir.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Dosya eşitlemesi için istemcileri kullanıyorsanız SQLite kullanımından kaçınmalısınız.",
-    "Database user" : "Veritabanı kullanıcı adı",
-    "Database password" : "Veritabanı parolası",
-    "Database name" : "Veritabanı adı",
-    "Database tablespace" : "Veritabanı tablo alanı",
+    "Database connection" : "Veri tabanı bağlantısı",
+    "Database user" : "Veri tabanı kullanıcı adı",
+    "Database password" : "Veri tabanı parolası",
+    "Database name" : "Veri tabanı adı",
+    "Database tablespace" : "Veri tabanı tablo alanı",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Lütfen sunucu adının yanında bağlantı noktasını da belirtin (Örnek: localhost:5432).",
-    "Database host" : "Veritabanı sunucusu",
+    "Database host" : "Veri tabanı sunucusu",
     "localhost" : "localhost",
-    "Installing …" : "Kuruluyor…",
+    "Installing …" : "Kuruluyor…",
     "Install" : "Kur",
     "Need help?" : "Yardım gerekiyor mu?",
     "See the documentation" : "Belgelere bakın",
@@ -251,7 +366,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Tarayıcınız desteklenmiyor. Lütfen daha yeni bir sürüme ya da desteklenen bir sürüme yükseltin.",
     "Continue with this unsupported browser" : "Bu desteklenmeyen tarayıcı ile ilerle",
     "Supported versions" : "Desteklenen sürümler",
-    "Search {types} …" : "{types} arama…",
+    "Search {types} …" : "{types} arama…",
     "Choose {file}" : "{file} seçin",
     "Choose" : "Seçin",
     "Copy to {target}" : "{target} içine kopyala",
@@ -271,8 +386,8 @@ OC.L10N.register(
     "(all selected)" : "(tüm seçilmişler)",
     "({count} selected)" : "({count} seçilmiş)",
     "Error loading file exists template" : "Dosya var kalıbı yüklenirken sorun çıktı",
-    "Saving …" : "Kaydediliyor …",
-    "seconds ago" : "saniyeler önce",
+    "Saving …" : "Kaydediliyor…",
+    "seconds ago" : "saniye önce",
     "Connection to server lost" : "Sunucu bağlantısı kesildi",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Sayfa yüklenirken bir sorun çıktı. %n saniye sonra yeniden yüklenecek","Sayfa yüklenirken bir sorun çıktı. %n saniye sonra yeniden yüklenecek"],
     "Add to a project" : "Bir projeye ekle",
@@ -286,23 +401,15 @@ OC.L10N.register(
     "Type to search for existing projects" : "Var olan projeleri aramak için yazın",
     "New in" : "Şuraya ekle",
     "View changelog" : "Değişiklik günlüğünü görüntüle",
-    "No action available" : "Yapılabilecek bir işlem yok",
-    "Error fetching contact actions" : "Kişi işlemleri alınırken sorun çıktı",
     "Close \"{dialogTitle}\" dialog" : "\"{dialogTitle}\" penceresini kapat",
     "Email length is at max (255)" : "E-posta uzunluğu en fazla (255)",
-    "Non-existing tag #{tag}" : "#{tag} etiketi bulunamadı",
-    "Restricted" : "Kısıtlanmış",
-    "Invisible" : "Görünmez",
-    "Delete" : "Sil",
-    "Rename" : "Yeniden adlandır",
-    "Collaborative tags" : "İş birlikli etiketler",
-    "No tags found" : "Herhangi bir etiket bulunamadı",
     "Clipboard not available, please copy manually" : "Pano kullanılamıyor. Lütfen el ile kopyalayın",
     "Personal" : "Kişisel",
     "Accounts" : "Hesaplar",
     "Admin" : "Yönetici",
     "Help" : "Yardım",
     "Access forbidden" : "Erişim engellendi",
+    "You are not allowed to access this page." : "Bu sayfaya erişme izniniz yok.",
     "Back to %s" : "%s sayfasına dön",
     "Page not found" : "Sayfa bulunamadı",
     "The page could not be found on the server or you may not be allowed to view it." : "Sayfa sunucuda bulunamadı ya da görüntülemenize izin verilmiyor olabilir.",
@@ -350,15 +457,15 @@ OC.L10N.register(
     "Password sent!" : "Parola gönderildi!",
     "You are not authorized to request a password for this share" : "Bu paylaşım için parola isteğinde bulunma izniniz yok",
     "Two-factor authentication" : "İki adımlı doğrulama",
-    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Hesabınız için gelişmiş güvenlik etkinleştirildi. Kimlik doğrulaması için bir ikinci aşama seçin:",
-    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Etkinleştirilmiş iki adımlı doğrulama yöntemlerinden en az biri yüklenemedi. Lütfen yöneticiniz ile görüşün.",
-    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "İki adımlı doğrulama kullanımı zorunlu kılınmış ancak hesabınız için yapılandırılmamış. Yardım almak için sistem yöneticiniz ile görüşün.",
-    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "İki adımlı doğrulama kullanımı dayatılmış ancak hesabınız için yapılandırılması tamamlanmamış. Lütfen işlemi sürdürmek için iki adımlı doğrulamayı kurun.",
+    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Hesabınız için gelişmiş güvenlik etkinleştirildi. Kimlik doğrulaması için bir ikinci adım seçin:",
+    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Kullanıma alınmış iki adımlı doğrulama yöntemlerinden en az biri yüklenemedi. Lütfen yöneticiniz ile görüşün.",
+    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "İki adımlı doğrulama kullanımı zorunlu kılınmış. Ancak hesabınız için yapılandırılmamış. Yardım almak için sistem yöneticiniz ile görüşün.",
+    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "İki adımlı doğrulama kullanımı zorunlu kılınmış. Ancak hesabınız için yapılandırılmamış. Lütfen işlemi sürdürmek için iki adımlı doğrulamayı kurun.",
     "Set up two-factor authentication" : "İki adımlı doğrulama kurulumu",
     "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "İki adımlı doğrulama kullanımı zorunlu kılınmış ancak hesabınız için yapılandırılmamış. Yedek kodlarınızdan birini kullanın ya da yardım almak için sistem yöneticiniz ile görüşün.",
     "Use backup code" : "Yedek kodu kullanacağım",
     "Cancel login" : "Oturum açmaktan vazgeç",
-    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Hesabınız için gelişmiş güvenlik kullanımı dayatılmış. Kuracağınız hizmet sağlayıcıyı seçin:",
+    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Hesabınız için gelişmiş güvenlik kullanımı zorunlu kılınmış. Kurulacak hizmet sağlayıcıyı seçin:",
     "Error while validating your second factor" : "İkinci aşama doğrulanırken sorun çıktı",
     "Access through untrusted domain" : "Güvenilmeyen etki alanı üzerinden erişim",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Lütfen BT yöneticiniz ile görüşün. Yöneticisi siz iseniz, config/config.php dosyası içerisindeki \"trusted_domain\" ayarını config/config.sample.php dosyasındaki gibi düzenleyin.",
@@ -366,9 +473,9 @@ OC.L10N.register(
     "App update required" : "Uygulamanın güncellenmesi gerekli",
     "%1$s will be updated to version %2$s" : "%1$s, %2$s sürümüne güncellenecek",
     "The following apps will be updated:" : "Şu uygulamalar güncellenecek:",
-    "These incompatible apps will be disabled:" : "Şu uyumsuz uygulamalar devre dışı bırakılacak:",
-    "The theme %s has been disabled." : "%s teması devre dışı bırakıldı.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "İlerlemeden önce lütfen veritabanı, yapılandırma klasörü ve veri klasörünün yedeklenmiş olduğundan emin olun.",
+    "These incompatible apps will be disabled:" : "Şu uyumsuz uygulamalar kullanımdan kaldırılacak:",
+    "The theme %s has been disabled." : "%s teması kullanımdan kaldırıldı.",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "İlerlemeden önce lütfen veri tabanı, yapılandırma klasörü ve veri klasörünün yedeklenmiş olduğundan emin olun.",
     "Start update" : "Güncellemeyi başlat",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Daha büyük kurulumlarda zaman aşımlarının önüne geçmek için, kurulum klasörünüzden şu komutu da çalıştırabilirsiniz:",
     "Detailed logs" : "Ayrıntılı günlükler",
@@ -381,19 +488,41 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Bu %s kopyası şu anda bakım kipinde, bu işlem biraz zaman alabilir.",
     "This page will refresh itself when the instance is available again." : "Sistem yeniden kullanılabilir olduğunda bu sayfa kendiliğinden yenilenecek",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Bu ileti görüntülenmeyi sürdürüyor ya da beklenmedik şekilde ortaya çıkıyorsa BT yöneticiniz ile görüşün.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Sohbet, görüntülü çağrı, ekran paylaşımı, çevrim içi toplantılar ve internet görüşmeleri - masaüstü ve mobil için uygulamalar.",
-    "You have not added any info yet" : "Henüz herhangi bir bilgi eklememişsiniz",
-    "{user} has not added any info yet" : "{user} henüz herhangi bir bilgi eklememiş",
-    "Error opening the user status modal, try hard refreshing the page" : "Üste açılan kullanıcı durumu penceresinde sorun çıktı. Sayfası temizleyerek yenilemeyi deneyin ",
-    "Edit Profile" : "Profili düzenle",
-    "The headline and about sections will show up here" : "Başlık ve hakkında bölümleri burada görüntülenir",
+    "Error occurred while checking server setup" : "Sunucu ayarları denetlenirken sorun çıktı",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Ayrıntılı bilgi almak için {linkstart}belgeler ↗{linkend} bölümüne bakabilirsiniz.",
+    "unknown text" : "bilinmeyen yazı",
+    "Hello world!" : "Merhaba dünya!",
+    "sunny" : "güneşli",
+    "Hello {name}, the weather is {weather}" : "Merhaba {name}, hava durumu {weather}",
+    "Hello {name}" : "Merhaba {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Arama sonuçlarınız<script>alert(1)</script></strong>",
+    "new" : "yeni",
+    "_download %n file_::_download %n files_" : ["%n dosya indiriliyor","%n dosya indiriliyor"],
+    "Direct link copied to clipboard" : "Doğrudan bağlantı panoya kopyalandı",
+    "Searching …" : "Aranıyor…",
+    "Logging in …" : "Oturum açılıyor …",
+    "Loading apps …" : "Uygulamalar yükleniyor …",
+    "Installing apps …" : "Uygulamalar kuruluyor …",
+    "Loading your contacts …" : "Kişileriniz yükleniyor …",
+    "Looking for {term} …" : "{term} ifadesi aranıyor …",
+    "Search contacts …" : "Kişi arama …",
+    "Loading more results …" : "Diğer sonuçlar yükleniyor…",
+    "Search {types} …" : "{types} arama…",
+    "Saving …" : "Kaydediliyor …",
     "Very weak password" : "Parola çok zayıf",
     "Weak password" : "Parola zayıf",
     "So-so password" : "Parola idare eder",
     "Good password" : "Parola iyi",
     "Strong password" : "Parola güçlü",
-    "Profile not found" : "Profil bulunamadı",
-    "The profile does not exist." : "Profil bulunamadı.",
+    "No action available" : "Yapılabilecek bir işlem yok",
+    "Error fetching contact actions" : "Kişi işlemleri alınırken sorun çıktı",
+    "Non-existing tag #{tag}" : "#{tag} etiketi bulunamadı",
+    "Restricted" : "Kısıtlanmış",
+    "Invisible" : "Görünmez",
+    "Delete" : "Sil",
+    "Rename" : "Yeniden adlandır",
+    "Collaborative tags" : "İş birlikli etiketler",
+    "No tags found" : "Herhangi bir etiket bulunamadı",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccess dosyası yürürlükte olmadığından veri klasörünüz ve dosyalarınız İnternet üzerinden erişime açık.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Sunucunuzu nasıl yapılandıracağınız hakkında bilgi almak için <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">belgelere</a> bakabilirsiniz.",
     "<strong>Create an admin account</strong>" : "<strong>Bir yönetici hesabı oluşturun</strong>",
@@ -403,6 +532,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Parolayı görüntüle/gizle",
     "Configure the database" : "Veri tabanını yapılandır",
     "Only %s is available." : "Yalnızca %s kullanılabilir.",
-    "Database account" : "Veritabanı hesabı"
+    "Database account" : "Veri tabanı hesabı",
+    "Installing …" : "Kuruluyor…"
 },
 "nplurals=2; plural=(n > 1);");
