@@ -9,7 +9,6 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s y %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s y %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s y %5$s",
-    "Education Edition" : "Edición Educativa",
     "Enterprise bundle" : "Paquete empresarial",
     "Groupware bundle" : "Paquete de Groupware",
     "Social sharing bundle" : "Paquete para compartir en redes sociales",
@@ -20,11 +19,11 @@ OC.L10N.register(
     "The library %s is not available." : "La biblioteca %s no está disponible. ",
     "Server version %s or higher is required." : "Se requiere la versión del servidor %s o superior. ",
     "Server version %s or lower is required." : "La versión del servidor %s o inferior es requerdia. ",
-    "Logged in user must be an admin" : "El usuario firmado debe ser un administrador",
     "Authentication" : "Autenticación",
     "Unknown filetype" : "Tipo de archivo desconocido",
     "Invalid image" : "Imagen inválida",
     "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
+    "Files" : "Archivos",
     "today" : "hoy",
     "tomorrow" : "mañana",
     "yesterday" : "ayer",
@@ -45,21 +44,18 @@ OC.L10N.register(
     "in a few seconds" : "en algunos segundos",
     "seconds ago" : "hace segundos",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El módulo con ID: %sno existe. Por favor hablíitalo en tus configuraciones de aplicación o contacta a tu administrador.  ",
-    "File already exists" : "El archivo ya existe",
-    "File name is a reserved word" : "Nombre de archivo es una palabra reservada",
-    "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un caracter inválido",
-    "File name is too long" : "El nombre del archivo es demasiado largo",
     "Dot files are not allowed" : "Los archivos Dot no están permitidos",
+    "File already exists" : "El archivo ya existe",
+    "Filename contains at least one invalid character" : "El nombre del archivo contiene al menos un carácter inválido",
     "Empty filename is not allowed" : "El uso de nombres de archivo vacíos no está permitido",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "La aplicación \"%s\" no puede ser instalada porque el archivo appinfo no se puede leer. ",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "La aplicación \"%s\" no puede ser instalada porque no es compatible con esta versión del servidor. ",
     "__language_name__" : "Español (Guatemala)",
     "This is an automatically sent email, please do not reply." : "Este es un correo enviado automáticamente, por favor no lo contestes. ",
-    "Help" : "Ayuda",
     "Apps" : "Aplicaciones",
     "Settings" : "Configuraciones",
     "Log out" : "Cerrar sesión",
-    "Users" : "Usuarios",
+    "Accounts" : "Accounts",
     "Email" : "Correo electrónico",
     "Phone" : "Teléfono fijo",
     "Twitter" : "Twitter",
@@ -67,28 +63,20 @@ OC.L10N.register(
     "Address" : "Dirección",
     "Profile picture" : "Foto de perfil",
     "About" : "Acerca de",
-    "Full name" : "Nombre completo",
-    "Unknown user" : "Ususario desconocido",
     "Additional settings" : "Configuraciones adicionales",
     "You need to enter details of an existing account." : "Necesitas ingresar los detalles de una cuenta existente.",
     "Oracle connection could not be established" : "No fue posible establecer la conexión a Oracle",
-    "Oracle username and/or password not valid" : "Usuario y/o contraseña de Oracle inválidos",
-    "PostgreSQL username and/or password not valid" : "El Usuario y/o Contraseña de PostgreSQL inválido(s)",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "OS X de Mac no está soportado y %s no funcionará correctamente en esta plataforma ¡Úsalo bajo tu propio riesgo!",
     "For the best results, please consider using a GNU/Linux server instead." : "Para mejores resultados, por favor cosidera usar en su lugar un servidor GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Al parecer esta instancia %s está corriendo en un ambiente PHP de 32-bits y el open_basedir ha sido configurado en el archivo php.ini. Esto generará problemas con archivos de más de 4GB de tamaño y es altamente desalentado. ",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor elimina el ajuste open_basedir de tu archivo php.ini o cambia a PHP de 64 bits. ",
-    "Set an admin username." : "Establecer un Usuario administrador",
     "Set an admin password." : "Establecer la contraseña del administrador.",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El backend %s que comparte debe implementar la interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "No fue encontrado el Backend que comparte %s ",
     "Sharing backend for %s not found" : "No fue encontrado el Backend que comparte para %s",
-    "Open »%s«" : "Abrir »%s«",
+    "Unknown share type" : "Tipo de elemento compartido desconocido",
     "You are not allowed to share %s" : "No tienes permitido compartir %s",
     "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
     "Expiration date is in the past" : "La fecha de expiración se encuentra en el pasado",
-    "Sharing %s failed, because this item is already shared with user %s" : "Se presento una falla al compartir %s, porque este elemento ya ha sido compartido con el usuario %s",
-    "Click the button below to open it." : "Haz click en el botón inferior para abrirlo. ",
     "The requested share does not exist anymore" : "El recurso compartido solicitado ya no existe",
     "Could not find category \"%s\"" : "No fue posible encontrar la categoria \"%s\"",
     "Sunday" : "Domingo",
@@ -136,17 +124,9 @@ OC.L10N.register(
     "Oct." : "Oct.",
     "Nov." : "Nov.",
     "Dec." : "Dic.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Sólo se permiten los siguientes caracteres en el usuario: \"a-z\", \"A-Z\", \"0-9\" y \"_.@-'\"",
-    "A valid username must be provided" : "Debes proporcionar un nombre de usuario válido",
-    "Username contains whitespace at the beginning or at the end" : "El usuario contiene un espacio en blanco al inicio o al final",
-    "Username must not consist of dots only" : "El usuario no debe consistir de solo puntos. ",
     "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
-    "The username is already being used" : "Ese usuario ya está en uso",
-    "Could not create user" : "No fue posible crear el usuario",
-    "User disabled" : "Usuario deshabilitado",
     "Login canceled by app" : "Inicio de sesión cancelado por la aplicación",
     "a safe home for all your data" : "un lugar seguro para todos tus datos",
-    "File is currently busy, please try again later" : "El archivo se encuentra actualmente en uso, por favor intentalo más tarde. ",
     "Application is not enabled" : "La aplicación está deshabilitada",
     "Authentication error" : "Error de autenticación",
     "Token expired. Please reload page." : "La ficha ha expirado. Por favor recarga la página.",
@@ -155,39 +135,20 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Por favor solicita a tu adminsitrador la instalación del módulo. ",
     "PHP setting \"%s\" is not set to \"%s\"." : "El ajuste PHP \"%s\" no esta establecido a \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "El cambiar este ajuste del archivo php.ini hará que Nextcloud corra de nuevo.",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Se requiere de por lo menos libxml2 2.7.0. Actualmente %s está instalado. ",
-    "To fix this issue update your libxml2 version and restart your web server." : "Para corregir este tema, por favor actualiza la versión de su libxml2 y reinicia tu servidor web. ",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Al parecer PHP está configurado para quitar los bloques de comentarios internos. Esto hará que varias aplicaciones principales sean inaccesibles. ",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Esto ha sido causado probablemente por un acelerador de caché como Zend OPcache o eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "¿Los módulos de PHP han sido instalados, pero se siguen enlistando como faltantes?",
     "Please ask your server administrator to restart the web server." : "Por favor solicita al administrador reiniciar el servidor web. ",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor cambia los permisos a 0770 para que el directorio no pueda ser enlistado por otros usuarios. ",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegurate de que exista una archivo llamado \".ocdata\" en la raíz del directorio de datos. ",
     "Could not obtain lock type %d on \"%s\"." : "No fue posible obtener el tipo de bloqueo %d en \"%s\". ",
     "Storage unauthorized. %s" : "Almacenamiento no autorizado. %s",
     "Storage incomplete configuration. %s" : "Configuración incompleta del almacenamiento. %s",
     "Storage connection error. %s" : "Se presentó un error con la conexión al almacenamiento. %s",
     "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
     "Storage connection timeout. %s" : "El tiempo de la conexión del almacenamiento se agotó. %s",
-    "%s enter the database username and name." : "%s ingresa el usuario y nombre de la base de datos",
-    "%s enter the database username." : "%s ingresa el nombre de usuario de la base de datos.",
-    "%s enter the database name." : "%s ingresar el nombre de la base de datos",
-    "%s you may not use dots in the database name" : "%s no puedes utilizar puntos en el nombre de la base de datos",
-    "Cannot write into \"config\" directory" : "No fue posible escribir en el directorio \"config\"",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Por lo general esto se puede resolver al darle al servidor web acceso de escritura al directorio config. Por favor ve %s",
-    "Cannot write into \"apps\" directory" : "No fue posible escribir en el directorio \"apps\"",
-    "Cannot create \"data\" directory" : "No fue posible crear el directorio \"data\"",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Por lo general esto se puede resolver al darle al servidor web acceso de escritura al directorio raíz. Por favor ve %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Por lo general los permisos se pueden corregir al darle al servidor web acceso de escritura al directorio raíz. Por favor ve %s.",
-    "Setting locale to %s failed" : "Se presentó una falla al establecer la regionalización a  %s",
-    "Please install one of these locales on your system and restart your webserver." : "Por favor instala uno de las siguientes configuraciones locales en tu sistema y reinicia tu servidor web",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está establecido como \"%s\" en lugar del valor esperado de \"0\"",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para corregir este tema, establece <code>mbstring.func_overload</code> a <code>0</code> en tu archivo php.ini",
-    "PostgreSQL >= 9 required" : "Se requiere PostgreSQL >= 9",
-    "Please upgrade your database version" : "Por favor actualiza tu versión de la base de datos",
-    "Your data directory is readable by other users" : "Tu direcctorio data puede ser leído por otros usuarios",
-    "Your data directory must be an absolute path" : "Tu directorio data debe ser una ruta absoluta",
-    "Check the value of \"datadirectory\" in your configuration" : "Verifica el valor de \"datadirectory\" en tu configuración",
-    "Your data directory is invalid" : "Tu directorio de datos es inválido"
+    "Images" : "Imágenes",
+    "Text" : "Texto",
+    "Summary" : "Resumen",
+    "Translate" : "Traducir",
+    "Result" : "Resultado"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
