@@ -119,7 +119,6 @@ OC.L10N.register(
     "About" : "Acerca de",
     "Display name" : "Nombre para mostrar",
     "Headline" : "Título",
-    "Organisation" : "Organización",
     "Role" : "Cargo",
     "Pronouns" : "Pronombre",
     "Unknown account" : "Cuenta desconocida",
@@ -176,7 +175,6 @@ OC.L10N.register(
     "Path is already shared with this group" : "La ruta ya ha sido compartida con este grupo",
     "Link sharing is not allowed" : "La compartición mediante enlaces no está permitida",
     "Public upload is not allowed" : "No se permite la subida pública de archivos",
-    "Path contains files shared with you" : "La ruta contiene archivos compartidos contigo",
     "Sharing is disabled" : "Compartir está deshabilitado",
     "Sharing is disabled for you" : "No estás habilitado para compartir",
     "Cannot share with the share owner" : "No puedes compartir con el propietario del recurso compartido",
@@ -255,8 +253,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "No se puede escribir en el directorio \"config\".",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Normalmente, esto se puede arreglar al darle al servidor web permiso de escritura al directorio de configuración. Vea %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Sin embargo, si prefiere mantener el archivo config.php como sólo lectura, establezca la opción \"config_is_read_only\" como verdadero. Vea %s",
-    "Cannot write into \"apps\" directory." : "No se puede escribir en el directorio \"apps\".",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Normalmente, esto se puede arreglar al darle al servidor web permiso de escritura al directorio de aplicaciones o deshabilitando la tienda de aplicaciones del archivo de configuración.",
     "Cannot create \"data\" directory." : "No se puede crear el directorio \"data\".",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Normalmente, esto se puede arreglar dando al servidor web permiso de escritura al directorio raíz. Vea %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Los permisos normalmente se pueden arreglar dando al servidor web permiso de escritura al directorio raíz. Vea %s.",
@@ -267,8 +263,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Por favor solicita a tu adminsitrador la instalación del módulo. ",
     "PHP setting \"%s\" is not set to \"%s\"." : "El ajuste PHP \"%s\" no esta establecido a \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "El cambiar este ajuste del archivo php.ini hará que Nextcloud corra de nuevo.",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> está configurado como <code>%s</code> en lugar del valor esperado <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Para arreglar este problema, establezca <code>mbstring.func_overload</code> como<code>0</code> en su php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Al parecer PHP está configurado para quitar los bloques de comentarios internos. Esto hará que varias aplicaciones principales sean inaccesibles. ",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Esto ha sido causado probablemente por un acelerador de caché como Zend OPcache o eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "¿Los módulos de PHP han sido instalados, pero se siguen enlistando como faltantes?",
@@ -292,14 +286,18 @@ OC.L10N.register(
     "Storage connection error. %s" : "Se presentó un error con la conexión al almacenamiento. %s",
     "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
     "Storage connection timeout. %s" : "El tiempo de la conexión del almacenamiento se agotó. %s",
+    "Images" : "Imágenes",
+    "System prompt" : "Prompt del sistema",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Define las reglas y suposiciones que el asistente debe seguir durante la conversación.",
+    "Chat history" : "Historial de la conversación",
     "Transcribe audio" : "Transcribir audio",
     "Transcribe the things said in an audio" : "Transcribir lo que se dice en un audio",
     "Audio input" : "Entrada de audio",
     "The audio to transcribe" : "El audio a transcribir",
     "Transcription" : "Transcripción",
     "The transcribed text" : "El texto transcrito",
-    "Chat message" : "Mensaje de chat",
     "Confirmation" : "Confirmación",
+    "Chat message" : "Mensaje de chat",
     "Writes text in a given style based on the provided source material." : "Escribe el texto en un estilo dado basándose en el material fuente proporcionado.",
     "Writing style" : "Estilo de escritura",
     "Demonstrate a writing style that you would like to immitate" : "Demostrar un estilo de escritura que le gustaría imitar",
@@ -327,9 +325,6 @@ OC.L10N.register(
     "The generated text from the assistant" : "El texto generado por el asistente",
     "Chat" : "Chat",
     "Chat with the assistant" : "Conversar con el asistente",
-    "System prompt" : "Prompt del sistema",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "Define las reglas y suposiciones que el asistente debe seguir durante la conversación.",
-    "Chat history" : "Historial de la conversación",
     "The history of chat messages before the current message, starting with a message by the user" : "El historial de mensajes del chat antes del mensaje actual, empezando con un mensaje de usuario",
     "Response message" : "Mensaje de respuesta",
     "The generated response as part of the conversation" : "La respuesta generada como parte de la conversación",
@@ -379,20 +374,10 @@ OC.L10N.register(
     "Generate headline" : "Generar titular",
     "Summarizes text by reducing its length without losing key information." : "Resume el texto reduciendo su longitud sin perder información clave.",
     "Extracts topics from a text and outputs them separated by commas." : "Extrae los temas de un texto y genera una salida separada por comas. ",
-    "Education Edition" : "Edición Educativa",
-    "File name is a reserved word" : "Nombre de archivo es una palabra reservada",
-    "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un caracter inválido",
-    "File name is too long" : "El nombre del archivo es demasiado largo",
-    "Users" : "Usuarios",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartió »%2$s« contigo y quiere añadir:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s compartió »%2$s« contigo y quiere añadir",
-    "»%s« added a note to a file shared with you" : "»%s« añadió una nota a un archivo compartido contigo",
-    "Open »%s«" : "Abrir »%s«",
-    "%1$s shared »%2$s« with you" : "%1$s compartió »%2$s« contigo",
-    "%1$s shared »%2$s« with you." : "%1$s compartió »%2$s« contigo.",
-    "Click the button below to open it." : "Haz click en el botón inferior para abrirlo. ",
-    "File is currently busy, please try again later" : "El archivo se encuentra actualmente en uso, por favor intentalo más tarde. ",
-    "Cannot download file" : "No se puede descargar el archivo",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegurate de que exista una archivo llamado \".ocdata\" en la raíz del directorio de datos. "
+    "Organisation" : "Organización",
+    "Cannot write into \"apps\" directory." : "No se puede escribir en el directorio \"apps\".",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Normalmente, esto se puede arreglar al darle al servidor web permiso de escritura al directorio de aplicaciones o deshabilitando la tienda de aplicaciones del archivo de configuración.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> está configurado como <code>%s</code> en lugar del valor esperado <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Para arreglar este problema, establezca <code>mbstring.func_overload</code> como<code>0</code> en su php.ini."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
