@@ -19,7 +19,6 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s és %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s és %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s és %5$s",
-    "Education Edition" : "Oktatási kiadás",
     "Enterprise bundle" : "Vállalati csomag",
     "Groupware bundle" : "Csoportmunka csomag",
     "Hub bundle" : "Központi csomag",
@@ -54,6 +53,7 @@ OC.L10N.register(
     "Avatar image is not square" : "A profilkép nem négyzetes.",
     "Files" : "Fájlok",
     "View profile" : "Profil megtekintése",
+    "_%nh_::_%nh_" : ["%nó","%nó"],
     "Local time: %s" : "Helyi idő: %s",
     "today" : "ma",
     "tomorrow" : "holnap",
@@ -76,26 +76,28 @@ OC.L10N.register(
     "seconds ago" : "pár másodperce",
     "Empty file" : "Üres fájl",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "A(z) %s azonosítójú modul nem létezik. Engedélyezze az alkalmazásbeállításokban, vagy lépjen kapcsolatba a rendszergazdával.",
+    "Dot files are not allowed" : "A ponttal kezdődő fájlok nem engedélyezettek",
+    "%1$s (renamed)" : "%1$s (átnevezve)",
+    "renamed file" : "átnevezett fájl",
+    "Filenames must not end with \"%1$s\"." : "Fájlnév nem végződhet így: „%1$s”.",
     "File already exists" : "A fájl már létezik",
     "Invalid path" : "Érvénytelen útvonal",
     "Failed to create file from template" : "Nem sikerült létrehozni a fájlt a sablonból",
     "Templates" : "Sablonok",
-    "File name is a reserved word" : "A fájl neve egy fenntartott szó",
-    "File name contains at least one invalid character" : "A fájlnév legalább egy érvénytelen karaktert tartalmaz",
-    "File name is too long" : "A fájlnév túl hosszú",
-    "Dot files are not allowed" : "A ponttal kezdődő fájlok nem engedélyezettek",
+    "Filename contains at least one invalid character" : "A fájlnév legalább egy érvénytelen karaktert tartalmaz",
     "Empty filename is not allowed" : "Az üres fájlnév nem engedélyezett",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "A(z) „%s” alkalmazást nem lehet telepíteni, mert az appinfo fájl nem olvasható.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "A(z) „%s” alkalmazást nem lehet telepíteni, mert nem kompatibilis ezzel a kiszolgálóverzióval.",
     "__language_name__" : "Magyar",
     "This is an automatically sent email, please do not reply." : "Ez egy automatikusan küldött levél, ne válaszoljon rá.",
+    "Help & privacy" : "Súgó és adatvédelem",
     "Appearance and accessibility" : "Megjelenés és akadálymentesítés",
     "Apps" : "Alkalmazások",
     "Personal settings" : "Személyes beállítások",
     "Administration settings" : "Rendszergazdai beállítások",
     "Settings" : "Beállítások",
     "Log out" : "Kijelentkezés",
-    "Users" : "Felhasználók",
+    "Accounts" : "Fiókok",
     "Email" : "E-mail",
     "Mail %s" : "Levél küldése ide: %s",
     "Fediverse" : "Födiverzum",
@@ -111,14 +113,13 @@ OC.L10N.register(
     "About" : "Névjegy",
     "Display name" : "Megjelenítendő név",
     "Headline" : "Címsor",
-    "Organisation" : "Szervezet",
+    "Organization" : "Szervezet",
     "Role" : "Szerepkör",
     "Additional settings" : "További beállítások",
     "Enter the database name for %s" : "Adja meg a %s adatbázisának nevét",
     "You cannot use dots in the database name %s" : "A(z) %s adatbázisnév nem tartalmazhat pontot",
     "You need to enter details of an existing account." : "Egy már létező fiók adatait kell megadnia.",
     "Oracle connection could not be established" : "Az Oracle kapcsolat nem hozható létre",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "A Mac OS X nem támogatott, és a %s nem lesz teljesen működőképes. Csak saját felelősségre használja.",
     "For the best results, please consider using a GNU/Linux server instead." : "A legjobb eredmény érdekében érdemes GNU/Linux kiszolgálót használni.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Úgy tűnik, hogy ez a %s példány 32 bites PHP környezetben fut, és az open_basedir be lett állítva a php.ini fájlban. Ez 4 GB-nál nagyobb fájlok esetén problémákat okozhat, így erősen ellenjavallott.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Távolítsa el az open_basedir beállítást a php.ini fájlból, vagy váltson 64 bites PHP-ra.",
@@ -127,11 +128,8 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A(z) %s megosztási alrendszernek meg kell valósítania az OCP\\Share_Backend interfészt",
     "Sharing backend %s not found" : "A(z) %s megosztási alrendszer nem található",
     "Sharing backend for %s not found" : "A(z) %s megosztási alrendszere nem található",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s megosztotta Önnel: „%2$s”, és hozzá akarja adni:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s megosztotta Önnel: „%2$s”, és hozzá akarja adni",
-    "»%s« added a note to a file shared with you" : "„%s” megjegyzést fűzött az Önnel megosztott fájlhoz",
-    "Open »%s«" : "A(z) „%s” megnyitása",
     "%1$s via %2$s" : "%1$s – %2$s",
+    "Unknown share type" : "Ismeretlen megosztástípus",
     "You are not allowed to share %s" : "Nincs jogosultsága a(z) %s megosztásához",
     "Cannot increase permissions of %s" : "A(z) %s engedélyei nem bővíthetők",
     "Files cannot be shared with delete permissions" : "A fájlok nem oszthatók meg törlési jogosultsággal",
@@ -139,9 +137,7 @@ OC.L10N.register(
     "Expiration date is in the past" : "A lejárati dátum már elmúlt",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Nem állítható be %n napnál távolabbi lejárati dátum","Nem állítható be %n napnál távolabbi lejárati dátum"],
     "Sharing is only allowed with group members" : "A megosztás csak a csoport tagjaival engedélyezett",
-    "%1$s shared »%2$s« with you" : "%1$s megosztotta Önnel: „%2$s”",
-    "%1$s shared »%2$s« with you." : "%1$s megosztotta Önnel: „%2$s”.",
-    "Click the button below to open it." : "Kattintson a lenti gombra a megnyitáshoz.",
+    "Sharing %s failed, because this item is already shared with the account %s" : "A(z) %s megosztása sikertelen, mert már meg van osztva a(z) %s fiókkal",
     "The requested share does not exist anymore" : "A kért megosztás már nem létezik",
     "The requested share comes from a disabled user" : "A kért megosztás letiltott felhasználótól származik",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "A felhasználó nem jött létre, mert elérte a felhasználókorlátot. Nézze meg az értesítéseit, hogy többet tudjon meg.",
@@ -195,8 +191,6 @@ OC.L10N.register(
     "Login canceled by app" : "Bejelentkezés megszakítva az alkalmazás által",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "A(z) „%1$s” alkalmazást nem lehet telepíteni, mert a következő függőségek nem teljesülnek: %2$s",
     "a safe home for all your data" : "egy biztonságos hely az adataidnak",
-    "File is currently busy, please try again later" : "A fájl jelenleg foglalt, próbálja újra később",
-    "Cannot download file" : "A fájl nem tölthető le",
     "Application is not enabled" : "Az alkalmazás nincs engedélyezve",
     "Authentication error" : "Hitelesítési hiba",
     "Token expired. Please reload page." : "A token lejárt. Frissítse az oldalt.",
@@ -204,8 +198,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "A „config” könyvtár nem írható.",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Ez általában úgy javítható, hogy írási jogosultságot ad a webkiszolgáló számára a config könyvtáron. Lásd %s.",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Vagy, ha jobbnak látja, hogy a config.php fájl csak olvasható legyen, akkor állítsa igazra a „config_is_read_only” beállítást. Lásd: %s.",
-    "Cannot write into \"apps\" directory." : "Az „apps” könyvtár nem írható.",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ez általában úgy javítható, hogy írási jogosultságot ad a webkiszolgáló számára az apps könyvtáron, vagy letiltja az alkalmazástárt a konfigurációs fájlban.",
     "Cannot create \"data\" directory." : "A „data” könyvtár nem hozható létre.",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Ez általában úgy javítható, hogy írási jogosultságot ad a webkiszolgáló számára a gyökérkönyvtáron. Lásd %s.",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Az engedélyek általában úgy javíthatók, hogy írási jogosultságot ad a webkiszolgáló számára a gyökérkönyvtáron. Lásd %s.",
@@ -216,8 +208,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Kérje meg a rendszergazdát, hogy telepítse a modult.",
     "PHP setting \"%s\" is not set to \"%s\"." : "A(z) %s PHP beállítás nincs erre állítva: „%s”.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "A beállítás a php.ini fájlban történő módosításai után újra fog futni a Nexcloud",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "Az <code>mbstring.func_overload</code> a várt <code>0</code> érték helyett erre van állítva: <code>%s</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "A probléma javításához állítsa <code>0</code>-ra az <code>mbstring.func_overload</code> értékét a php.ini-ben.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Úgy tűnik, hogy a PHP úgy van beállítva, hogy eltávolítja programok belsejében elhelyezett szövegblokkokat. Emiatt a rendszer több alapvető fontosságú eleme működésképtelen lesz.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ezt valószínűleg egy gyorsítótár, mint például a Zend, az OPcache vagy az eAccelererator okozza.",
     "PHP modules have been installed, but they are still listed as missing?" : "A PHP modulok telepítve vannak, de a listában mégsem szerepelnek?",
@@ -227,7 +217,6 @@ OC.L10N.register(
     "Your data directory must be an absolute path." : "Az adatkönyvtárnak abszolút útvonalnak kell lennie",
     "Check the value of \"datadirectory\" in your configuration." : "Ellenőrizze a „datadirectory” értékét a konfigurációban.",
     "Your data directory is invalid." : "Az adatkönyvtár érvénytelen.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Győződjön meg róla, hogy az adatmappa gyökerében van-e egy „.ocdata” fájl.",
     "Action \"%s\" not supported or implemented." : "A(z) „%s” művelet nem támogatott vagy nem ismert.",
     "Authentication failed, wrong token or provider ID given" : "Hitelesítés sikertelen, hibás token vagy szolgáltatóazonosító lett megadva",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "A következő paraméterek hiányoznak, hogy végrehajtható legyen a kérés. Paraméterek: \"%s\"",
@@ -239,38 +228,27 @@ OC.L10N.register(
     "Storage connection error. %s" : "Tároló kapcsolódási hiba. %s",
     "Storage is temporarily not available" : "A tároló átmenetileg nem érhető el",
     "Storage connection timeout. %s" : "Időtúllépés a tárolókapcsolatban. %s",
+    "Images" : "Képek",
+    "Question" : "Kérdés",
+    "Confirmation" : "Megerősítés",
+    "Prompt" : "Prompt",
+    "Generates a possible headline for a text." : "Egy lehetséges címsort állít elő egy szöveghez.",
+    "Text" : "Szöveg",
+    "Summarize" : "Összesítés",
+    "Summary" : "Összefoglalás",
+    "Extract topics" : "Témák kinyerése",
+    "Translate" : "Lefordítás",
+    "Target language" : "Célnyelv",
+    "Result" : "Eredmény",
     "Free prompt" : "Szabad prompt",
     "Runs an arbitrary prompt through the language model." : "Tetszőleges promptot futtat a nyelvi modellen.",
     "Generate headline" : "Címsor előállítása",
-    "Generates a possible headline for a text." : "Egy lehetséges címsort állít elő egy szöveghez.",
-    "Summarize" : "Összesítés",
     "Summarizes text by reducing its length without losing key information." : "Összesíti a szöveget a hosszúság csökkentésével anélkül, hogy a kulcsinformációk elvesznének.",
-    "Extract topics" : "Témák kinyerése",
     "Extracts topics from a text and outputs them separated by commas." : "Kinyeri a témákat a szövegből, és vesszőkkel elválasztva megjeleníti.",
-    "404" : "404",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "A bejelentkezett felhasználónak rendszergazdának vagy alrendszergazdának kell lennie, vagy speciális hozzáféréssel kell rendelkeznie ehhez a beállításhoz",
-    "Logged in user must be an admin or sub admin" : "A bejelentkezett felhasználónak rendszergazdának vagy alrendszergazgának kell lennie",
-    "Logged in user must be an admin" : "A bejelentkezett felhasználónak rendszergazdának kell lennie",
-    "Help" : "Súgó",
-    "Unknown user" : "Ismeretlen felhasználó",
-    "Enter the database username and name for %s" : "Adja meg a %s adatbázisának nevét és a hozzá tartozó felhasználónevet",
-    "Enter the database username for %s" : "Adja meg a %s adatbázisához tartozó felhasználónevet",
-    "MySQL username and/or password not valid" : "A MySQL felhasználónév vagy jelszó érvénytelen",
-    "Oracle username and/or password not valid" : "Az Oracle felhasználónév vagy jelszó érvénytelen",
-    "PostgreSQL username and/or password not valid" : "A PostgreSQL felhasználói név vagy jelszó érvénytelen",
-    "Set an admin username." : "Állítson be egy rendszergazdai felhasználónevet.",
-    "Sharing %s failed, because this item is already shared with user %s" : "A(z) %s megosztása nem sikerült, mert ez az elem már meg van osztva a(z) %s felhasználóval",
-    "The username is already being used" : "Ez a felhasználónév már foglalt",
-    "Could not create user" : "Nem sikerült létrehozni a felhasználót",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "A felhasználónévben csak a következő karakterek engedélyezettek: „a-z”, „A-Z”, „0-9”, szóköz és „_.@-'”",
-    "A valid username must be provided" : "Érvényes felhasználónevet kell megadnia",
-    "Username contains whitespace at the beginning or at the end" : "A felhasználónév szóközt tartalmaz az elején vagy a végén",
-    "Username must not consist of dots only" : "A felhasználónév nem állhat csak pontokból",
-    "Username is invalid because files already exist for this user" : "A felhasználónév érvénytelen, mert már vannak fájlok ehhez a felhasználóhoz",
-    "User disabled" : "Felhasználó letiltva",
-    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 szükséges.",
-    "Please upgrade your database version." : "Frissítse az adatbázis verzióját.",
-    "Your data directory is readable by other users." : "Az adatkönyvtára más felhasználók által is olvasható.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Módosítsa a könyvtár elérhetőségi engedélybeállítását 0770-re, hogy a tartalmát más felhasználók ne listázhassák."
+    "Organisation" : "Szervezet",
+    "Cannot write into \"apps\" directory." : "Az „apps” könyvtár nem írható.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ez általában úgy javítható, hogy írási jogosultságot ad a webkiszolgáló számára az apps könyvtáron, vagy letiltja az alkalmazástárt a konfigurációs fájlban.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "Az <code>mbstring.func_overload</code> a várt <code>0</code> érték helyett erre van állítva: <code>%s</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "A probléma javításához állítsa <code>0</code>-ra az <code>mbstring.func_overload</code> értékét a php.ini-ben."
 },
 "nplurals=2; plural=(n != 1);");
