@@ -238,8 +238,6 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "Summarizes text by reducing its length without losing key information.",
     "Extracts topics from a text and outputs them separated by commas." : "Extracts topics from a text and outputs them separated by commas.",
     "Organisation" : "Organisation",
-    "File is currently busy, please try again later" : "File is currently busy, please try again later",
-    "Cannot download file" : "Cannot download file",
     "Cannot write into \"apps\" directory." : "Cannot write into \"apps\" directory.",
     "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file.",
     "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>.",
