@@ -469,12 +469,10 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "Temel içeriği kaybetmeden uzunluğunu kısaltarak yazıyı özetler.",
     "Extracts topics from a text and outputs them separated by commas." : "Bir yazıdaki konuları ayıklar ve bunları virgül ile ayırarak sıralar.",
     "Organisation" : "Kuruluş",
-    "File is currently busy, please try again later" : "Dosya şu anda meşgul. Lütfen bir süre sonra yeniden deneyin",
-    "Cannot download file" : "Dosya indirilemedi",
+    "Login is too long" : "Kullanıcı adı çok uzun",
     "Cannot write into \"apps\" directory." : "\"apps\" klasörüne yazılamadı.",
     "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Bu sorun genellikle, site sunucusuna apps klasörüne yazma izni verilerek ya da yapılandırma dosyasından uygulama mağazası kullanımdan kaldırılarak çözülebilir.",
     "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code>, beklenen <code>0</code> değeri yerine <code>%s</code> olarak ayarlanmış.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Bu sorunu çözmek için php.ini dosyasındaki <code>mbstring.func_overload</code> seçeneğini <code>0</code> olarak ayarlayın.",
-    "Login is too long" : "Kullanıcı adı çok uzun"
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Bu sorunu çözmek için php.ini dosyasındaki <code>mbstring.func_overload</code> seçeneğini <code>0</code> olarak ayarlayın."
 },
 "nplurals=2; plural=(n > 1);");
